/***********************************************************************************
FILE NAME  		bus_init.h
DESCRIPTION		Header file for external bus initialization.

Copyright   : 2007 Renesas Technology Europe Ltd.
Copyright   : 2007 Renesas Technology Corporation.
All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
23.02.2007 RTE-VNA First Release.
***********************************************************************************/

#ifndef BUS_INIT_H_INCLUDED
#define BUS_INIT_H_INCLUDED

#include <stdlib.h>

/***********************************************************************************
SDRAM Mode register addresses
***********************************************************************************/
/* The address when writing in a SDRAM mode register */
#define	SDRAM_MODE		(*(volatile unsigned short *)(0xfffc5060))
#define	SDRAM_MODE32	(*(volatile unsigned short *)(0xfffc50C0))

/***********************************************************************************
Macro Defines
***********************************************************************************/
#define USE_32BIT_SDRAM_INTERFACE
//#define USE_CACHE_MEMORY	
//#define CACHE_WRITEBACK
#define USE_CLKMODE0

/* Define a delay count for the time period between write and read on the memory test */
#define RST_MEM_DELAY_CNT               30

/* The SDRAM on this RSK can be configured either as 8M x32 SDRAM or 8M x 16 */
#define RSK_SDRAM_SIZE    (1024 * 1024 * 8)

#ifdef USE_CACHE_MEMORY
#define RSK_SDRAM_START   0x0C000000
#else
#define RSK_SDRAM_START   0x2C000000
#endif

/* Define the size of the external bus for the SDRAM here */
#ifdef USE_32BIT_SDRAM_INTERFACE
typedef unsigned long BUS_WIDTH;
#else
typedef unsigned short BUS_WIDTH;
#endif

/* Define the stat address of the CS3 SDRAM */
#define RST_CS3_SDRAM_START         ((BUS_WIDTH*)RSK_SDRAM_START)

/* Define the maximum ammount of SDRAM that area CS3 can support */
#define RSK_CS3_SDRAM_MAX_SIZE      (1024 * 1024 * 64)

/***********************************************************************************
Function Prototypes
***********************************************************************************/
void ConfigureBusAndMemory(void);
void init_bsc_cs0(void);
void set_acswr (void);
size_t rstSizeSDRAM(BUS_WIDTH *pbwRamStart, size_t stLength);
BUS_WIDTH rstTestLocation(BUS_WIDTH *pbwLocation, unsigned int uiDelayCount);
BUS_WIDTH rstReadWrite(BUS_WIDTH *pbwRam, BUS_WIDTH bwTest, unsigned int uiDelayCount);

#ifdef USE_32BIT_SDRAM_INTERFACE
void init_sdram32(void);
#else
void init_sdram(void);
#endif

#ifdef USE_CACHE_MEMORY
void init_cache(void);
#endif

#ifdef CACHE_WRITEBACK
int cache_writeback(void);
#endif

#endif		/* BUS_INIT_H_INCLUDED */
