/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : bscdsdram.c
--------  END-OF-HEADER  ---------------------------------------------
*/
#include "iodefine.h"

#define SDRAM_MODE      (*(volatile unsigned short *)(0xfffc5440))


void io_init_sdram(void);

/*""FUNC COMMENT""**************************************************************
 * ID           : 
 * Outline      : SDRAM 16 bit bus width connection settings
 *------------------------------------------------------------------------------
 * Include      : "iodefine.h"
 *------------------------------------------------------------------------------
 * Declaration  : void io_init_sdram(void);
 *------------------------------------------------------------------------------
 * Description  : Setup to SDRAM of CS3 space.
 *------------------------------------------------------------------------------
 * Argument     : void
 *------------------------------------------------------------------------------
 * Return Value : void
 *------------------------------------------------------------------------------
 * Note         : The PFC setting is set by bit manipulation not to change the PFC 
 *              : set value which is set by other process.
 *""FUNC COMMENT END""**********************************************************/
void io_init_sdram(void)
{
	volatile int j = 4000;			/* for 200-usec wait count @200MHz */

	/* ==== PFC settings ==== */
	PFC.PACRH2.BIT.PA21MD = 0x4;	/* Set CKE   */
	PFC.PACRH1.BIT.PA18MD = 0x1;	/* Set CK    */
	PFC.PACRH1.BIT.PA16MD = 0x1;	/* Set DQMLL */
	PFC.PACRL4.BIT.PA15MD = 0x1;	/* Set DQMLU */
	PFC.PACRL4.BIT.PA14MD = 0x2;	/* Set RASL  */
	PFC.PACRL4.BIT.PA13MD = 0x2;	/* Set CASL  */
	PFC.PBCRL3.BIT.PB11MD = 0x2;	/* Set CS3#  */
	PFC.PBCRL1.BIT.PB0MD  = 0x2;	/* Set RDWR  */

	PFC.PCCRL4.BIT.PC14MD = 0x1;	/* Set A14   */
	PFC.PCCRL4.BIT.PC13MD = 0x1;	/* Set A13   */
	PFC.PCCRL4.BIT.PC12MD = 0x1;	/* Set A12   */
	PFC.PCCRL3.WORD = 0x1111;		/* Set A11-A8 */
	PFC.PCCRL2.WORD = 0x1111;		/* Set A7-A4 */
	PFC.PCCRL1.BIT.PC3MD = 0x1;		/* Set A3    */
	PFC.PCCRL1.BIT.PC2MD = 0x1;		/* Set A2    */
	PFC.PCCRL1.BIT.PC1MD = 0x1;		/* Set A1    */

	PFC.PDCRL4.WORD = 0x1111;		/* Set D15-D12 */
	PFC.PDCRL3.WORD = 0x1111;		/* Set D11-D8 */
	PFC.PDCRL2.WORD = 0x1111;		/* Set D7-D4 */
	PFC.PDCRL1.WORD = 0x1111;		/* Set D3-D0 */

	/* ==== Waiting for a 200-usec interval ==== */
	while(j-- > 0){
	}

	/* ==== CS3BCR Setting ==== */
	BSC.CS3BCR.LONG = 0x00004400ul;
									/* Memory type: SDRAM         */
									/* Data bus size: 16-bit size */

	/* ==== CS3WCR setting ==== */
	BSC.CS3WCR = 0x00000492ul; 
	/* Precharge completion wait cycles: 0 cycle */
	/* Wait cycles between ACTV command and READ/WRIT command: 1 cycle */
	/* CAS latency for Area 3: 2 cycles */
	/* Auto-precharge startup wait cycles: 2 cycles */
	/* Idle cycles from REF command/self-refresh relese to ACTV/REF/MRS command: 5 cycles */

	/* ==== SDCR setting ==== */
	BSC.SDCR.LONG = 0x00000809ul;
									/* Refresh Control: Refresh            */
									/* RMODE: Auto-refresh is performed    */
									/* BACTV: Auto-precharge mode          */
									/* Row address for Area 3: 12 bits     */
									/* Column Address for Area 3: 9 bits   */

	/* ==== RTCOR setting ==== */
	BSC.RTCOR = 0xa55a0030ul;       /* 15.625usec/320nsec = 48(0x30)cycles/refresh  */

	/* ==== RTCSR setting ==== */
	BSC.RTCSR.LONG = 0xa55a0010ul;
									/* Initialize sequence start           */
									/* Clock select B-clock/16 = 320nsec   */
									/* Refresh count: 1 Time               */

	/* ==== Written in SDRAM Mode Register ==== */
	SDRAM_MODE = 0;
									/* CS3 area/16bit bus size             */
									/* Burst read/Single write             */
}

/* End of File */
