/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : cpg.c
--------  END-OF-HEADER  ---------------------------------------------
*/#include <machine.h>
#include "iodefine.h"

/* ==== Prototype declaration ==== */
void io_set_cpg(void);

/*""FUNC COMMENT""**************************************************************
 * ID           : 
 * Outline      : CPG setting
 *------------------------------------------------------------------------------
 * Include      : <machine.h> and "iodefine.h"
 *------------------------------------------------------------------------------
 * Declaration  : void io_set_cpg(void);
 *------------------------------------------------------------------------------
 * Description  : Initializes the clock pulse generator (CPG) as follows: 
 *              :   I-clock = 200MHz, B-clock = 50MHz, P-clock = 50MHz, 
 *              :   M-clock = 100MHz, and A-clock = 50MHz.
 *              : And then supplies clock to all peripheral modules except USB.
 *------------------------------------------------------------------------------
 * Argument     : void
 *------------------------------------------------------------------------------
 * Return Value : void
 *------------------------------------------------------------------------------
 * Note         : This function is an example of CPG setting at the input clock
 *              : of 12.5MHz.
 *""FUNC COMMENT END""**********************************************************/
void io_set_cpg(void)
{
	/* ==== CPG setting ==== */
	CPG.FRQCR.WORD  = 0x0303;			/* Clock-in = 12.5MHz */
										/* I-clock = 200MHz */
										/* B-clock = 50MHz */
										/* P-clock = 50MHz */

	/* ---- Inserting 32 NOP instructions ---- */
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();

	CPG.MCLKCR.BYTE = 0x41;				/* M-clock = 100MHz */
	CPG.ACLKCR.BYTE = 0x43;				/* A-clock = 50MHz */


	/* ==== Module standby clear ==== */
	STB.CR3.BYTE = 0x02;				/* HIZ, MTU2S, MTU2, POE2, */
										/* IIC3, ADC0, Reserve(1), FLASH */

	STB.CR4.BYTE = 0xe2;				/* Reserve(1), Reserve(1), Reserve(1), SCIF3, */
										/* Reserve(0), CMT, Reserve(1), EtherC */

	STB.CR5.BYTE = 0x12;				/* SCI0, SCI1, SCI2, Reserve(1), */
										/* SCI4, ADC1, Reserve(1), RSPI */

	STB.CR6.BYTE = 0x8f;				/* USB: Using USBXTAL/USBEXTAL for USBCLK. */
										/* RCAN-ET */
}

/* End of File */
