/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : resetprg.c
--------  END-OF-HEADER  ---------------------------------------------
*/
#include <machine.h>
#include <_h_c_lib.h>
#include "stacksct.h"
#include "iodefine.h"

/* ==== Macro definition ==== */
#define FPSCR_Init  0x00040001
#define SR_Init     0x000000F0
#define INT_OFFSET  0x10

/* ==== Prototype declaration ==== */
void PowerON_Reset_PC(void);
void Manual_Reset_PC(void);

/* ==== External reference declaration ==== */
/* ---- Function prototype ---- */
extern void main(void);
extern void HardwareSetup(void);
/* ---- Global variable ---- */
extern unsigned int INT_Vectors;

/* ==== Section name changed to ResetPRG ==== */
#pragma section ResetPRG

/* ==== Entry function specified ==== */
#pragma entry PowerON_Reset_PC

/*""FUNC COMMENT""**************************************************************
 * ID           : 
 * Outline      : CPU initialization
 *------------------------------------------------------------------------------
 * Include      : <machine.h>, <_h_c_lib.h>, and "iodefine.h"
 *------------------------------------------------------------------------------
 * Declaration  : void PowerON_Reset_PC(void);
 *------------------------------------------------------------------------------
 * Description  : Executes the CPU initialization processing to register 
 *              : the power-on reset vector to the exception vector table.
 *------------------------------------------------------------------------------
 * Argument     : void
 *------------------------------------------------------------------------------
 * Return Value : void
 *------------------------------------------------------------------------------
 * Note         : This function is executed first after power-on reset.
 *""FUNC COMMENT END""**********************************************************/
void PowerON_Reset_PC(void)
{
	/* ==== Floating Point Status/Control Register setting ==== */
	set_fpscr(FPSCR_Init);

	/* ==== Hardware initialization ==== */
	HardwareSetup();				/* HardwareSetup function */

	/* ==== Sections initialization ==== */
	_INITSCT();

	/* ==== Vector Base Register setting ==== */
	set_vbr((void *)((char *)&INT_Vectors - INT_OFFSET));

	/* ==== IO library initialization ==== */
	//_INIT_IOLIB();

	/* ==== Status Register setting ==== */
	set_cr(SR_Init);
	nop();

	/* ==== Bunk Number Register setting ==== */
	INTC.IBNR.BIT.BE = 0x01;		/* Use of register banks enabled for all */
									/*  interrupts except NMI and user break */

	/* ==== Interrupt enabling ==== */
	set_imask(0);					/* Interrupt mask bits clear */

	/* ==== Main function call ==== */
	main();

	/* ==== Sleep instruction execution ==== */
	sleep();
}

//#pragma entry Manual_Reset_PC		/* Remove the comment when you use Manual Reset */
/*""FUNC COMMENT""**************************************************************
 * ID           : 
 * Outline      : Manual reset processing
 *------------------------------------------------------------------------------
 * Include      : 
 *------------------------------------------------------------------------------
 * Declaration  : void Manual_Reset_PC(void);
 *------------------------------------------------------------------------------
 * Description  : Registers the manual reset vector to the exception vector table.
 *------------------------------------------------------------------------------
 * Argument     : void
 *------------------------------------------------------------------------------
 * Return Value : void
 *------------------------------------------------------------------------------
 * Note         : This sample does not describe the processing content at all.
 *              : Add the program in this function as needed.
 *""FUNC COMMENT END""**********************************************************/
void Manual_Reset_PC(void)
{
	/* NOP */
}

/* END of File */
