/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS RSKSH2A7264 Starterkit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/


/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/
#define LED0 (1ul << 6)
#define LED1 (1ul << 7)
#define LED_ALL  LED0 | LED1

#define PJDR0  (*(volatile OS_U16*)(0xFFFFE3916)) // Data register
#define PJIOR0 (*(volatile OS_U16*)(0xFFFFE3912)) // Data direction register


/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/
//PJ6
//PJ7
//PJ8

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Configure port pins connected to LEDs, set Port mode
  //
  PJIOR0 |= LED_ALL;   // Set led pins to output
  PJDR0  &= ~LED_ALL;	// Clear leds
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PJDR0 |= LED0;
  } else if (Index == 1){
	  PJDR0 |= LED1;
  }	  
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PJDR0 &= ~LED0;
  } else if (Index == 1){
	  PJDR0 &= ~LED1;
  }	  
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    PJDR0 ^= LED0;
  } else if (Index == 1){
	  PJDR0 ^= LED1;
  }	  
}

/****** EOF *********************************************************/


