/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/

/* Copyright (C) 2009. Renesas Technology Europe, All Rights Reserved */

/*FILE COMMENT******************************* Technical reference data ****
* File Name		: bus_init.c
* Version 		: 1.00
* Device 		: SH/7264 (R5S72643W144FPU)
* Tool Chain 	: HEW, Renesas SuperH Standard Tool chain v9.3
* H/W Platform	: RSK2+SH7264
* Description 	: External memory bus initialization
******************************************************************************/

/******************************************************************************
* History 		: 12.11.2009 Ver. 1.00 First Release
*FILE COMMENT END*********************************************************/

/******************************************************************************
System Includes
******************************************************************************/
/* 	This header file provides access to intrinsic functions useful for 
	configuring and controlling the interrupts. */
#include <machine.h>

/******************************************************************************
User Includes (Project level includes)
******************************************************************************/
/*	Following header file provides a structure to access on-chip I/O 
    registers. */
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "rsksh7264def.h"
/*	Following header file provides prototype for the functions contained in this
	file. */
#include "bus_init.h"

/******************************************************************************
Compiler Directives
******************************************************************************/
/* '#pragma section' instructs the linker to place all subsequent code in 
    the named section. This can be used to relocate code in the memory map. 
	Use of the directive without the section name will reset the section
	to default. */

/******************************************************************************
User Program Code
******************************************************************************/

/*FUNC COMMENT*************************************************************
* Outline 		: ConfigureBusAndMemory
* Description 	: Configures the external bus and memory. 
* Argument  	: none
* Return value  : none
*FUNC COMMENT END*********************************************************/

void ConfigureBusAndMemory(void)
{
	/* Configure the CS0 space.	*/
	init_bsc_cs0();

	/* Configure the CS3 space.	*/
	init_bsc_cs3();
	
	/* Configure and initialize the cache memory */
	io_init_cache();
	
	/* Cache write back */
	io_cache_writeback();
}
/******************************************************************************
End of function ConfigureBusAndMemory
******************************************************************************/

/*FUNC COMMENT*************************************************************
* Outline 		: init_bsc_cs0
* Description 	: configures the NOR flash memory connected to CS0 space. 
* Argument  	: none
* Return value  : none
*FUNC COMMENT END*********************************************************/

void init_bsc_cs0 (void)
{
	/* Configure the port pins PB22-PB20 as external address A22-A20 pins */
	PORT.PBCR5.WORD = 0x0111;
	
	/* Configure the port pin PC3 as WE0n */
	PORT.PCCR0.BIT.PC3MD   = 1u;	
	/* Configure the port pin PC1 as RDn */
	PORT.PCCR0.BIT.PC1MD   = 1u;	
	/* Configure the port pin PC0 as CS0n */
	PORT.PCCR0.BIT.PC0MD   = 1u;	
	
	/* Configure the port pins PD15-PD12 as external data D15-D12 pins */
	PORT.PDCR0.WORD = 0x1111;
	/* Configure the port pins PD11-PD8 as external data D11-D8 pins */
	PORT.PDCR1.WORD = 0x1111;
	/* Configure the port pins PD7-PD4 as external data D7-D4 pins */
	PORT.PDCR2.WORD = 0x1111;
	/* Configure the port pins PD3-PD0 as external data D3-D0 pins */
	PORT.PDCR3.WORD = 0x1111;

	/* Configure the port pins PB3-PB1 as external address A3-A1 pins */
	PORT.PBCR0.WORD = 0x1110;
	/* Configure the port pins PB7-PB4 as external address A7-A4 pins */
	PORT.PBCR1.WORD = 0x1111;
	/* Configure the port pins PB11-PB8 as external address A11-A8 pins */
	PORT.PBCR2.WORD = 0x1111;
	/* Configure the port pins PB15-PB12 as external address A15-A12 pins */
	PORT.PBCR3.WORD = 0x1111;
	/* Configure the port pins PB19-PB16 as external address A19-A16 pins */
	PORT.PBCR4.WORD = 0x1111;

	/* Configure the CS0 Space Wait Control Register
	   b1:b0	- HW			- 01 (0.5 Delay cycles RD, WEn Negation to Address,
									  CS0 Negation)
	   b5:b2	- Reserved		- Set to 0000
	   b6		- WM			- 1 (External wait input is ignored)
	   b10:b7	- WR			- 0110 (6 Wait cycles for Access)
	   b12:b11	- SW			- 01 (1.5 cycles of Delay Cycles from Address, 
	   								  CS0 Assertion to RD, WEn Assertion)
	   b19:b13	- Reserved		- Set to 0000000
	   b20		- BAS			- 0 (Asserts the WEn signal at the read/write 
	   								 timing and asserts the RD/WR signal during
									 the write access cycle)
	   b31:b21	- Reserved		- Set to 00000000000 */

	BSC.CS0WCR.NORMAL.LONG = 0x00000b41ul;

	/* Configure CS0 Space Bus Control Register (CS0BCR) 
	   b8:b0	- Reserved		- Set to 000000000
	   b10:b9	- BSZ			- 10 	(16 bit Data Bus)
	   b11		- ENDIAN		- 0  	(Big Endian)
	   b14:b12	- TYPE			- 000	(Normal space)
	   b15		- Reserved		- Set to 0	
	   b18:b16	- IWRRS			- 000  	(No Idle cycle)
	   b21:b19	- IWRRD			- 000  	(No Idle cycle)
	   b24:b22	- IWRWS			- 000  	(No Idle cycle)
	   b27:b25	- IWRWD			- 000  	(No Idle cycle)
	   b30:b28	- IWW			- 001  	(1 Idle cycle between Write-Read Cycles and 
	   									 Write-Write Cycles)
	   b31		- Reserved		- Set to 0 */			
	   
	BSC.CS0BCR.LONG = 0x10000400ul;	
}
/******************************************************************************
End of function init_bsc_cs0
******************************************************************************/

/* It is placed in the CS0 cache-disabled */ 
#pragma section CACHE

/*FUNC COMMENT*************************************************************
* Outline 		: io_init_cache
* Description 	: Instruction/operand cache are flushed and enabled. 
* Argument  	: none
* Return value  : none
* Notice     	: The section name of this function is changed to be placed in 
*            	  the cache-disabled.
*            	  When this function is used only in the state of interrupt level 15,
*	              the setting and clearing of interrupt mask need not be processed.
*FUNC COMMENT END*********************************************************/

void io_init_cache(void)
{ 
	volatile unsigned long reg;
	int mask;

	/* Save interrupt mask setting */
	mask = get_imask();
	
	/* Mask all interrupts */
	set_imask(15);					

	/* Configure Cache Control Register 1 (CCR1)
	   b0		- OCE			- 1 (Operand cache enable)
	   b1		- WT			- 0 (Write-back mode)
	   b2		- Reserved		- Set to 0
	   b3		- OCF			- 1 (Operand Cache Flush)
	   b7:b4	- Reserved		- Set to 0000
	   b8		- ICE			- 1 (Instruction cache enable)
	   b10:b9	- Reserved		- Set to 00 
	   b11		- ICF			- 1 (Instruction Cache Flush)
	   b31:b12	- Read Only		- Set to 00000000000000000000	*/

	CCNT.CCR1.LONG = 0x00000909ul;		

	/* Read back the cache register */
	reg = CCNT.CCR1.LONG ;

	/* Restore interrupt mask level */
	set_imask(mask);					
}
/******************************************************************************
End of function io_init_cache
******************************************************************************/

/*FUNC COMMENT*************************************************************
* Outline 		: io_cache_writeback
* Description 	: All lines of operand cache are disabled, and the contents of 
*            	  cache memory are written back to the external memory. 
* Argument  	: none
* Return value  : 0 - Normal completion
*FUNC COMMENT END*********************************************************/

short io_cache_writeback(void)
{ 
	volatile unsigned long *arry;
	unsigned short i,j;
	int mask;

	/* Save interrupt mask setting */
	mask = get_imask();
	
	/* Mask all interrupts */
	set_imask(15);					
	
	/* Disable all entries */
	for(i = 0u; i < 4u; i++)
	{
		for(j = 0u; j < 128u; j++)
		{
			/* Creating an array address */
			arry = (volatile unsigned long *)(0xf0800000 | (i<<11) | (j<<4));
			
			/* Write U = 0 and V = 0 in the address array */
			*arry &= 0xfffffffcul;
		}
	}
	
	/* Restore interrupt mask level */
	set_imask(mask);					
	
	return 0;
}
/******************************************************************************
End of function io_cache_writeback
******************************************************************************/
#pragma section

/*FUNC COMMENT*************************************************************
* Outline 		: init_bsc_cs3
* Description 	: Configures the SDRAM connected to CS3 space 
* Argument  	: none
* Return value  : none
*FUNC COMMENT END*********************************************************/

void init_bsc_cs3 (void)
{	
	/* 200usec delay count	*/
	volatile short j = 133;					
	
	/* Configure the port pin PC8 as CS3n */
	PORT.PCCR2.BIT.PC8MD = 1u;				
	/* Configure the port pin PC7 as CKE */
	PORT.PCCR1.BIT.PC7MD = 1u;
	/* Configure the port pin PC6 as CASn */
	PORT.PCCR1.BIT.PC6MD = 1u;	
	/* Configure the port pin PC5 as RASn */
	PORT.PCCR1.BIT.PC5MD = 1u;			
	/* Configure the port pin PC4 as DQMUn */
	PORT.PCCR1.BIT.PC4MD = 1u;				
	/* Configure the port pin PC3 as DQMLn */
	PORT.PCCR0.BIT.PC3MD = 1u;	
	/* Configure the port pin PC2 as RD/WR# */
	PORT.PCCR0.BIT.PC2MD = 1u;				

	/* Settling time before configuring SDRAM */
	while(j-- > 0)
	{
		/* delay loop of 200 us */
	}

	/* Configure the CS3 Bus Control Register 
		   b8:b0	- Reserved		- Set to 000000000
		   b10:b9	- BSZ			- 10 	(16 bit Data Bus)
		   b11		- ENDIAN		- 0  	(Big Endian
		   b14:b12	- TYPE			- 100	(SDRAM)
		   b15		- Reserved		- Set to 0
		   b18:b16	- IWRRS			- 000  	(No Idle cycle)
		   b21:b19	- IWRRD			- 000  	(No Idle cycle)
		   b24:b22	- IWRWS			- 000  	(No Idle cycle)
		   b27:b25	- IWRWD			- 000  	(No Idle cycle)
		   b30:b28	- IWW			- 000  	(No Idle cycle)
		   b31		- Reserved		- Set to 0 */
		   
	BSC.CS3BCR.LONG = 0x00004400ul;
									
	/* Configure the CS3 Space Wait Control Register 
	   b1:b0	- WTRC			- 10 ( 5 idle cycles from REF Command/Self
									   Refresh Release to ACTV/REF/MRS Command )
	   b2		- Reserved		- Set to 0
	   b4:b3	- TRWL			- 01 ( 1 wait cycle for Auto-Precharge Startup )
	   b6:b5	- Reserved		- Set to 00
	   b8:b7	- A3CL			- 01 ( 1 cycle CAS Latency for Area 3)
	   b9		- Reserved		- Set to 0
	   b11:b10	- WTRCD			- 10 ( 2 wait cycles between ACTV Command and 
	   									READ(A)/WRIT(A) Command )
	   b12		- Reserved		- Set to 0
	   b14:b13	- WTRP			- 01 ( 1 wait cycle for Auto-Precharge Completion )
	   b31:b15	- Reserved		- Set to 000000000000000000 */
	
	BSC.CS3WCR.SDRAM.LONG = 0x0000288aul;
										
	/* Configure the SDRAM Control Register 
	   b1:b0	- A3COL			- 10  ( 10 Bits of Column Address for Area 3)
	   b2		- Reserved		- Set to 0
	   b4:b3	- A3ROW			- 10  ( 13 Bits of Row Address for Area 3)
	   b7:b5	- Reserved		- Set to 000
	   b8		- BACTV			- 0   ( Auto-precharge mode )
	   b9		- PDOWN			- 0   ( Power-Down Mode Disable)
	   b10		- RMODE			- 0   ( Auto-refresh is performed)
	   b11		- RFSH			- 1   ( Refresh Action is performed )
	   b12		- SLOW			- 0   ( Command, address, write data and read 
	   									data on rising edge of CKIO )
	   b13		- DEEP			- 0   ( Self-refresh mode )
	   b15:b14	- Reserved		- Set to 00
	   b17:b16	- A2COL			- 00  ( 8 Bits of Column Address for Area 2 )
	   b18		- Reserved		- Set to 0
	   b20:b19	- A2ROW			- 00  ( 11 Bits of Row Address for Area 2 )
	   b31:b20	- Reserved		- Set to 00000000000 */
	
	BSC.SDCR.LONG = 0x00000812ul;
										
	/* Configure the Refresh Time Constant Register
	   15.625us/222ns = 70(0x46)cycles per refresh 
	   b7:b0	- RTCOR			- 0x46 ( 70 cycles per refresh)
	   b15:B8	- Reserved		- 0x00 (Reserved)
	   b31:b16	- Read Only		- 0xA55A */   
	   
	BSC.RTCOR = 0xa55a0046ul;		
	
	/* Configure the Refresh Timer Control/Status Register 
	   b2:b0	- RRC			- 000 ( 1 continuous refresh cycles)
	   b5:b3	- CKS			- 010 ( Bphi/16)
	   b6		- CMIE			- 0	  ( Disables CMF interrupt requests)
	   b7		- CMF			- 0   ( Clear Compare Match Flag)
	   b15:B8	- Reserved		- Set to 00 
	   b31:b16	- Read Only		- 0xA55A	*/		
	
	BSC.RTCSR.LONG = 0xa55a0010ul;	

	/* Write to SDRAM Mode Register to enable SDRAM
		The writing data is arbitrary
		SDRAM mode register setting CS3 space
		Burst read (burst length 1)/Burst write	*/
		
	SDRAM_MODE = 0;						
}
/******************************************************************************
End of function init_bsc_cs3
******************************************************************************/
