/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/

/* Copyright (C) 2009. Renesas Technology Europe, All Rights Reserved */

/*FILE COMMENT******************************* Technical reference data ****
* File Name		: resetprg.c
* Version 		: 1.00
* Device 		: SH/7264 (R5S72643W144FPU)
* Tool Chain 	: HEW, Renesas SuperH Standard Tool chain v9.3
* H/W Platform	: RSK2+SH7264
* Description 	: Reset program
******************************************************************************/

/******************************************************************************
* History 		: 12.11.2009 Ver. 1.00 First Release
*FILE COMMENT END*********************************************************/

/******************************************************************************
System Includes
******************************************************************************/
/*	Following header file provides access to intrinsic functions to control 
	interrupt levels. */
#include <machine.h>
/* Following header file provides access to intrinsic functions _INITSCT(). */
#include <_h_c_lib.h>

/******************************************************************************
User Includes (Project level includes)
******************************************************************************/
/* Following header file is used by __entry directive to set the initial 
   stack pointer. The value in this file should only be changed if relocating
   and / or changing the size of the stack. */
#include "stacksct.h"
/*	Following header file provides macros & prototypes for the functions used 
	in this file.	*/
#include "resetprg.h"
/*	Following header file provides a structure to access on-chip I/O
    registers. */
#include "iodefine.h"

/******************************************************************************
Compiler Directives
******************************************************************************/
/* '#pragma section' instructs the linker to place all subsequent code in the 
named section. This can be used to relocate code in the memory map. 
Use of the directive without the section name will reset the section to 
default. */

/* The function specified with the compiler directive '#pragma entry' is treated 
as an entry function. The entry function is created without any code to save and 
restore the contents of registers. 
When SH-3, SH3-DSP, SH-4, SH-4A, or SH4AL-DSP is specified as the CPU and
sp=<constant> is specified, or #pragma stacksize is declared, the code that
makes the initial setting of the stack pointer will be output at the beginning
of the function. 
When cpu=sh1, sh2, sh2e, sh2a, sh2afpu or sh2dsp has been specified, the
specification of sp=<constant> will be invalid. */

/******************************************************************************
User Program Code
******************************************************************************/

/*FUNC COMMENT*************************************************************
* Outline 		: PowerON_Reset_PC
* Description 	: Power on reset function.
*			      This function executes following a power on reset.
*				  It first calls hardware initialisation function & then 'main()' 
*				  function.	
* Argument  	: none
* Return value  : none
*FUNC COMMENT END*********************************************************/

#pragma entry PowerON_Reset_PC
#pragma section ResetPRG
void PowerON_Reset_PC(void)
{
	/* Configure Floating-Point Status/Control Register	*/
	set_fpscr(FPSCR_Init);

	/* Initialize the hardware */	 
	HardwareSetup();
		
	/* Copy initialized data from ROM to RAM */ 
	_INITSCT();
	
	/* Set Vector Base Register */
	set_vbr((void *)((char *)&INT_Vectors - INT_OFFSET));

	/* Reset Status Register */ 
	set_cr(SR_Init);
	nop();

	/* Use the separate register bank for interrupts */
	INTC.IBNR.BIT.BE = 0x01;	
	
	/* Disable interrupt mask */
	set_imask(0);

	/* Call user program */ 	
	main();
	
	/* End of user program */ 
	sleep();
}
#pragma section
/******************************************************************************
End of function PowerON_Reset_PC
******************************************************************************/

/*FUNC COMMENT*************************************************************
* Outline 		: Manual_Reset_PC
* Description 	: Manual reset function.
* Argument  	: none
* Return value  : none
*FUNC COMMENT END*********************************************************/

void Manual_Reset_PC(void)	
{
	/* Call Power ON reset function	*/
	PowerON_Reset_PC();
}
/******************************************************************************
End of function Manual_Reset_PC
******************************************************************************/
