/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : RTOSInit_SH2A7269.c for Renesas SH2A7269 and RSKSH2A7269 
Purpose : Initializes and handles the hardware for embOS as far
          as required by embOS.
          Feel free to modify this file acc. to your target system.
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "RTOS.h"

/*********************************************************************
*
*                    Configuration
*
**********************************************************************
*/

/*********************************************************************
*
*       Clock frequency settings
*/
#ifndef   OS_FSYS                   /* CPU Main clock frequency     */
  #define OS_FSYS (264500000uL)     /* Assume 264.5 MHz,            */
#endif                              /* 13.225 MHz oscillator        */

#ifndef   OS_PCLK_TIMER             /* Peripheral clock for timer   */
  #define OS_PCLK_TIMER (OS_FSYS/64)/* May vary from CPU clock      */
#endif                              /* depending on CPU             */

#ifndef   OS_PCLK_UART              /* Peripheral clock for UART    */
  #define OS_PCLK_UART (OS_FSYS/4)  /* May vary from CPU clock      */
#endif                              /* depending on CPU             */

#ifndef   OS_TICK_FREQ
  #define OS_TICK_FREQ (1000)
#endif
  
/*********************************************************************
*
*       Configuration of communication to OSView
*/
#ifndef   OS_VIEW_ENABLE            // Global enable of communication
  #define OS_VIEW_ENABLE    (1)     // Default: on
#endif  

#ifndef   OS_VIEW_USE_UART          // If set, UART will be used for communication
  #define OS_VIEW_USE_UART  (1)     // Default: 1 => Uart is used
#endif                              // if OS_VIEW_ENABLE is on

/*********************************************************************
*
*       UART settings for OSView
*       If you do not want (or can not due to hardware limitations)
*       to dedicate a UART to OSView, please define it to be -1
*       Uart 7 is supported. It is connected to the DB9 connector
*       on RSKSH2A7269 which is named "Serial".
*/
#ifndef   OS_UART
  #define OS_UART (7)
#endif

#ifndef   OS_BAUDRATE
  #define OS_BAUDRATE (38400)
#endif

#ifndef   ALLOW_NESTED_INTERRUPTS
  #define ALLOW_NESTED_INTERRUPTS (0)
#endif

/****** End of configurable options *********************************/

#define OS_UART_USED  ((OS_VIEW_ENABLE && (OS_VIEW_USE_UART != 0)) && (OS_UART == 7))

#if OS_UART_USED
  #define OS_COM_INIT() OS_COM_Init()
#else
  #define OS_COM_INIT()
#endif

#define OS_TIMER_RELOAD (OS_PCLK_TIMER / OS_TICK_FREQ)

/*********************************************************************
*
*       Check configuration
*
**********************************************************************
*/

#ifndef   DEBUG     /* Should normally be defined as project option */
  #define DEBUG  (0)
#endif

/*********************************************************************
*
*       Local defines (sfrs used in RTOSInit.c)
*
**********************************************************************
*/

/*********************************************************************
*
*		SFRs used in RTOSInit
*/

/* Module stop register */     
#define STB_BASE_ADDR       (0xFFFE0000)
#define STBCR4              (*(volatile OS_U8* ) (STB_BASE_ADDR + 0x040C))
#define STBCR7              (*(volatile OS_U8* ) (STB_BASE_ADDR + 0x0418))

/* Compare match timer */
#define CMT_BASE_ADDR       (0xFFFEC000)
#define CMSTR               (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x00))
#define CMCSR_0             (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x02))
#define CMCNT_0             (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x04))
#define CMCOR_0             (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x06))

#define CMT_CMSR0_CMF_BIT   (7)
#define CMT_MODULE_ID_BIT   (2)

/* Interrupt controller */
#define INTC_BASE_ADDR      (0xFFFE0800)
#define INTC_IBNR           (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x000e)) 
#define INTC_IPR12          (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x040C)) 
#define INTC_IPR21          (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x041E)) 

#define INTC_CMT0_PRIO_REG  INTC_IPR12
#define CMT0_PRIO_POS       (12)
#define CMT0_PRIO_MASK      (~(0x0F << CMT0_PRIO_POS))

/* Uart */
#define SCIF7_BASE_ADDR     (0xE800A800)
#define SCIF_BASE_ADDR      (SCIF7_BASE_ADDR)
#define BAUDDIVIDE          (((OS_PCLK_UART+(OS_BAUDRATE*16L))/(OS_BAUDRATE*32L))-1)
#define SCIFx_MODULE_ID_BIT (0)
#define INTC_SCIFx_PRIO_REG (INTC_IPR21)
#define SCIFx_PRIO_POS      (0)

#define PECR1               (*(volatile OS_U16*) (0xFFFE388C))  // Port E control register 1
#define PJCR3               (*(volatile OS_U16*) (0xFFFE3908))  // Port J control register 3

#define SCIFx_SCSMR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x00)) 
#define SCIFx_SCBRR         (*(volatile OS_U8*) (SCIF_BASE_ADDR + 0x04)) 
#define SCIFx_SCSCR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x08)) 
#define SCIFx_SCFTDR        (*(volatile OS_U8*) (SCIF_BASE_ADDR + 0x0C)) 
#define SCIFx_SCFSR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x10)) 
#define SCIFx_SCFRDR        (*(volatile OS_U8*) (SCIF_BASE_ADDR + 0x14)) 
#define SCIFx_SCFCR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x18)) 
#define SCIFx_SCFDR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x1C)) 
#define SCIFx_SCSPTR        (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x20)) 
#define SCIFx_SCLSR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x24)) 
#define SCIFx_SCEMR         (*(volatile OS_U16*)(SCIF_BASE_ADDR + 0x28)) 

#define SCSCR_REIE_BIT      (3)
#define SCSCR_RE_BIT        (4)
#define SCSCR_TE_BIT        (5)
#define SCSCR_RIE_BIT       (6)
#define SCSCR_TIE_BIT       (7)
#define SCFSR_RDRF_BIT      (1)
#define SCFSR_TDRE_BIT      (5)
#define SCFSR_MPBT_BIT      (0)
#define SCFSR_MPB_BIT       (1)
#define SCFSR_TEND_BIT      (2)
#define SCFSR_PER_BIT       (3)
#define SCFSR_FER_BIT       (4)
#define SCFSR_OVR_BIT       (5)

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/

/*********************************************************************
*
*		Local functions
*
**********************************************************************
*/

/*********************************************************************
*
*		_IsrTickHandler()
*/
static void _IsrTickHandler(void) {
  /* Clear the interrupt flag	*/
  CMCSR_0 &= ~(1uL << CMT_CMSR0_CMF_BIT);
  OS_TICK_Handle();
}

/*********************************************************************
*
*		Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       OS_ISR_Tick(), the embOS timer interrupt handler
*/
#pragma interrupt (OS_ISR_Tick(resbank))
void OS_ISR_Tick(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrTickHandler);
  #else
    OS_CallISR(_IsrTickHandler);
  #endif
}

/*********************************************************************
*
*       OS_InitHW()
*
*       Initialize the hardware (timer) required for the OS to run.
*       May be modified, if an other timer should be used
*/
void OS_InitHW(void) {
  OS_IncDI();                       // For Safety disable interrupts

  //
  // Enable module clock for CMT and initialize CMT
  //
  STBCR7 &= ~(1 << CMT_MODULE_ID_BIT);              
  CMSTR  &= ~(1 << 0);              // Stop counter channel 0
  CMCOR_0 = OS_TIMER_RELOAD;        // Initialize compare value
  CMCNT_0 = 0;                      // Reset counter
  CMCSR_0 = 0                       // Set divider to 1/8
          | (1 << 6);               // Compare match interrupt enable
  INTC_CMT0_PRIO_REG &= CMT0_PRIO_MASK;
  INTC_CMT0_PRIO_REG |= (1uL << CMT0_PRIO_POS);         // Set interrupt priority, enable lowest

  CMSTR  |= (1 << 0);               // Start timer

  INTC_IBNR = 0
             | (1 << 14)  // Enable Bank switching for all interrupts
             | (0 << 13); // 1: => Enable Bank Overflow interrupt
 
  OS_COM_INIT();                    // Initialize UART for embOSView
  OS_SetFastIntPriorityLimit(8);    // Set Priority limit for "Fast" interrupts 
  OS_DecRI();
}

/*********************************************************************
*
*       OS_Idle()
*
*       Please note:
*       This is basically the "core" of the idle loop.
*       This core loop can be changed, but:
*       The idle loop does not have a stack of its own, therefore no
*       functionality should be implemented that relies on the stack
*       to be preserved. However, a simple program loop can be programmed
*       (like toggeling an output or incrementing a counter)
*/
void OS_Idle(void) {    // Idle loop: No task is ready to execute
  while (1) {           // Nothing to do ... wait for interrupt
    #if (DEBUG == 0)
                        // Switch CPU into sleep mode
    #endif
  }
}

/*********************************************************************
*
*       OS_GetTime_Cycles()
*
*       This routine is required for task-info via OSView or high
*       resolution time measurement functions.
*       It returns the system time in timer clock cycles.
*/
OS_U32 OS_GetTime_Cycles(void) {
  OS_U32 Time;
  OS_U32 Cnt;
  
  Time = OS_GetTime32();
  Cnt  = CMCNT_0;
  //  
  // Check if timer interrupt pending ...
  // 
  if ((CMCSR_0 & (1 << 7)) != 0) {  
    Cnt = CMCNT_0;  // Interrupt pending, re-read timer and adjust result
    Time++;
  } 
  return (OS_TIMER_RELOAD * Time) + Cnt;
}

/*********************************************************************
*
*       OS_ConvertCycles2us()
*
*       Convert Cycles into micro seconds.
*
*       If your clock frequency is not a multiple of 1 MHz,
*       you may have to modify this routine in order to get proper
*       diagnostics.
*
*       This routine is required for profiling or high resolution time
*       measurement only. It does not affect operation of the OS.
*/
OS_U32 OS_ConvertCycles2us(OS_U32 Cycles) {
  return Cycles/(OS_PCLK_TIMER/1000000);
}

/*********************************************************************
*
*       Optional communication with embOSView
*
**********************************************************************
*/

#if OS_UART_USED

/*********************************************************************
*
*		_IsrUartRxHandler()
*/
static void _IsrUartRxHandler(void) {
  if (SCIFx_SCFSR & (1 << SCFSR_RDRF_BIT)) {
    OS_U8 Data;
    Data = SCIFx_SCFRDR;      // Get data
    SCIFx_SCFSR &= ~(1 << SCFSR_RDRF_BIT);  
    OS_OnRx(Data);             // Process data
  }
}

/*********************************************************************
*
*		_IsrUartTxHandler()
*/
static void _IsrUartTxHandler(void) {
  if (OS_OnTx()) {
    SCIFx_SCSCR &= ~(1 << SCSCR_TIE_BIT);      // Disable Tx-Int
  }
}

/*********************************************************************
*
*		_IsrUartErrHandler()
*/
static void _IsrUartErrHandler(void) {
  SCIFx_SCSCR  &= ~(0x50);   // disable Rx and Rx-Int
  while (SCIFx_SCFSR & ((1 << 7) | (1 << 4) | (1 << 3) | (1 << 2))) {  // Any error (ER, BRK, FER, PER)?
    SCIFx_SCFSR    &= ~((1 << 7) | (1 << 4) | (1 << 3) | (1 << 2));    // Clear error and Rx data flags 
  }   
  while (SCIFx_SCFSR & (1 << 0)) {  // Overrun error ?
    SCIFx_SCFSR &= ~(1 << 0);       // Clear error
  }   
  SCIFx_SCSCR |= 0x50;     // Reenable Rx and Rx-Int
}

/*********************************************************************
*
*       OS_COM_Init()
*/
void OS_COM_Init(void) {
  int i;
  //
  // Configure the port pins connected to UART
  //
  PECR1 |= 0x2000;       // Set Pins to uart function
  PJCR3 |= 0x5000;       // Set Pins to uart function
  //
  // Enable selected UART peripheral
  //
  STBCR4 &= ~(1 << SCIFx_MODULE_ID_BIT);              
  //
  // Disable transmission, reception & serial interrupts
  //
  SCIFx_SCSCR = 0x0000;
  //
  // Initializes the serial mode register
  //
  SCIFx_SCSMR = 0x0000    // B15:B8 - Reserved - Set to 0
               | (0 << 7)  // B7 - Communication mode; 0: Asynchronous
               | (0 << 6)  // B6 - Character length;   0: 8 bit data
               | (0 << 5)  // B5 - Parity Enable;      0: No Parity
               | (0 << 4)  // B4 - Parity mode;        0: N/A (set to 0)
               | (0 << 3)  // B3 - Stop bit length;    0: 1 stop bit
               | (0 << 2)  // B2 - Reserved - Set to 0
               | (0 << 0)  // B1:B0 - Clock Select     0: Select Pphi as source clock
               ;
  //
  // Initialize Baudrate generator
  //
  SCIFx_SCBRR = BAUDDIVIDE;
  for(i=0 ; i < 10500 ; i++) {
    /* Setting delay (1 bit cycle) */
  }
  //
  // Initialize serial status register
  //
  SCIFx_SCFSR = 0x0000;
  //
  // Set interrupt priority for SCI, enables interrupt
  //
  INTC_SCIFx_PRIO_REG = (0x01 << SCIFx_PRIO_POS);
  //
  // Enable transmission, reception and receive interrupts
  //
  SCIFx_SCSCR |= 0x0070;
}

/*********************************************************************
*
*       OS_COM_Send1()
*       Send one character via UART.
*       Never call this function from your application
*/
void OS_COM_Send1(OS_U8 c) {
  SCIFx_SCFTDR  = c;
  SCIFx_SCFSR  &=~(1 << SCFSR_TDRE_BIT);     // Clear Tx Empty Flag
  SCIFx_SCSCR  |= (1 << SCSCR_TIE_BIT);      // Enable Tx-Int
}

/*********************************************************************
*
*       OS_ISR_rx()
*/
#pragma interrupt (OS_ISR_Rx(resbank))
void OS_ISR_Rx(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartRxHandler);
  #else
    OS_CallISR(_IsrUartRxHandler);
  #endif
}

/*********************************************************************
*
*       OS_ISR_tx()
*/
#pragma interrupt(OS_ISR_Tx(resbank))
void OS_ISR_Tx (void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartTxHandler);
  #else
    OS_CallISR(_IsrUartTxHandler);
  #endif
}

/*********************************************************************
*
*       OS_ISR_RxErr()
*/
#pragma interrupt (OS_ISR_RxErr(resbank))
void OS_ISR_RxErr(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartErrHandler);
  #else
    OS_CallISR(_IsrUartErrHandler);
  #endif
}

#else  /* UART for communication not used, define dummy functions */

void OS_COM_Send1(OS_U8 c) {
  OS_USEPARA(c);           /* Avoid compiler warning */
  OS_COM_ClearTxActive();  /* Let the OS know that Tx is not busy */
}
#endif 

/****** End Of File *************************************************/
