/******************************************************************************
*   DISCLAIMER
*
*   This software is supplied by Renesas Electronics Corp. and is only 
*   intended for use with Renesas products. No other uses are authorized.
*
*   This software is owned by Renesas Electronics Corp. and is protected under 
*   all applicable laws, including copyright laws.
*
*   THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES 
*   REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, 
*   INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
*   PARTICULAR PURPOSE AND NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY 
*   DISCLAIMED.
*
*   TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, NEITHER RENESAS 
*   ELECTRONICS CORP. NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE 
*   FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES 
*   FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR ITS
*   AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*
*   Renesas reserves the right, without notice, to make changes to this 
*   software and to discontinue the availability of this software.
*   By using this software, you agree to the additional terms and 
*   conditions found by accessing the following link: 
*   http://www.renesas.com/disclaimer
********************************************************************************
*   Copyright (C) 2010 Renesas Electronics Corporation. All rights reserved.
*""FILE COMMENT""*********** Technical reference data **************************
*   System Name : SH7268/SH7269 Sample Program
*   File Name   : bsc_cs0.c
*   Abstract    : SH7268/SH7269 Initial Settings
*   Version     : 0.01.00
*   Device      : SH7268/SH7269
*   Tool-Chain  : High-performance Embedded Workshop (Ver.4.07.00).
*               : C/C++ compiler package for the SuperH RISC engine family
*               :                              (Ver.9.03Release02).
*   OS          : None
*   H/W Platform: R0K57269(CPU board)
*   Description : 
********************************************************************************
*   History     : Sep.6,2010 Ver.0.01.00
*""FILE COMMENT END""**********************************************************/
#include "iodefine.h"


/*  CS0 PAGEMODE setting */
//#define PAGEMODE

/* ==== Prototype Declaration ==== */
void io_init_bsc_cs0(void);

#pragma section ResetPRG
/*""FUNC COMMENT""**************************************************************
 * ID          : 
 * Outline     : CS0 setting
 *------------------------------------------------------------------------------
 * Include     : #include "iodefine.h"
 *------------------------------------------------------------------------------
 * Declaration : void io_init_bsc_cs0(void);
 *------------------------------------------------------------------------------
 * Description : Pin function controller (PFC) and bus state controller (BSC) 
 *             : are set, and the access timing to the Flash Memory of CS0 space
 *             : is set.
 *             : The PFC setting is set by bit manipulation not to change the PFC 
 *             : set value which is set by other process.
 *------------------------------------------------------------------------------
 * Argument    : void
 *------------------------------------------------------------------------------
 * Return Value: void
 *------------------------------------------------------------------------------
 * Note        : None
 *""FUNC COMMENT END""**********************************************************/
void io_init_bsc_cs0(void)
{
	/* Configure the port pins as external address A24-A21 pins */
	PORT.PBCR5.BIT.PB21MD  = 1u;	/* Set A21 	*/
	/* Configure the port pin PC2 as WRn */
	PORT.PCCR0.BIT.PC2MD   = 1u;	/* Set WRn# */
	/* Configure the port pin PC3 as WE0n */
	PORT.PCCR0.BIT.PC3MD   = 1u;	/* Set WE0# */

	/* Configure the CS0 Space Wait Control Register 
	   for Normal Space, SRAM with Byte Selection, and MPX-I/O
	   
	   b1:b0	- HW			- 01 (1.5 Delay cycles RD, WEn Negation to Address,
									  CS0 Negation)
	   b5:b2	- Reserved		- Set to 0000
	   b6		- WM			- 1 (External wait input is ignored)
	   b10:b7	- WR			- 0110 (6 Wait cycles for Access)
	   b12:b11	- SW			- 00 (0.5 cycles of Delay Cycles from Address, 
	   								  CS0 Assertion to RD, WEn Assertion)
	   b19:b13	- Reserved		- Set to 0000000
	   b20		- BAS			- 0 (Asserts the WEn signal at the read/write 
	   								 timing and asserts the RD/WR signal during
									 the write access cycle)
	   b31:b21	- Reserved		- Set to 00000000000 */

	BSC.CS2WCR.NORMAL.LONG = 0x00000b41ul;

	/* Configure CS0 Space Bus Control Register (CS0BCR) 
	   b8:b0	- Reserved		- Set to 000000000
	   b10:b9	- BSZ			- 10 	(16 bit Data Bus)
	   b11		- ENDIAN		- 0  	(Big Endian)
	   b14:b12	- TYPE			- 001	(Burst ROM (clock asynchronous))
	   b15		- Reserved		- Set to 0	
	   b18:b16	- IWRRS			- 000  	(No Idle cycle)
	   b21:b19	- IWRRD			- 000  	(No Idle cycle)
	   b24:b22	- IWRWS			- 000  	(No Idle cycle)
	   b27:b25	- IWRWD			- 000  	(No Idle cycle)
	   b30:b28	- IWW			- 001  	(1 Idle cycle between Write-Read Cycles and 
	   									 Write-Write Cycles)
	   b31		- Reserved		- Set to 0 */
    BSC.CS2BCR.LONG = 0x00000400ul;
}

/* End of File */
