/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS RSKSH2A7264 Starterkit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/


/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/
#define LED0 (1ul << 1)
#define LED1 (1ul << 2)
#define LED_ALL  LED0 | LED1

#define PBIORH (*(volatile OS_U16*)(0xFFFE3884)) // Port B I/O register High
#define PBDRH  (*(volatile OS_U16*)(0xFFFE3880)) // Data register High

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Configure port pins connected to LEDs, set Port mode
  //
  PBIORH |= LED_ALL;  
  PBDRH  &= ~LED_ALL;	// Clear leds
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PBDRH |= LED0;
  } else if (Index == 1){
	  PBDRH |= LED1;
  }	  
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PBDRH &= ~LED0;
  } else if (Index == 1){
	  PBDRH &= ~LED1;
  }	  
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    PBDRH ^= LED0;
  } else if (Index == 1){
	  PBDRH ^= LED1;
  }	  
}

/****** EOF *********************************************************/
