/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : RTOSInit_SH7216.c            (for RENESAS SH2A SH7216)
Purpose : Initializes and handles the hardware for embOS as far
          as required by embOS.
          Feel free to modify this file acc. to your
          target system.
--------  END-OF-HEADER  ---------------------------------------------
*/
#include <machine.h>
#include "RTOS.h"
#include "iodefine.h"
#include "rsk7286def.h"

/*********************************************************************
*
*                    Configuration
*
**********************************************************************
*/

#ifndef   ALLOW_NESTED_INTERRUPTS
  #define ALLOW_NESTED_INTERRUPTS (0)
#endif

#ifndef OS_FSYS
  /* The PLL is initialized in the function                         */
  /* ConfigureOperatingFrequency() in hwsetup.c                     */
  #define OS_FSYS (100000000L)  /* Standard setting is 100 MHz      */
#endif

#ifndef   OS_PCLK_DIVIDER
  #define OS_PCLK_DIVIDER  (2)
#endif
  
#ifndef   OS_PCLK_TIMER
  #define OS_PCLK_TIMER (OS_FSYS / OS_PCLK_DIVIDER / 8)
#endif
  
/*********************************************************************
*
*       Configuration of communication to OSView
*/
#ifndef   OS_VIEW_ENABLE            // Global enable of communication
  #define OS_VIEW_ENABLE    (1)     // Default: on
#endif  

/*********************************************************************
*
*       UART settings for OSView
*       If you do not want (or can not due to hardware limitations)
*       to dedicate a UART to OSView, please define it to be -1
*       Currently UART0 and UART1 are supported and the standard
*       setup enables UART 0 per default
*       When using DCC for communiction, the UART is not used for embOSView,
*       regardless the OS_UART settings
*/
#ifndef   OS_UART
  #define OS_UART (3)
#endif

#ifndef   OS_BAUDRATE
  #define OS_BAUDRATE (38400)
#endif

#ifndef   OS_PCLK_UART
  #define OS_PCLK_UART (OS_FSYS / OS_PCLK_DIVIDER)
#endif

/******	End of configurable option **********************************/

#define OS_UART_USED (OS_VIEW_ENABLE && OS_UART == 3)

/*********************************************************************
*
*		Local defines
*
**********************************************************************
*/

/*********************************************************************
*
*		SFRs used in RTOSInit
*/
#define STB_BASE_ADDR  (0xFFFE0000)
#define STBCR4        (*(volatile OS_U8* ) (STB_BASE_ADDR + 0x040C))
#define STBCR5        (*(volatile OS_U8* ) (STB_BASE_ADDR + 0x0418))

#define CMT_BASE_ADDR (0xFFFEC000)
#define CMSTR         (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x00))
#define CMCSR_0       (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x02))
#define CMCNT_0       (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x04))
#define CMCOR_0       (*(volatile OS_U16*) (CMT_BASE_ADDR + 0x06))

#define CMT_CMSR0_CMF_BIT (7)
#define CMT_MODULE_ID_BIT (2)

#define INTC_BASE_ADDR (0xFFFE0800)
#define INTC_IBCR      (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x000c)) 
#define INTC_IBNR      (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x000e)) 
#define INTC_IPR08     (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x0404)) 
#define INTC_IPR10     (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x0408)) 
#define INTC_IPR13     (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x040E)) 
#define INTC_IPR14     (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x0410)) 
#define INTC_IPR16     (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x0414)) 
#define INTC_IPR17     (*(volatile OS_U16*) (INTC_BASE_ADDR + 0x0416)) 

#define INTC_CMT0_PRIO_REG    INTC_IPR08
#define CMT0_PRIO_POS         (12)
#define CMT0_PRIO_MASK        (~(0x0F << CMT0_PRIO_POS))
  
#define PAIORL       (*(volatile OS_U16*) (0xFFFE3806))
#define PACRL2       (*(volatile OS_U16*) (0xFFFE3814))
#define PACRL1       (*(volatile OS_U16*) (0xFFFE3816))  // Port A control register 1

#define SCIF1_BASE_ADDR      (0xFFFF8800)
#define SCIF_BASE_ADDR       (SCIF1_BASE_ADDR)
#define BAUDPRESCALE         (0)  // CKE bits: 0,1,2,3
#define BAUDDIVIDE           ((OS_PCLK_UART+(OS_BAUDRATE*16L))/(OS_BAUDRATE*32L))-1
#define SCIFx_MODULE_ID_BIT  (6)
#define INTC_SCIFx_PRIO_REG  (INTC_IPR16)
#define SCIFx_PRIO_POS       (8)

#define SCIFx_SCSMR  (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x00)) 
#define SCIFx_SCBRR  (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x02)) 
#define SCIFx_SCSCR  (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x04)) 
#define SCIFx_SCTDR  (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x06)) 
#define SCIFx_SCSSR  (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x08)) 
#define SCIFx_SCRDR  (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x0A)) 
#define SCIFx_SCSDCR (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x0C)) 
#define SCIFx_SCSPTR (*(volatile OS_U8*)(SCIF_BASE_ADDR + 0x0E)) 

#define SCSCR_REIE_BIT (3)
#define SCSCR_RE_BIT   (4)
#define SCSCR_TE_BIT   (5)
#define SCSCR_RIE_BIT  (6)
#define SCSCR_TIE_BIT  (7)

#define SCFSR_RDRF_BIT  (6)
#define SCFSR_TDRE_BIT  (7)

#define SCFSR_TEND_BIT  (2)
#define SCFSR_PER_BIT   (3)
#define SCFSR_FER_BIT   (4)
#define SCFSR_OVR_BIT   (5)

/*********************************************************************
*
*		Local functions
*
**********************************************************************
*/

/*********************************************************************
*
*		_IsrTickHandler()
*/
static void _IsrTickHandler(void) {
  /* Clear the interrupt flag	*/
  CMCSR_0 &= ~(1 << CMT_CMSR0_CMF_BIT);
  OS_TICK_Handle();
}

/*********************************************************************
*
*		Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       OS_ISR_Tick(), the embOS timer interrupt handler
*/
#pragma interrupt (OS_ISR_Tick(resbank))
void OS_ISR_Tick(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrTickHandler);
  #else
    OS_CallISR(_IsrTickHandler);
  #endif
}

/*********************************************************************
*
*		    OS_InitHW()
*
*  Initialize the hardware required for the OS to run. This will work
*  on any target hardware, but may have to be tailored a little
*  (regarding the clock frequency). Of course the same holds true
*  if for some reason you choose to use an other timer.
*  Per default we use the Compare match timer channel 0, which is an up-counter
*/
#define TIMER_RELOAD (OS_PCLK_TIMER / 1000)
void OS_InitHW(void) {
  OS_IncDI();                       // For Safety disable interrupts

  //
  // Enable module clock for CMT and initialize CMT
  //
  STBCR4 &= ~(1 << CMT_MODULE_ID_BIT);              
  CMSTR  &= ~(1 << 0);              // Stop counter channel 0
  CMCOR_0 = TIMER_RELOAD;           // Initialize compare value
  CMCNT_0 = 0;                      // Reset counter
  CMCSR_0 = 0                       // Set divider to 1/8
          | (1 << 6);               // Compare match interrupt enable
  INTC_CMT0_PRIO_REG &= CMT0_PRIO_MASK;
  INTC_CMT0_PRIO_REG |= (1 << CMT0_PRIO_POS);         // Set interrupt priority, enable lowest

  CMSTR  |= (1 << 0);               // Start timer

  INTC_IBNR = 0
             | (1 << 14)  // Enable Bank switching for all interrupts
             | (0 << 13); // 1: => Enable Bank Overflow interrupt
 
  OS_COM_Init();                    // Initialize UART for embOSView
  OS_SetFastIntPriorityLimit(8);    // Set Priority limit for "Fast" interrupts 
  OS_DecRI();
}

/*********************************************************************
*
*       Idle loop  (OS_Idle)
*
*  Please note:
*  This is basically the "core" of the idle loop.
*  This core loop can be changed, but:
*  The idle loop does not have a stack of its own, therefore no
*  functionality should be implemented that relies on the stack
*  to be preserved. However, a simple program loop can be programmed
*  (like toggeling an output or incrementing a counter)
*/
void OS_Idle(void) {          // Idle loop: No task is ready to exec
  for (;;);                   // Nothing to do ... wait for a interrupt
}

/*********************************************************************
*
*       Get time [cycles]
*
*  This routine is required for task-info via embOSView or high
*  resolution time measurement.
*  It returns the system time in clock cycles.
*/
OS_U32 OS_GetTime_Cycles(void) {
  OS_U32 Time;
  OS_U32 Cnt;
  
  Time = OS_GetTime32();
  Cnt  = CMCNT_0;
  //  
  // Check if timer interrupt pending ...
  // 
  if ((CMCSR_0 & (1 << 7)) != 0) {  // Adjust result
    Cnt = CMCNT_0;
    Time++;
  } 
  return (TIMER_RELOAD * Time) + Cnt;
}

/*********************************************************************
*
*       OS_ConvertCycles2us
*
*  Convert Cycles into micro seconds. When using 20.0 MHz, this
*  means dividing by 20. If you have a different clock frequency,
*  you may have to modify this routine in order to get proper
*  diagonstics. Please note: Operation of theOS is not affected
*  by this routine. It is used for profiling and testing
*/
OS_U32 OS_ConvertCycles2us(OS_U32 Cycles) {
  return Cycles/(OS_PCLK_TIMER/1000000);
}

/*********************************************************************
*
*       Communication for embOSView   (UART 1)
*
**********************************************************************
*/

#if (OS_UART_USED)

/*********************************************************************
*
*		_IsrUartRxHandler()
*/
static void _IsrUartRxHandler(void) {
  if (SCIFx_SCSSR & (1 << SCFSR_RDRF_BIT)) {
    OS_U8 Data;
    Data = SCIFx_SCRDR;      // Get data
    SCIFx_SCSSR &= ~(1 << SCFSR_RDRF_BIT);  
    OS_OnRx(Data);             // Process data
  }
}

/*********************************************************************
*
*		_IsrUartTxHandler()
*/
static void _IsrUartTxHandler(void) {
  if (OS_OnTx()) {
    SCIFx_SCSCR &= ~(1 << SCSCR_TIE_BIT);      // Disable Tx-Int
  }
}

/*********************************************************************
*
*		_IsrUartErrHandler()
*/
static void _IsrUartErrHandler(void) {
  SCIFx_SCSCR  &= ~(0x50);   // disable Rx and Rx-Int
  while (SCIFx_SCSSR & ((1 << 7) | (1 << 4) | (1 << 3) | (1 << 2))) {  // Any error (ER, BRK, FER, PER)?
    SCIFx_SCSSR    &= ~((1 << 7) | (1 << 4) | (1 << 3) | (1 << 2));    // Clear error and Rx data flags 
  }   
  while (SCIFx_SCSSR & (1 << 0)) {  // Overrun error ?
    SCIFx_SCSSR &= ~(1 << 0);       // Clear error
  }   
  SCIFx_SCSCR |= 0x50;     // Reenable Rx and Rx-Int
}

/*********************************************************************
*
*       OS_COM_Init()
*/
void OS_COM_Init(void) {
  int i;
  OS_IncDI();           // Disable interrupts, save previous state
  //
  // Enable selected UART peripheral
  //
  STBCR5 &= ~(1uL << SCIFx_MODULE_ID_BIT);              
  //  
  // Setting port A I/O register L (PAIORL) TXD1 pin configured as output
  //
  PAIORL |= (1uL << 4);
  //
  // Configure the port pins connected to UART
  //
  PACRL1 |= (5uL << 12);
  PACRL2 |= 5;
  //
  // Disable transmission, reception & serial interrupts
  //
  SCIFx_SCSCR = 0x0000;
  //
  // Initializes the serial mode register
  //
  SCIFx_SCSMR = 0x0000     // B15:B8 - Reserved - Set to 0
               | (0 << 7)  // B7 - Communication mode; 0: Asynchronous
               | (0 << 6)  // B6 - Character length;   0: 8 bit data
               | (0 << 5)  // B5 - Parity Enable;      0: No Parity
               | (0 << 4)  // B4 - Parity mode;        0: N/A (set to 0)
               | (0 << 3)  // B3 - Stop bit length;    0: 1 stop bit
               | (0 << 2)  // B2 - Reserved - Set to 0
               | (0 << 0)  // B1:B0 - Clock Select     0: Select Pphi as source clock
               ;
  //
  // Initialize Baudrate generator
  //
  SCIFx_SCBRR = BAUDDIVIDE;
  for(i=0 ; i < 10500 ; i++) {
    /* Setting delay (1 bit cycle) */
  }
  //
  // Initialize serial status register
  //
  SCIFx_SCSSR = 0x0000;
  //
  // Set interrupt priority for SCI, enables interrupt
  //
  INTC_SCIFx_PRIO_REG = (0x01 << SCIFx_PRIO_POS);
  //
  // Enable transmission, reception and receive interrupts
  //
  SCIFx_SCSCR |= 0x70;
  OS_DecRI();                           // Restore interrupt state
}

/*********************************************************************
*
*       OS_COM_Send1()
*/
void OS_COM_Send1(OS_U8 c) {
  SCIFx_SCTDR  = c;
  SCIFx_SCSSR  &=~(1 << SCFSR_TDRE_BIT);     // Clear Tx Empty Flag
  SCIFx_SCSCR  |= (1 << SCSCR_TIE_BIT);      // Enable Tx-Int
}

/*********************************************************************
*
*       OS_ISR_rx()
*/
#pragma interrupt (OS_ISR_Rx(resbank))
void OS_ISR_Rx(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartRxHandler);
  #else
    OS_CallISR(_IsrUartRxHandler);
  #endif
}

/*********************************************************************
*
*       OS_ISR_tx()
*/
#pragma interrupt(OS_ISR_Tx(resbank))
void OS_ISR_Tx (void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartTxHandler);
  #else
    OS_CallISR(_IsrUartTxHandler);
  #endif
}

/*********************************************************************
*
*       OS_ISR_RxErr()
*/
#pragma interrupt (OS_ISR_RxErr(resbank))
void OS_ISR_RxErr(void) {
  #if ALLOW_NESTED_INTERRUPTS
    OS_CallNestableISR(_IsrUartErrHandler);
  #else
    OS_CallISR(_IsrUartErrHandler);
  #endif
}

#else  /* No communication routines */
  void OS_COM_Init(void) {}
  void OS_COM_Send1(OS_U8 c) {
    OS_COM_ClearTxActive();  /* let OS know that transmitter is not busy  */
  }
#endif /* (OS_UART_USED)

/****** End of file *************************************************/
