/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/
/***********************************************************************************
FILE NAME  	: hwsetup.c

DESCRIPTION	: Sets up RSK hardware.

Copyright   : 2008 Renesas Technology Europe Ltd.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
09.07.2008 RTE-DPR First Release.
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include <machine.h>

/***********************************************************************************
User Includes
***********************************************************************************/
/* Following header file provides a structure to access all of the device registers. */
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "rsk7286def.h"
/* Following header file provides function prototype for hardware setup function. */
#include "hwsetup.h"

/***********************************************************************************
User Program Code Prototypes
***********************************************************************************/
/* These fuctions are private so their prototypes are defined locally */
static void ConfigureOperatingFrequency(void);
static void EnablePeripheralModules(void);
static void ConfigurePortPins(void);

/***********************************************************************************
User Program Code
***********************************************************************************/

/***********************************************************************************
Function Name: 	HardwareSetup
Description:	Sets up hardware
Parameters:		none
Return value:	none
***********************************************************************************/
void HardwareSetup(void)
{
	ConfigureOperatingFrequency();
  EnablePeripheralModules();
  ConfigurePortPins();
}
/***********************************************************************************
End of function HardwareSetup
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigureOperatingFrequency
Description:	Sets up operating speed
Parameters: 	none
Return value: 	none
***********************************************************************************/
void ConfigureOperatingFrequency(void)
{
/* Set CPU PLL operating frequencies. Changes to the peripheral clock will require
changes to the debugger and flash kernel BRR settings.
REF: HMONSerialConfigUser.h define for SCI_CFG_BRR */

	/* Stop DMAC and DTC.  Leave H-UDI and UBC running. */
	STB.CR2.BYTE = 0x22;
	/* Stop MTU2S, MTU2, POE2, IIC3, ADC0 and DAC. */
	STB.CR3.BYTE = 0x7E;
	/* Stop SCIF3 and CMT */
	STB.CR4.BYTE = 0xF6;
	/* Stop SCI1, SCI2, SCI4, ADC1, ADC2 and SSU.  Leave SCI0 running (used by the E8A). */
	STB.CR5.BYTE = 0x7F;
	/* Stop USB and RCAN. */
	STB.CR6.BYTE = 0xDF;
		
	/* Internal clock = 100MHz; Bus and Peripheral clock = 50MHz */
	CPG.FRQCR.WORD = 0x0101;
	/* Execute 32 NOPs, as per 4.4.1 in the Hardware manual */
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	nop(); nop(); nop(); nop(); nop(); nop(); nop(); nop();
	
	/* AD clock = 50MHz */
	CPG.ACLKCR.BYTE = 0x41;
}
/***********************************************************************************
End of function ConfigureOperatingFrequency
***********************************************************************************/

/***********************************************************************************
Function Name: 	ConfigurePortPins
Description:	Configures port pins.
Parameters: 	none
Return value: 	none
***********************************************************************************/
void ConfigurePortPins(void)
{
/* Port pins default to inputs. To ensure safe initialisation set the pin states
before changing the data direction registers. This will avoid any unintentional
state changes on the external ports.
Many peripheral modules will override the setting of the port registers. Ensure
that the state is safe for external devices if the internal peripheral module is
disabled or powered down. */

/* Switch Port configuration */

	/* LED Port configuration (LED0 - LED3 as o/p. respectively)*/
	PFC.PBIORL.BIT.B12 = 1;
	PFC.PBIORH.BIT.B17 = 1;
	PFC.PBIORH.BIT.B18 = 1;
	PFC.PBIORH.BIT.B19 = 1;

	/* Sets the bits in the LED Port DR */
	LED0 = LED1 = LED2= LED3 = LED_OFF;

	/* LCD Port configuration (set as o/p.)  DLCD4 - DLCD7,DLCDE, DLCDRS respectively */
	PFC.PDIORH.BIT.B27 = 1;
	PFC.PDIORH.BIT.B28 = 1;
	PFC.PDIORH.BIT.B29 = 1;
	PFC.PDIORH.BIT.B30 = 1;

	PFC.PDIORH.BIT.B23 = 1;
	PFC.PDIORH.BIT.B24 = 1;

	/* LCD data configuration */
	PD.DR.BIT.B23 = SET_BIT_LOW;
	PD.DR.BIT.B24 = SET_BIT_HIGH;
	

	
}
/***********************************************************************************
End of function ConfigurePortPins
***********************************************************************************/

/***********************************************************************************
Function Name: 	EnablePeripheralModules
Description:	Enables Peripheral Modules before use
Parameters: 	none
Return value: 	none
***********************************************************************************/
void EnablePeripheralModules(void)
{
	/* Enable MTU2 module */
	STB.CR3.BIT._MTU2 = 0;		

	/* Enable ADC0 module */
	STB.CR3.BIT._ADC0 = 0;		
	
	/* Enable SCI module */
	STB.CR5.BIT._SCI1 = 0;
}
/***********************************************************************************
End of function EnablePeripheralModules
***********************************************************************************/

/**********************************************************************************
End of file
***********************************************************************************/
