/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/
/***********************************************************************************
FILE NAME  	: Interrupts.c

DESCRIPTION	: Function to Configure the interrupt controller and used interrupts.

Copyright   : 2008 Renesas Technology Europe Ltd.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
16.06.2008 RTE-DPR First Release.
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include <machine.h>

/**********************************************************************************
User Includes
***********************************************************************************/
/*	Following header file provides vector locations for the interrupts. */
#include "vect.h"
/*	Following header file provides a structure to access on-chip I/O registers. */
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "rsk7286def.h"
/*Following header file provides prototypes for LED controlling functions */
#include "FlashLEDs.h"
/*Following header file provides function prototype for interrupt function. */
#include "Interrupts.h"
/*Following header file */
#include "lcd.h"

/**********************************************************************************
Global variables
***********************************************************************************/
/* Global initialised variable. Modified by the function 'Statics_Test()' */
int cnt=0;

/**********************************************************************************
User Program Code
***********************************************************************************/
/***********************************************************************************
Function Name: 	ConfigureInterrupts
Description:	Configure interrupt enables and settings
Parameters: 	none
Return value: 	none
***********************************************************************************/
void ConfigureInterrupts(void)
{
	/* SW1 is connected to IRQ0-PD16 pin */
	/* Configure pin PD16 as IRQ0 pin */
	PFC.PDCRH1.BIT.PD16MD = 0x3;
	INTC.ICR1.BIT.IRQ0S = 1;
	/* Enable IRQ0 interrupt */
	INTC.IPR01.BIT._IRQ0 = 1;

	/* SW2 is connected to IRQ1-PD17 pin */
	/* Configure pin PD17 as IRQ1 pin */
	PFC.PDCRH1.BIT.PD17MD = 0x3;
	INTC.ICR1.BIT.IRQ1S = 1;
	/* Enable IRQ1 interrupt */
	INTC.IPR01.BIT._IRQ1 = 1;

	/* SW3 is connected to IRQ2-PD18 pin */
	/* Configure pin PD18 as IRQ2 pin */
	PFC.PDCRH1.BIT.PD18MD = 0x3;
	INTC.ICR1.BIT.IRQ2S = 1;
	/* Enable IRQ2 interrupt */
	INTC.IPR01.BIT._IRQ2 = 1;
	
	/* Set timer interrupt priority */
	INTC.IPR09.BIT._MTU21G= 0x3;

	/* Disable MTU2 interrupt.	*/
	MTU21.TIER.BYTE = 0x00;

	/* Set the interrupt mode 2 interrupt mask level to 0 */
	set_imask(0);
}
/***********************************************************************************
End of function ConfigureInterrupts
***********************************************************************************/

/**********************************************************************************
ISR Name: 		INT_MTU1_TGIA1
Description:	Turns on The LEDs.
				If the ADC has completed a conversion:-
					Sets the timer period relative to the ADC value.
					Sets the timer duty relative to the ADC value.
					Re-starts the ADC.
				Clears the interrupt
Parameters: 	none
Return value: 	none
***********************************************************************************/
void INT_MTU1_TGIA1(void)
{
		
	unsigned short usData;

	if (cnt == 5)

	{
		usData = ADC0.ADDR0;

		if (usData <= 0x00F)
		{
			usData = 0x00F;
		}
	
		/* Use the ADC reading as timer upper limit */
		MTU21.TGRA = usData;


		/* Turn on the LEDs */
		ToggleLEDs();
		
		/* Clear cnt variable */
		cnt=0;
	}
	
	/* increment cnt on each timer interrupt */
	cnt++;
	
	/* Clear the interrupt flag */
	MTU21.TSR.BIT.TGFA = SET_BIT_LOW;
		
	
}
/**********************************************************************************
End of ISR INT_MTU1_TGIA1
***********************************************************************************/

/**********************************************************************************
 Switch driven ISRs
***********************************************************************************/

/**********************************************************************************
ISR Name: 		INT_IRQ0
Description:	SW1 is connected to the IRQ0 interrupt pin
Parameters: 	none
Return value: 	If SW1 is pressed global 'gucKeyPressed' is set to 1.
***********************************************************************************/
void INT_IRQ0(void)
{
	/* Add delay to debounce switch */
	unsigned char ucDelay = 0x3F;

	while (ucDelay--);

	/* Set a flag to say the switch has been pressed */
	gcKeyPressed = '1';
 
	/* Clear interrupt flag */
	INTC.ICR1.BIT.IRQ0S = 1;
	INTC.IRQRR.BIT.IRQ0F = SET_BIT_LOW;
	
}
/**********************************************************************************
End of function INT_IRQ0
***********************************************************************************/

/**********************************************************************************
ISR Name: 		INT_IRQ1
Description:	SW2 is connected to the IRQ1 interrupt pin
Parameters: 	none
Return value: 	If SW2 is pressed global 'gucKeyPressed' is set to 2.
***********************************************************************************/
void INT_IRQ1(void)
{
	/* Add delay to debounce switch */
	unsigned char ucDelay = 0x3F;

	while (ucDelay--);

	/* Set a flag to say a switch has been pressed */
	gcKeyPressed = '2';

	/* Clear interrupt flag */
	INTC.IRQRR.BIT.IRQ1F = SET_BIT_LOW;
	

}
/**********************************************************************************
End of function INT_IRQ1
***********************************************************************************/

/**********************************************************************************
ISR Name: 		INT_IRQ2
Description:	SW3 is connected to the IRQ2 interrupt pin
Parameters: 	none
Return value: 	If SW3 is pressed global 'gucKeyPressed' is set to 3.
***********************************************************************************/
void INT_IRQ2(void)
{
	/* Add delay to debounce switch */
	unsigned char ucDelay = 0x3F;

	while (ucDelay--);

	/* Set a flag to say a switch has been pressed */
	gcKeyPressed = '3';

	/* Clear interrupt flag */
	INTC.IRQRR.BIT.IRQ2F = SET_BIT_LOW;
	
}
/**********************************************************************************
End of function INT_IRQ2
***********************************************************************************/

/**********************************************************************************
End of file
***********************************************************************************/
