/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/
/***********************************************************************************
FILE NAME  		main.c
DESCRIPTION		Main Program

	This is the main tutorial code. This code will call three functions to demonstrate
	Port pin control (FlashLEDs), Interrupt usage (TimerADC) and C variable
	initialisation (Statics_Test). Code is also included to drive the optional LCD
	module.

	Please refer to the tutorial manual for more information on the program flow.


Copyright   : 2008 Renesas Technology Europe Ltd.
			  2008 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
15.08.2008 RTE-ADE First Release.
***********************************************************************************/

/**********************************************************************************
User Includes
***********************************************************************************/
/* Following header file provides a structure to access on-chip I/O registers. */
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "rsk7286def.h"
/* Following header file provides prototypes for LCD controlling functions */
#include "lcd.h"
/* Following header file provides prototypes for LED controlling functions */
#include "FlashLEDs.h"
/* Following header file provides prototypes for timer & ADC controlling functions */
#include "timeradc.h"
/* Following header file provides prototype for functions contained in this	file. */
#include "main.h"

/**********************************************************************************
Global variables
***********************************************************************************/
/* Global initialised variable. Modified by the function 'Statics_Test()' */
char ucStr[] = " STATIC ";
/* Constant string for replacement */
const char gcReplace[] = "TESTTEST";
/* Pressing any switch will update this global variable */
volatile char gcKeyPressed = 0;

/**********************************************************************************
User Program Code
***********************************************************************************/
/***********************************************************************************
Function Name : main
Description   :	Main function.
		This function calls timer, ADC & LCD initialisation functions. The user
		LEDs flashes until the user presses a switch on the RSK.
Parameters    : none
Return value  : none
***********************************************************************************/
void main(void)
{
	/* 	Reset the LCD module. */
	InitialiseDisplay();

	/* 	Display Renesas Splash Screen. */
	DisplayString(LCD_LINE1, "Renesas");	
	DisplayString(LCD_LINE2, NICKNAME);

	/* 	Flash the user LEDs for some time or until a key is pressed. */
	FlashLEDs();

	/* 	Flash the user LEDs at a rate set by the user potentiomenter (ADC) using
		interrupts. */
	TimerADC();

	/* 	Demonstration of initialised variables.
		Use this function with the debugger. */
	Statics_Test();

	/* 	End of user program. This function must not exit. */
	while(1);
}
/***********************************************************************************
End of function main
***********************************************************************************/

/***********************************************************************************
Function Name : Statics_Test
Description	  :	Displays an initialised string, then modifies it, a character
				at a time, displaying it at each stage.
				Finally NICKNAME is displayed.
Parameters	  : none.
Return value  : none.
***********************************************************************************/
void Statics_Test(void)
{
	unsigned char ucCount;

	DisplayString(LCD_LINE2, ucStr);

/* At this point please right click on the 'ucSTR' variable and select 'Instant
Watch' A dialog will be displayed showing the current value of the variable.
Select 'Add' in the dialog and a new 'Watch Window' will open.
Step through the following code to see that the initialised data is being
overwritten with the different data. */

	for (ucCount=0; ucCount<=8; ucCount++)
	{
		ucStr[ucCount] = gcReplace[ucCount];
		DisplayString(LCD_LINE2, ucStr);
	    DisplayDelay(0x3000);
	}

	/* Reset the LCD display */
	DisplayString(LCD_LINE2, NICKNAME);
}
/***********************************************************************************
End of function Statics_Test
***********************************************************************************/

/***********************************************************************************
End of file
***********************************************************************************/
