/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/

/***********************************************************************************
FILE NAME  	: sbrk.c

DESCRIPTION	: Program of sbrk

Copyright   : 2008 Renesas Technology Europe Ltd.
			  2008 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
15.08.2008 RTE-ADE First Release.
***********************************************************************************/     

#include <stddef.h>
#include <stdio.h>
#include "typedefine.h"
#include "sbrk.h"

_SBYTE  *sbrk(size_t size);

/* Specifies the minimum unit of */
//const size_t _sbrk_size=	

/* the defined heap area */
extern _SBYTE *_s1ptr;

#pragma pack 4
union HEAP_TYPE {
	
/* Dummy for 4-byte boundary */
    _SDWORD  dummy ;
	
/* Declaration of the area managed by sbrk*/		
    _SBYTE heap[HEAPSIZE];	
};

static union HEAP_TYPE heap_area ;
/* for DSP-C */
//static __X union HEAP_TYPE heap_area__X; 
/* for DSP-C */             
//static __Y union HEAP_TYPE heap_area__Y;              
#pragma unpack

/* End address allocated by sbrk	*/
static _SBYTE *brk=(_SBYTE *)&heap_area;

//static __X _SBYTE *brk__X=(_SBYTE __X *)&heap_area__X;    /* for DSP-C */
//static __Y _SBYTE *brk__Y=(_SBYTE __Y *)&heap_area__Y;    /* for DSP-C */

/**************************************************************************/
/*     sbrk:Memory area allocation                                        */
/*          Return value:Start address of allocated area (Pass)           */
/*                       -1                              (Failure)        */
/**************************************************************************/

/* Assigned area size   */
_SBYTE  *sbrk(size_t size)                      
{
    _SBYTE  *p;
/* Empty area size      */
    if(brk+size > heap_area.heap+HEAPSIZE){     
        p = (_SBYTE *)-1;
    }
    else {
	
/* Area assignment      */
        p = brk;       
/* End address update   */                         
        brk += size;                            
    }
    return p;
}

/**************************************************************************/
/*     sbrk:X Memory area allocation                                      */
/*          Return value:Start address of allocated area (Pass)           */
/*                       -1                              (Failure)        */
//*      When the dspc option is specified at compiling, remove // of     */
//*      the head of the line which has /* for DSP-C */ and add start     */
//*      options and add "$XB" and "$YB" to the start option at linkage.  */
/**************************************************************************/
//_SBYTE __X *sbrk__X(size_t size)        /* Assigned area size */      /* for DSP-C */
//{                                                                     /* for DSP-C */
//    __X _SBYTE *p;                                                    /* for DSP-C */
//                                                                      /* for DSP-C */
//    if (brk__X+size > heap_area__X.heap+HEAPSIZE) { /* Empty area size */ /* for DSP-C */
//        return (_SBYTE __X *)-1;                                      /* for DSP-C */
//    }                                                                 /* for DSP-C */
//                                                                      /* for DSP-C */
//    p = brk__X;                 /* Area assignment */                 /* for DSP-C */
//    brk__X += size;             /* End address update */              /* for DSP-C */
//    return p;                                                         /* for DSP-C */
//}                                                                     /* for DSP-C */

/**************************************************************************/
/*     sbrk:Y Memory area allocation                                      */
/*          Return value:Start address of allocated area (Pass)           */
/*                       -1                              (Failure)        */
//*      When the dspc option is specified at compiling, remove // of     */
//*      the head of the line which has /* for DSP-C */ and add start     */
//*      options and add "$XB" and "$YB" to the start option at linkage.  */
/**************************************************************************/
//_SBYTE __Y *sbrk__Y(size_t size)         /* Assigned area size */     /* for DSP-C */
//{                                                                     /* for DSP-C */
//    __Y _SBYTE *p;                                                    /* for DSP-C */
//                                                                      /* for DSP-C */
//    if (brk__Y+size > heap_area__Y.heap+HEAPSIZE) { /* Empty area size */ /* for DSP-C */
//        return (_SBYTE __Y *)-1;                                      /* for DSP-C */
//    }                                                                 /* for DSP-C */
//    p = brk__Y;                  /* Area assignment */                /* for DSP-C */
//    brk__Y += size;              /* End address update */             /* for DSP-C */
//    return p;                                                         /* for DSP-C */
//}                                                                     /* for DSP-C */
