/******************************************************************************
* DISCLAIMER:
* The software supplied by Renesas Technology Europe Ltd is
* intended and supplied for use on Renesas Technology products.
* This software is owned by Renesas Technology Europe, Ltd. Or
* Renesas Technology Corporation and is protected under applicable
* copyright laws. All rights are reserved.
*
* THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS,
* IMPLIED OR STATUTORY, INCLUDING BUT NOT LIMITED TO IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* APPLY TO THIS SOFTWARE. RENESAS TECHNOLOGY AMERICA, INC. AND
* AND RENESAS TECHNOLOGY CORPORATION RESERVE THE RIGHT, WITHOUT
* NOTICE, TO MAKE CHANGES TO THIS SOFTWARE. NEITHER RENESAS
* TECHNOLOGY AMERICA, INC. NOR RENESAS TECHNOLOGY CORPORATION SHALL,
* IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
* CONSEQUENTIAL DAMAGES FOR ANY REASON WHATSOEVER ARISING OUT OF THE
* USE OR APPLICATION OF THIS SOFTWARE.
******************************************************************************/
/***********************************************************************************
FILE NAME	: TimerADC.c

DESCRIPTION	: Configures the MTU2 and ADC channel 0. 

Copyright   : 2008 Renesas Technology Europe Ltd.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
16.06.2008 RTE-DPR First Release.
***********************************************************************************/

/**********************************************************************************
User Includes
***********************************************************************************/
/* Following header file provides a structure to access all of the device registers.*/
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "rsk7286def.h"
/*	Following header file provides function prototypes for timer & ADC controlling
	functions. */
#include "TimerADC.h"

/**********************************************************************************
User Program Code
***********************************************************************************/

/**********************************************************************************
Function Name: 	TimerADC
Description:	Uses the ADC to change the Duty of the timer, used to flash the LEDs
Parameters: 	none
Return value: 	none
***********************************************************************************/
void TimerADC(void)
{     
	StartTimer();
	StartADC();
}
/**********************************************************************************
End of function TimerADC
***********************************************************************************/

/**********************************************************************************
Function Name: 	StartADC
Description:	Starts the ADC
Parameters: 	none
Return value: 	none
***********************************************************************************/
void StartADC(void)
{
	/* Ensure the ADC is stopped before modifying AD settings*/
	ADC0.ADCR.BIT.ADST = 0;
	
	/*clear ADC flag*/
	ADC0.ADSR.BIT.ADF = 0; 
	/* Select channel AN0 for converter ADC0 */
	ADC0.ADANSR.BIT.ANS0 = 1;
	
	/* Select high-accuracy automatic correction mode */
	ADC0.ADBYPSCR.BIT.OFC = 0;
	
	/* Select the sample-and-hold circuits */	
	ADC0.ADBYPSCR.BIT.SH = 1;
	
	/* Configure ADC */
	/* bit[7]	= b'0'	: ADST; Start control				*/
	/* bit[6]	= b'1'	: ADCS; Continuous scan selected	*/
	/* bit[5]	= b'1'	: ACE; Automatic Clear enabled		*/
	/* bit[4]	= b'0'	: ACIE; Interrupts disabled			*/
	/* bit[3-2]	= 0		: Reserved							*/
	/* bit[1]	= b'0'	: TRGE; MTU2 trigger disabled		*/
	/* bit[[0]	= b'0'	: EXTRG; MTU2 trigger selected		*/
	ADC0.ADCR.BYTE = 0x60;
	
	/* Start A/D conversion */
	ADC0.ADCR.BIT.ADST = 1;    
}
/**********************************************************************************
End of function StartADC
***********************************************************************************/

/**********************************************************************************
Function Name: 	StartTimer
Description:	Configures and starts the timer
Parameters: 	none
Return value: 	none
***********************************************************************************/
void StartTimer(void)
{
	/* Stops the timer from counting */
	MTU2.TSTR.BIT.CST1 = SET_BIT_LOW;

	/* Set timer mode */
	/*00000000
		b7 		-
		b6		BFE
        b5		BFB
        b4		BFA
	   	b3:b0	MD[3:0]		Modes, Normal */
	MTU21.TMDR.BYTE = 0x00;

	/* Set timer control register */
	/*00101110
        b7:b5	CCLR[2:0]	Cleared by TGRA compare match
        b4:b3	CKEG[1:0]	Count at rising edge
	   	b2:b0	TPSC[2:0]	Clock source P/64 */
	MTU21.TCR.BYTE = 0x26;

	/* Set output state control */
	/*00000001
		b7:b4	IOB, 1 Output at compare match
		b3:b0	IOA, 0 Output at compare match */
	MTU21.TIOR.BYTE = 0x01;

	/* Clear all interrupt flags */
	/*11000000
		b7	TCFD	TCNT counts up
		b6	-		Always write 1
		b5	TCFU	Underflow Flag, Clear
		b4	TCFV	Overflow Flag, Clear
		b3	TGFD	TGRD Compare Match/Capture Flag, Clear
		b2	TGFC	TGRC Compare Match/Capture Flag, Clear
		b1  TGFB	TGRB Compare Match/Capture Flag, Clear
		b0	TGFA	TGRA Compare Match/Capture Flag, Clear */
	MTU21.TSR.BYTE = 0xC0;

	/* Enable timer interrupts on compare match */
	/*00000001
		b7	TTGE	Disable TGRA ADC start request generation
		b6	TTGE2	Disable TCNT_4 ADC start request generation
		b5	TCIEU	Disable TCFU undeflow interrupts
		b4	TCIEV	Disable TCFV overflow interrupts
		b3	TGIED	Reserved.
		b2	TGIEC	Reserved.
		b1	TGIEB	Disable TGFB interrupt requests
		b0	TGIEA	Enable TGFA interrupt requests */
	MTU21.TIER.BYTE = 0x01;

	/* Set the period by setting the initial value */
	MTU21.TGRA = 0xFFFF;

	/* Start the timer */
	MTU2.TSTR.BIT.CST1 = 1;
}
/**********************************************************************************
End of function StartTimer
***********************************************************************************/

/**********************************************************************************
End of file
***********************************************************************************/
