/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for RENESAS SH7203 Starterkit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "iodefine.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs and identifiers used for LED demo **********************/

#define PEDRL    (*(volatile unsigned short*) (0xFFFE3A02))


/****** Assign LEDs to Ports ****************************************/

#define LED0_PORT        (PEDRL)
#define LED1_PORT        (PEDRL)
#define LED2_PORT        (PEDRL)
#define LED3_PORT        (PEDRL)

#define LED0_BIT         (4)
#define LED1_BIT         (5)
#define LED2_BIT         (10)
#define LED3_BIT         (11)

#define		LED0			PORT.PEDRL.BIT.PE4DR 
#define		LED1			PORT.PEDRL.BIT.PE5DR 
#define		LED2			PORT.PEDRL.BIT.PE10DR 
#define		LED3			PORT.PEDRL.BIT.PE11DR 

#define LED0_MASK        (1 << LED0_BIT)
#define LED1_MASK        (1 << LED1_BIT)
#define LED2_MASK        (1 << LED2_BIT)
#define LED3_MASK        (1 << LED3_BIT)

/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/

static unsigned char _LEDIsOn(int Index) {
  unsigned char result;
  result = 0;
  switch (Index) {
    case 0:
      result = (LED0_PORT & LED0_MASK) ? 0 : 1;    // LED0 is switched on with low level
      break;
    case 1: 
      result = (LED1_PORT & LED1_MASK) ? 0 : 1;    // LED1 is switched on with low level
      break;
    case 2: 
      result = (LED2_PORT & LED2_MASK) ? 0 : 1;    // LED2 is switched on with low level
      break;
    case 3: 
      result = (LED3_PORT & LED3_MASK) ? 0 : 1;    // LED3 is switched on with low level
      break;
    default:
    break;
  }
  return result;
}

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {

  // 
  // Configure port pins connected to LEDs	
  //
  PORT.PECRL1.BYTE.H      &= 0xFC;
  PORT.PEIORL.BIT.PE4IOR   = 1;
  PORT.PECRL1.BYTE.H      &= 0xF3;
  PORT.PEIORL.BIT.PE5IOR   = 1;
  PORT.PECRL2.BYTE.L      &= 0xCF;
  PORT.PEIORL.BIT.PE10IOR  = 1;
  PORT.PECRL2.BYTE.L      &= 0x3F;
  PORT.PEIORL.BIT.PE11IOR  = 1;
  //
  // Initially switch LEDs on for test
  //
  LED0_PORT &= ~(LED0_MASK);    // LED0 is switched on with low level
  LED1_PORT &= ~(LED1_MASK);    // LED1 is switched on with low level
  LED2_PORT &= ~(LED2_MASK);    // LED2 is switched on with low level
  LED3_PORT &= ~(LED3_MASK);    // LED3 is switched on with low level
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
    case 0:
      LED0_PORT &= ~(LED0_MASK);    // LED0 is switched on with low level
      break;
    case 1: 
      LED1_PORT &= ~(LED1_MASK);    // LED1 is switched on with low level
      break;
    case 2: 
      LED2_PORT &= ~(LED2_MASK);    // LED2 is switched on with low level
      break;
    case 3: 
      LED3_PORT &= ~(LED3_MASK);    // LED3 is switched on with low level
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
    case 0:
      LED0_PORT |= (LED0_MASK);    // LED0 is switched off with high level
      break;
    case 1: 
      LED1_PORT |= (LED1_MASK);    // LED1 is switched off with high level
      break;
    case 2: 
      LED2_PORT |= (LED2_MASK);    // LED2 is switched off with high level
      break;
    case 3: 
      LED3_PORT |= (LED3_MASK);    // LED3 is switched off with high level
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
    case 0:
      if(_LEDIsOn(Index)) {
        LED0_PORT |= (LED0_MASK);    // LED0 is switched off with high level
      } else {
        LED0_PORT &= ~(LED0_MASK);    // LED0 is switched on with low level
    }
      break;
    case 1: 
      if(_LEDIsOn(Index)) {
        LED1_PORT |= (LED1_MASK);    // LED1 is switched off with high level
      } else {
        LED1_PORT &= ~(LED1_MASK);    // LED1 is switched on with low level
    }
      break;
    case 2: 
      if(_LEDIsOn(Index)) {
        LED2_PORT |= (LED2_MASK);    // LED2 is switched off with high level
      } else {
        LED2_PORT &= ~(LED2_MASK);    // LED2 is switched on with low level
    }
      break;
    case 3: 
      if(_LEDIsOn(Index)) {
        LED3_PORT |= (LED3_MASK);    // LED3 is switched off with high level
      } else {
        LED3_PORT &= ~(LED3_MASK);    // LED3 is switched on with low level
    }
      break;
    default:
      break;
  }
}

/*********************************************************************
*
*       _write
*
*  Function description
*    Dummy function for H8 compilers (HEW) and printf()
*/
void write(char c) {
}

/*********************************************************************
*
*       _read
*
*  Function description
*    Dummy function for H8 compilers (HEW) and printf()
*/
char read(void) {
}

/****** EOF *********************************************************/


