/***********************************************************************************
FILE NAME  		bus_init.h
DESCRIPTION		Header file for external bus initialization.

Copyright   : 2008 Renesas Technology Europe Ltd.
Copyright   : 2008 Renesas Technology Corporation.
All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
11.04.2008 RTE-VNA First Release.
***********************************************************************************/

#ifndef BUS_INIT_H
#define BUS_INIT_H

/***********************************************************************************
Macro Defines
***********************************************************************************/
#define USE_32BIT_SDRAM_INTERFACE
/* To enable 32-bit acces to FLASH, uncomment this line */
/* #define USE_32BIT_FLASH_INTERFACE */
/* To enable on-chip cache memory, uncomment this line */
#define USE_CACHE_MEMORY
/* To enable cache writeback abiity, uncomment this line */
/* #define CACHE_WRITEBACK */

/***********************************************************************************
SDRAM Mode register addresses
***********************************************************************************/
/* The address when writing in a SDRAM mode register */
#ifdef USE_32BIT_SDRAM_INTERFACE
#define	SDRAM_MODE				(*(volatile unsigned short*) (0xfffc5060))
#else
#define	SDRAM_MODE				(*(volatile unsigned short*) (0xfffc50C0))
#endif

/* Define a delay count for the time period between write and read on the memory test */
#define RST_MEM_DELAY_CNT		8

/* The SDRAM on this RSK can be configured either as 8M x32 SDRAM or 8M x 16 */
#define RSK_SDRAM_SIZE			(1024 * 1024 * 8)

#ifdef USE_CACHE_MEMORY
#define RSK_SDRAM_START			0x0C000000
#else
#define RSK_SDRAM_START			0x2C000000
#endif

/* Define the size of the external bus for the SDRAM here */
#ifdef USE_32BIT_SDRAM_INTERFACE
typedef unsigned long BUS_WIDTH;
#else
typedef unsigned short BUS_WIDTH;
#endif

/* Define the stat address of the CS3 SDRAM */
#define RST_CS3_SDRAM_START		((BUS_WIDTH*) RSK_SDRAM_START)

/* Define the maximum ammount of SDRAM that area CS3 can support */
#define RSK_CS3_SDRAM_MAX_SIZE	(1024 * 1024 * 64)

/***********************************************************************************
Function Prototypes
***********************************************************************************/
void ConfigureBusAndMemory(void);
void Init_BSC_CS0(void);
void Init_SDRAM(void);

#ifdef USE_CACHE_MEMORY
void Init_Cache(void);
#endif

#ifdef CACHE_WRITEBACK
int Cache_Writeback(void);
#endif

/* BUS_INIT_H */
#endif		
