/***********************************************************************************
FILE NAME:		Interrupts.c
DESCRIPTION:	Function to configure the interrupt controller and used interrupts.

Copyright : 2008 Renesas Technology Europe Ltd.
Copyright : 2008 Renesas Technology Corporation.
All Rights Reserved

***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
23.01.2008 RTE-MBA First Release
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/* Header file for sleep() and nop() functions */
#include <machine.h>
/* iodefine.h provides a structure to access all of the device registers. */
#include "iodefine.h"
/* Following header file provides a proper definition of ISR procedures */
#include "vect.h"

/**********************************************************************************
User Includes
***********************************************************************************/
/* rsk7670def.h provides common defines for widely used items. */
#include "rsk7670def.h"

/**********************************************************************************
Global variables
***********************************************************************************/
extern unsigned char gucKeyPressed;
extern unsigned char flFlagLed;

/**********************************************************************************
User Program Code
***********************************************************************************/

/***********************************************************************************
Function Name:	ConfigureInterrupts
Description:	Enables external SDRAM memory and internal cache
Parameters:		None
Return value:	None
***********************************************************************************/
void ConfigureInterrupts(void)
{
	/* Configure the port pins as IRQ inputs */
	PORT.PDCRL1.BIT.PD4MD1 = 0x0;
	PORT.PDCRL1.BIT.PD4MD0 = 0x1;
	PORT.PDCRL1.BIT.PD5MD1 = 0x0;
	PORT.PDCRL1.BIT.PD5MD0 = 0x1;
	PORT.PDCRL1.BIT.PD6MD1 = 0x0;
	PORT.PDCRL1.BIT.PD6MD0 = 0x1;
		
	/* Increase the priority levels of the interrupts */
	INTC.IPR02.BIT._IRQ4 = 0x1;
	INTC.IPR02.BIT._IRQ5 = 0x1;
	INTC.IPR02.BIT._IRQ6 = 0x1;
	
	/* Set falling edge for the button's interrupts */
	INTC.ICR1.BIT.IRQ4S = 0x1;
	INTC.ICR1.BIT.IRQ5S = 0x1;
	INTC.ICR1.BIT.IRQ6S = 0x1;
	
	/* Clear interrupt flag */
	INTC.IRQRR.BIT.IRQ4F &= SET_BIT_LOW;
	/* Clear interrupt flag */
	INTC.IRQRR.BIT.IRQ5F &= SET_BIT_LOW;
	/* Clear interrupt flag */
	INTC.IRQRR.BIT.IRQ6F &= SET_BIT_LOW;
	
	/* Configure bank switching	*/
	INTC.IBNR.BIT.BE = 0x03;
	INTC.IBCR.BIT.E1 = 1;
	INTC.IBCR.BIT.E2 = 1;
}
/***********************************************************************************
End of function ConfigureInterrupts
***********************************************************************************/

/**********************************************************************************
 Switch driven ISRs
***********************************************************************************/

/**********************************************************************************
ISR Name:		INT_IRQ4
Description:	SW1 is connected to the IRQ4 interrupt pin
Parameters:		None
Return value:	If SW1 is pressed global 'gucKeyPressed' is set to 1.
***********************************************************************************/
void INT_IRQ4(void)
{
	/* Add delay to debounce switch */
	unsigned long ulDelay = 0x3F;

	while (ulDelay--)
	{
	}
	
	/* Set a flag to say the switch has been pressed */
	gucKeyPressed = '1';

	/* Clear the interrupt flag */
	INTC.IRQRR.BIT.IRQ4F &= SET_BIT_LOW;
}
/**********************************************************************************
End of ISR INT_IRQ4
***********************************************************************************/

/**********************************************************************************
ISR Name:		INT_IRQ5
Description:	SW2 is connected to the IRQ5 interrupt pin
Parameters:		None
Return value:	If SW2 is pressed global 'gucKeyPressed' is set to 2.
***********************************************************************************/
void INT_IRQ5(void)
{
	/* Add delay to debounce switch */
	unsigned long ulDelay = 0x3F;

	while (ulDelay--)
	{
	}
	
	/* Set a flag to say a switch has been pressed */
	gucKeyPressed = '2';

	/* Clear interrupt flag */
	INTC.IRQRR.BIT.IRQ5F &= SET_BIT_LOW;
}
/**********************************************************************************
End of ISR INT_IRQ5
***********************************************************************************/

/**********************************************************************************
ISR Name:		INT_IRQ6
Description:	SW3 is connected to the IRQ6 interrupt pin
Parameters:		None
Return value:	If SW3 is pressed global 'gucKeyPressed' is set to 3.
***********************************************************************************/
void INT_IRQ6(void)
{
	/* Add delay to debounce switch */
	unsigned long ulDelay = 0x3F;

	while (ulDelay--)
	{
	}

	/* Set a flag to say a switch has been pressed */
	gucKeyPressed = '3';

	/* Clear the interrupt flag */
	INTC.IRQRR.BIT.IRQ6F &= SET_BIT_LOW;
}
/**********************************************************************************
End of ISR INT_IRQ6
***********************************************************************************/
