/***********************************************************************************
FILE NAME  		resetprg.c
DESCRIPTION		Reset Initialisation Function.
		The user's program will start in this file.

Note - 
'#pragma section' used in this file instructs the linker to place all subsequent code
in the named section. This can be used to relocate code in the memory map. This
directive should be used when debugging code in RAM to provide a section name that
can be referenced in the build | toolchain | linker | section settings. Use of the
directive without the section name will reset the section to default. 

Copyright   : 2008 Renesas Technology Europe Ltd.
Copyright   : 2008 Renesas Technology Corporation.
All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
23.02.2008 RTE-VNA First Release.
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include <machine.h>
/* Following header file provides access to intrinsic functions _INITSCT(). */
#include <_h_c_lib.h>
/*  Following header file is used by __entry directive to set the initial stack pointer.
The value in this file should only be changed if relocating and / or changing the
size of the stack. */
#include "stacksct.h"

/***********************************************************************************
User Includes
***********************************************************************************/
/* iodefine.h provides a structure to access all of the device registers. */
#include "iodefine.h"
/* Following header file provides prototype for hardware setup function.	*/
#include "hwsetup.h"
/* Following header file provides prototype for main() function.	*/
#include "main.h"
/* Following header file provides prototype for bus initialization function.	*/
#include "bus_init.h"

/***********************************************************************************
Function Prototypes
***********************************************************************************/
void PowerON_Reset(void);

/***********************************************************************************
Macro Defines
***********************************************************************************/
#define FPSCR_Init    0x00040000
#define SR_Init    0x000000F0

/***********************************************************************************
ISR Name	: PowerON_Reset
Description	: Power on reset function.
		This function executes following to power on reset.
		It first calls hardware initialisation function & then 'main()' function.
Parameters	: none
Return value: none
***********************************************************************************/
#pragma entry PowerON_Reset

#pragma section ResetPRG
void PowerON_Reset(void)
{
	/* Set up the hardware	*/
	HardwareSetup();

	/* Copy initilizes data from ROM to RAM	 */
	_INITSCT();

#ifdef CACHE_WRITEBACK
	cache_writeback();
#endif

	/* Initialize FPSCR	 */
	set_fpscr(FPSCR_Init);

	/* Initialize VBR */
	set_vbr((void *)((char *)0));

	/* Initialize Status register */
	set_cr(SR_Init);
	nop();

	/* Unmask all interrutps.	*/
	set_imask(0);

	/* Start user code	*/
	main();

	while(1)
	{
		/* This function must never exit */
	}
}
#pragma section
/***********************************************************************************
End of function PowerON_Reset
***********************************************************************************/
