/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88                                             *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : iodefine.c
Purpose : I/O Register definitions for the SH2A/7670 CPU.
--------  END-OF-HEADER  ---------------------------------------------
*/


#ifndef __IODEFINE_H
#define __IODEFINE_H

typedef signed char _SBYTE;
typedef unsigned char _UBYTE;
typedef signed short _SWORD;
typedef unsigned short _UWORD;
typedef signed int _SINT;
typedef unsigned int _UINT;
typedef signed long _SDWORD;
typedef unsigned long _UDWORD;
typedef signed long long _SQWORD;
typedef unsigned long long _UQWORD;

struct st_ccnt {                            /* struct CCNT  */
    union {                                 /* CCR1         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :20;                    /*              */
            _UDWORD ICF:1;                  /*   ICF        */
            _UDWORD :2;                     /*              */
            _UDWORD ICE:1;                  /*   ICE        */
            _UDWORD :4;                     /*              */
            _UDWORD OCF:1;                  /*   OCF        */
            _UDWORD :1;                     /*              */
            _UDWORD WT:1;                   /*   WT         */
            _UDWORD OCE:1;                  /*   OCE        */
        } BIT;
    } CCR1;
    union {                                 /* CCR2         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :15;                    /*              */
            _UDWORD LE:1;                   /*   LE         */
            _UDWORD :6;                     /*              */
            _UDWORD W3LOAD:1;               /*   W3LOAD     */
            _UDWORD W3LOCK:1;               /*   W3LOCK     */
            _UDWORD :6;                     /*              */
            _UDWORD W2LOAD:1;               /*   W2LOAD     */
            _UDWORD W2LOCK:1;               /*   W2LOCK     */
        } BIT;
    } CCR2;
};

struct st_intc{                             /* struct INTC  */
    union{                                  /* ICR0         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD NMIL:1;                  /*   NMIL       */
            _UWORD :6;                      /*              */
            _UWORD NMIE:1;                  /*   NMIE       */
            _UWORD :8;                      /*              */
        } BIT;
    } ICR0;
    union {                                 /* ICR1         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD IRQ7S:2;                 /*   IRQ71S     */
            _UWORD IRQ6S:2;                 /*   IRQ61S     */
            _UWORD IRQ5S:2;                 /*   IRQ51S     */
            _UWORD IRQ4S:2;                 /*   IRQ41S     */
            _UWORD IRQ3S:2;                 /*   IRQ31S     */
            _UWORD IRQ2S:2;                 /*   IRQ21S     */
            _UWORD IRQ1S:2;                 /*   IRQ11S     */
            _UWORD IRQ0S:2;                 /*   IRQ01S     */
        } BIT;
    } ICR1;
    _UBYTE wk0[2];
    union {                                 /* IRQRR        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD IRQ7F:1;                 /*   IRQ7F      */
            _UWORD IRQ6F:1;                 /*   IRQ6F      */
            _UWORD IRQ5F:1;                 /*   IRQ5F      */
            _UWORD IRQ4F:1;                 /*   IRQ4F      */
            _UWORD IRQ3F:1;                 /*   IRQ3F      */
            _UWORD IRQ2F:1;                 /*   IRQ2F      */
            _UWORD IRQ1F:1;                 /*   IRQ1F      */
            _UWORD IRQ0F:1;                 /*   IRQ0F      */
        } BIT;
    } IRQRR;
    _UBYTE wk1[4];
    union {                                 /* IBCR         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD E15:1;                   /*   E15        */
            _UWORD E14:1;                   /*   E14        */
            _UWORD E13:1;                   /*   E13        */
            _UWORD E12:1;                   /*   E12        */
            _UWORD E11:1;                   /*   E11        */
            _UWORD E10:1;                   /*   E10        */
            _UWORD E9:1;                    /*   E9         */
            _UWORD E8:1;                    /*   E8         */
            _UWORD E7:1;                    /*   E7         */
            _UWORD E6:1;                    /*   E6         */
            _UWORD E5:1;                    /*   E5         */
            _UWORD E4:1;                    /*   E4         */
            _UWORD E3:1;                    /*   E3         */
            _UWORD E2:1;                    /*   E2         */
            _UWORD E1:1;                    /*   E1         */
            _UWORD :1;                      /*              */
        } BIT;
    } IBCR;
    union {                                 /* IBNR         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BE:2;                    /*   BE         */
            _UWORD BOVE:1;                  /*   BOVE       */
            _UWORD :9;                      /*              */
            _UWORD BN:4;                    /*   BN         */
        } BIT;
    } IBNR;
    _UBYTE wk2[8];
    union {                                 /* IPR01        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _IRQ0:4;                 /*   _IRQ0      */
            _UWORD _IRQ1:4;                 /*   _IRQ1      */
            _UWORD _IRQ2:4;                 /*   _IRQ2      */
            _UWORD _IRQ3:4;                 /*   _IRQ3      */
        } BIT;
    } IPR01;
    union {                                 /* IPR02        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _IRQ4:4;                 /*   _IRQ4      */
            _UWORD _IRQ5:4;                 /*   _IRQ5      */
            _UWORD _IRQ6:4;                 /*   _IRQ6      */
            _UWORD _IRQ7:4;                 /*   _IRQ7      */
        } BIT;
    } IPR02;
    _UBYTE wk3[4];
    _UBYTE wk4[992];
    union {                                 /* IPR06        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _DMAC0:4;                /*   DMAC0      */
            _UWORD _DMAC1:4;                /*   DMAC1      */
            _UWORD _DMAC2:4;                /*   DMAC2      */
            _UWORD _DMAC3:4;                /*   DMAC3      */
        } BIT;
    } IPR06;
    union {                                 /* IPR07        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _DMAC4:4;                /*   DMAC4      */
            _UWORD _DMAC5:4;                /*   DMAC5      */
            _UWORD _DMAC6:4;                /*   DMAC6      */
            _UWORD _DMAC7:4;                /*   DMAC7      */
        } BIT;
    } IPR07;
    union {                                 /* IPR08        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _USB:4;                  /*   USB        */
            _UWORD :4;                      /*              */
            _UWORD _CMT0:4;                 /*   CMT0       */
            _UWORD _CMT1:4;                 /*   CMT1       */
        } BIT;
    } IPR08;
    union {                                 /* IPR09        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _BSC:4;                  /*   BSC        */
            _UWORD _WDT:4;                  /*   WDT        */
            _UWORD _HIF0:4;                 /*   HIF0       */
            _UWORD _HIF1:4;                 /*   HIF1       */
        } BIT;
    } IPR09;
    union {                                 /* IPR10        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _ADM1I:4;                /*   ADM1I      */
            _UWORD _C0I:4;                  /*   C0I        */
            _UWORD _C1I:4;                  /*   C1I        */
            _UWORD :4;                      /*              */
        } BIT;
    } IPR10;
    union {                                 /* IPR11        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD :4;                      /*              */
            _UWORD FECI:4;                  /*   FECI       */
            _UWORD :4;                      /*              */
        } BIT;
    } IPR11;
    union {                                 /* IPR12        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _ETC:4;                  /*   ETC        */
            _UWORD _IIC3:4;                 /*   IIC3       */
            _UWORD :4;                      /*              */
            _UWORD STIF0:4;                 /*   STIF0      */
        } BIT;
    } IPR12;
    union {                                 /* IPR13        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _STIF1:4;                /*   STIF1      */
            _UWORD _SCIF0:4;                /*   SCIF0      */
            _UWORD _SCIF1:4;                /*   SCIF1      */
            _UWORD _SCIF2:4;                /*   SCIF2      */
        } BIT;
    } IPR13;
    union {                                 /* IPR14        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD :4;                      /*              */
            _UWORD :4;                      /*              */
            _UWORD _SSI0:4;                 /*   SSI0       */
        } BIT;
    } IPR14;
    union {                                 /* IPR15        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD _SSI1:4;                 /*   SSI1       */
            _UWORD :4;                      /*              */
            _UWORD :4;                      /*              */
            _UWORD :4;                      /*              */
        } BIT;
    } IPR15;
    union {                                 /* IPR16        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD _SDHI:4;                 /*   SDHI       */
            _UWORD :4;                      /*              */
            _UWORD :4;                      /*              */
        } BIT;
    } IPR16;
};

struct st_bsc {                                  /* struct BSC   */
       union {                                   /* CMNCR        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :23;                 /*              */
                    _UDWORD DMAIW:3;             /*   DMAIW      */
                    _UDWORD DMAIWA:1;            /*   DMAIWA     */
                    _UDWORD :3;                  /*              */
                    _UDWORD HIZMEM:1;            /*   HIZMEM     */
                    _UDWORD HIZCNT:1;            /*   HIZCNT     */
                    } BIT;                       /*              */
             } CMNCR;                            /*              */
       union {                                   /* CS0BCR       */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :1;                  /*              */
                    _UDWORD IWW:3;               /*   IWW        */
                    _UDWORD IWRWD:3;             /*   IWRWD      */
                    _UDWORD IWRWS:3;             /*   IWRWS      */
                    _UDWORD IWRRD:3;             /*   IWRRD      */
                    _UDWORD IWRRS:3;             /*   IWRRS      */
                    _UDWORD :1;                  /*              */
                    _UDWORD TYPE:3;              /*   TYPE       */
                    _UDWORD ENDIAN:1;            /*   ENDIAN     */
                    _UDWORD BSZ:2;               /*   BSZ        */
                    _UDWORD :9;                  /*              */
                    } BIT;                       /*              */
             } CS0BCR;                           /*              */
       _UBYTE wk0[8];                            /*              */
       union {                                   /* CS3BCR       */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :1;                  /*              */
                    _UDWORD IWW:3;               /*   IWW        */
                    _UDWORD IWRWD:3;             /*   IWRWD      */
                    _UDWORD IWRWS:3;             /*   IWRWS      */
                    _UDWORD IWRRD:3;             /*   IWRRD      */
                    _UDWORD IWRRS:3;             /*   IWRRS      */
                    _UDWORD :1;                  /*              */
                    _UDWORD TYPE:3;              /*   TYPE       */
                    _UDWORD ENDIAN:1;            /*   ENDIAN     */
                    _UDWORD BSZ:2;               /*   BSZ        */
                    _UDWORD :9;                  /*              */
                    } BIT;                       /*              */
             } CS3BCR;                           /*              */
       union {                                   /* CS4BCR       */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :1;                  /*              */
                    _UDWORD IWW:3;               /*   IWW        */
                    _UDWORD IWRWD:3;             /*   IWRWD      */
                    _UDWORD IWRWS:3;             /*   IWRWS      */
                    _UDWORD IWRRD:3;             /*   IWRRD      */
                    _UDWORD IWRRS:3;             /*   IWRRS      */
                    _UDWORD :1;                  /*              */
                    _UDWORD TYPE:3;              /*   TYPE       */
                    _UDWORD ENDIAN:1;            /*   ENDIAN     */
                    _UDWORD BSZ:2;               /*   BSZ        */
                    _UDWORD :9;                  /*              */
                    } BIT;                       /*              */
             } CS4BCR;                           /*              */
       union {                                   /* CS5BCR       */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :1;                  /*              */
                    _UDWORD IWW:3;               /*   IWW        */
                    _UDWORD IWRWD:3;             /*   IWRWD      */
                    _UDWORD IWRWS:3;             /*   IWRWS      */
                    _UDWORD IWRRD:3;             /*   IWRRD      */
                    _UDWORD IWRRS:3;             /*   IWRRS      */
                    _UDWORD :1;                  /*              */
                    _UDWORD TYPE:3;              /*   TYPE       */
                    _UDWORD ENDIAN:1;            /*   ENDIAN     */
                    _UDWORD BSZ:2;               /*   BSZ        */
                    _UDWORD :9;                  /*              */
                    } BIT;                       /*              */
             } CS5BCR;                           /*              */
       union {                                   /* CS6BCR       */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :1;                  /*              */
                    _UDWORD IWW:3;               /*   IWW        */
                    _UDWORD IWRWD:3;             /*   IWRWD      */
                    _UDWORD IWRWS:3;             /*   IWRWS      */
                    _UDWORD IWRRD:3;             /*   IWRRD      */
                    _UDWORD IWRRS:3;             /*   IWRRS      */
                    _UDWORD :1;                  /*              */
                    _UDWORD TYPE:3;              /*   TYPE       */
                    _UDWORD ENDIAN:1;            /*   ENDIAN     */
                    _UDWORD BSZ:2;               /*   BSZ        */
                    _UDWORD :9;                  /*              */
                    } BIT;                       /*              */
             } CS6BCR;                           /*              */
       _UBYTE wk1[8];                            /*              */
       union {                                   /*              */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :11;                 /*              */
                    _UDWORD BAS:1;               /*   BAS        */
                    _UDWORD :7;                  /*              */
                    _UDWORD SW:2;                /*   SW         */
                    _UDWORD WR:4;                /*   WR         */
                    _UDWORD WM:1;                /*   WM         */
                    _UDWORD :4;                  /*              */
                    _UDWORD HW:2;                /*   HW         */
                    } BIT;                       /*              */
             } CS0WCR;                           /*              */
       _UBYTE wk2[8];                            /*              */
       union {                                   /*              */
             union {                             /*              */
                   union {                       /* CS3WCR(NORMAL) */
                         _UDWORD LONG;           /*  Long Access */
                         struct {                /*  Bit Access  */
                                _UDWORD :11;     /*              */
                                _UDWORD BAS:1;   /*   BAS        */
                                _UDWORD :9;      /*              */
                                _UDWORD WR:4;    /*   WR         */
                                _UDWORD WM:1;    /*   WM         */
                                _UDWORD :6;      /*              */
                                } BIT;           /*              */
                         } REG_CS3WCR;           /*              */
                   } NORMAL;                     /*              */
             union {                             /*              */
                   union {                       /* CS3WCR(SDRAM) */
                         _UDWORD LONG;           /*  Long Access */
                         struct {                /*  Bit Access  */
                                _UDWORD :17;     /*              */
                                _UDWORD WTRP:2;  /*   WTRP       */
                                _UDWORD :1;      /*              */
                                _UDWORD WTRCD:2; /*   WTRCD      */
                                _UDWORD :1;      /*              */
                                _UDWORD A3CL:2;  /*   A3CL       */
                                _UDWORD :2;      /*              */
                                _UDWORD TRWL:2;  /*   TRWL       */
                                _UDWORD :1;      /*              */
                                _UDWORD WTRC:2;  /*   WTRC       */
                                } BIT;           /*              */
                         } REG_CS3WCR;           /*              */
                   } SDRAM;                      /*              */
             } UN3_BSC;                          /*              */
       union {                                   /*              */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :11;                 /*              */
                    _UDWORD BAS:1;               /*   BAS        */
                    _UDWORD :1;                  /*              */
                    _UDWORD WW:3;                /*   WW         */
                    _UDWORD :3;                  /*              */
                    _UDWORD SW:2;                /*   SW         */
                    _UDWORD WR:4;                /*   WR         */
                    _UDWORD WM:1;                /*   WM         */
                    _UDWORD :4;                  /*              */
                    _UDWORD HW:2;                /*   HW         */
                    } BIT;                       /*              */
             } CS4WCR;                           /*              */
       union {                                   /*              */
             union {                             /*              */
                   union {                       /* CS5WCR(NORMAL) */
                         _UDWORD LONG;           /*  Long Access */
                         struct {                /*  Bit Access  */
                                _UDWORD :11;     /*              */
                                _UDWORD BAS:1;   /*   BAS        */
                                _UDWORD :1;      /*              */
                                _UDWORD WW:3;    /*   WW         */
                                _UDWORD :3;      /*              */
                                _UDWORD SW:2;    /*   SW         */
                                _UDWORD WR:4;    /*   WR         */
                                _UDWORD WM:1;    /*   WM         */
                                _UDWORD :4;      /*              */
                                _UDWORD HW:2;    /*   HW         */
                                } BIT;           /*              */
                         } REG_CS5WCR;           /*              */
                   } NORMAL;                     /*              */
             union {                             /*              */
                   union {                       /* CS5WCR(PCMCIA) */
                         _UDWORD LONG;           /*  Long Access */
                         struct {                /*  Bit Access  */
                                _UDWORD :10;     /*              */
                                _UDWORD SA:2;    /*   SA         */
                                _UDWORD :5;      /*              */
                                _UDWORD TED:4;   /*   TED        */
                                _UDWORD PCW:4;   /*   PCW        */
                                _UDWORD WM:1;    /*   WM         */
                                _UDWORD :2;      /*              */
                                _UDWORD TEH:4;   /*   TEH        */
                                } BIT;           /*              */
                         } REG_CS5WCR;           /*              */
                   } PCMCIA;                     /*              */
             } UN5_BSC;                          /*              */
       union {                                   /*              */
             union {                             /*              */
                   union {                       /* CS6WCR(NORMAL) */
                         _UDWORD LONG;           /*  Long Access */
                         struct {                /*  Bit Access  */
                                _UDWORD :11;     /*              */
                                _UDWORD BAS:1;   /*   BAS        */
                                _UDWORD :7;      /*              */
                                _UDWORD SW:2;    /*   SW         */
                                _UDWORD WR:4;    /*   WR         */
                                _UDWORD WM:1;    /*   WM         */
                                _UDWORD :4;      /*              */
                                _UDWORD HW:2;    /*   HW         */
                                } BIT;           /*              */
                         } REG_CS6WCR;           /*              */
                   } NORMAL;                     /*              */
             union {                             /*              */
                   union {                       /* CS6WCR(PCMCIA) */
                         _UDWORD LONG;           /*  Long Access */
                         struct {                /*  Bit Access  */
                                _UDWORD :10;     /*              */
                                _UDWORD SA:2;    /*   SA         */
                                _UDWORD :5;      /*              */
                                _UDWORD TED:4;   /*   TED        */
                                _UDWORD PCW:4;   /*   PCW        */
                                _UDWORD WM:1;    /*   WM         */
                                _UDWORD :2;      /*              */
                                _UDWORD TEH:4;   /*   TEH        */
                                } BIT;           /*              */
                         } REG_CS6WCR;           /*              */
                   } PCMCIA;                     /*              */
             } UN6_BSC;                          /*              */
       _UBYTE wk3[8];                            /*              */
       union {                                   /* SDCR         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :18;                 /*              */
                    _UDWORD DEEP:1;              /*   DEEP       */
                    _UDWORD :1;                  /*              */
                    _UDWORD RFSH:1;              /*   RFSH       */
                    _UDWORD RMODE:1;             /*   RMODE      */
                    _UDWORD PDOWN:1;             /*   PDOWN      */
                    _UDWORD BACTV:1;             /*   BACTV      */
                    _UDWORD :3;                  /*              */
                    _UDWORD A3ROW:2;             /*   A3ROW      */
                    _UDWORD :1;                  /*              */
                    _UDWORD A3COL:2;             /*   A3COL      */
                    } BIT;                       /*              */
             } SDCR;                             /*              */
       union {                                   /* RTCSR        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :24;                 /*              */
                    _UDWORD CMF:1;               /*   CMF        */
                    _UDWORD CMIE:1;              /*   CMIE       */
                    _UDWORD CKS:3;               /*   CKS        */
                    _UDWORD RRC:3;               /*   RRC        */
                    } BIT;                       /*              */
             } RTCSR;                            /*              */
       union {                                   /* RTCNT        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RTCNT;                            /*              */
       union {                                   /* RTCOR        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RTCOR;                            /*              */
};

struct st_ac {                                   /* struct AC    */
       union {                                   /* ACSWR        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :28;                 /*              */
                    _UDWORD ACOSW:4;             /*   ACOSW      */
                    } BIT;                       /*              */
             } ACSWR;                            /*              */
       _UBYTE wk0[8];                            /*              */
       union {                                   /* IBMPR        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Bit Access  */
                    _UDWORD :2;                  /*              */
                    _UDWORD OP1R:2;              /*   OP1R       */
                    _UDWORD :2;                  /*              */
                    _UDWORD OP2R:2;              /*   OP2R       */
                    _UDWORD :2;                  /*              */
                    _UDWORD OP3R:2;              /*   OP3R       */
                    _UDWORD :20;                 /*              */
                    } BIT;                       /*              */
             } IBMPR;                            /*              */
       _UBYTE wk1[992];                          /*              */
       union {                                   /* ACKEYR       */
             _UBYTE BYTE;                        /*  Byte Access */
             struct {                            /*  Bit Access  */
                    _UBYTE D:8;                  /*   D          */
                    } BIT;                       /*              */
             } ACKEYR;                           /*              */
};                                               /*              */

struct st_dmac {                                 /* struct DMAC  */
       union {                                   /* SAR0         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR0;                             /*              */
       union {                                   /* DAR0         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR0;                             /*              */
       union {                                   /* DMATCR0      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR0;                          /*              */
       union {                                   /* CHCR0        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :4;                  /*              */
                    _UDWORD DO:1;                /*   DO         */
                    _UDWORD TL:1;                /*   TL         */
                    _UDWORD :1;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD AM:1;                /*   AM         */
                    _UDWORD AL:1;                /*   AL         */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD DL:1;                /*   DL         */
                    _UDWORD DS:1;                /*   DS         */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR0;                            /*              */
       union {                                   /* SAR1         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR1;                             /*              */
       union {                                   /* DAR1         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR1;                             /*              */
       union {                                   /* DMATCR1      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR1;                          /*              */
       union {                                   /* CHCR1        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :4;                  /*              */
                    _UDWORD DO:1;                /*   DO         */
                    _UDWORD TL:1;                /*   TL         */
                    _UDWORD :1;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD AM:1;                /*   AM         */
                    _UDWORD AL:1;                /*   AL         */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD DL:1;                /*   DL         */
                    _UDWORD DS:1;                /*   DS         */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR1;                            /*              */
       union {                                   /* SAR2         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR2;                             /*              */
       union {                                   /* DAR2         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR2;                             /*              */
       union {                                   /* DMATCR2      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR2;                          /*              */
       union {                                   /* CHCR2        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :7;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD :2;                  /*              */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD :2;                  /*              */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR2;                            /*              */
       union {                                   /* SAR3         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR3;                             /*              */
       union {                                   /* DAR3         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR3;                             /*              */
       union {                                   /* DMATCR3      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR3;                          /*              */
       union {                                   /* CHCR3        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :7;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD :2;                  /*              */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD :2;                  /*              */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR3;                            /*              */
       union {                                   /* SAR4         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR4;                             /*              */
       union {                                   /* DAR4         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR4;                             /*              */
       union {                                   /* DMATCR4      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR4;                          /*              */
       union {                                   /* CHCR4        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :7;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD :2;                  /*              */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD :2;                  /*              */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR4;                            /*              */
       union {                                   /* SAR5         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR5;                             /*              */
       union {                                   /* DAR5         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR5;                             /*              */
       union {                                   /* DMATCR5      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR5;                          /*              */
       union {                                   /* CHCR5        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :7;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD :2;                  /*              */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD :2;                  /*              */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR5;                            /*              */
       union {                                   /* SAR6         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR6;                             /*              */
       union {                                   /* DAR6         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR6;                             /*              */
       union {                                   /* DMATCR6      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR6;                          /*              */
       union {                                   /* CHCR6        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :7;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD :2;                  /*              */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD :2;                  /*              */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR6;                            /*              */
       union {                                   /* SAR7         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } SAR7;                             /*              */
       union {                                   /* DAR7         */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DAR7;                             /*              */
       union {                                   /* DMATCR7      */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } DMATCR7;                          /*              */
       union {                                   /* CHCR7        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Byte Access */
                    _UBYTE HH;                   /*   High, High */
                    _UBYTE HL;                   /*   High, Low  */
                    _UBYTE LH;                   /*   Low, High  */
                    _UBYTE LL;                   /*   Low, Low   */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD TC:1;                /*   TC         */
                    _UDWORD :1;                  /*              */
                    _UDWORD RLDSAR:1;            /*   RLDSAR     */
                    _UDWORD RLDDAR:1;            /*   RLDDAR     */
                    _UDWORD :7;                  /*              */
                    _UDWORD TEMASK:1;            /*   TEMASK     */
                    _UDWORD HE:1;                /*   HE         */
                    _UDWORD HIE:1;               /*   HIE        */
                    _UDWORD :2;                  /*              */
                    _UDWORD DM:2;                /*   DM         */
                    _UDWORD SM:2;                /*   SM         */
                    _UDWORD RS:4;                /*   RS         */
                    _UDWORD :2;                  /*              */
                    _UDWORD TB:1;                /*   TB         */
                    _UDWORD TS:2;                /*   TS         */
                    _UDWORD IE:1;                /*   IE         */
                    _UDWORD TE:1;                /*   TE         */
                    _UDWORD DE:1;                /*   DE         */
                    } BIT;                       /*              */
             } CHCR7;                            /*              */
       _UBYTE wk0[128];                          /*              */
       union {                                   /* RSAR0        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR0;                            /*              */
       union {                                   /* RDAR0        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR0;                            /*              */
       union {                                   /* RDMATCR0     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR0;                         /*              */
       _UBYTE wk1[4];                            /*              */
       union {                                   /* RSAR1        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR1;                            /*              */
       union {                                   /* RDAR1        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR1;                            /*              */
       union {                                   /* RDMATCR1     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR1;                         /*              */
       _UBYTE wk2[4];                            /*              */
       union {                                   /* RSAR2        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR2;                            /*              */
       union {                                   /* RDAR2        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR2;                            /*              */
       union {                                   /* RDMATCR2     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR2;                         /*              */
       _UBYTE wk3[4];                            /*              */
       union {                                   /* RSAR3        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR3;                            /*              */
       union {                                   /* RDAR3        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR3;                            /*              */
       union {                                   /* RDMATCR3     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR3;                         /*              */
       _UBYTE wk4[4];                            /*              */
       union {                                   /* RSAR4        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR4;                            /*              */
       union {                                   /* RDAR4        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR4;                            /*              */
       union {                                   /* RDMATCR4     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR4;                         /*              */
       _UBYTE wk5[4];                            /*              */
       union {                                   /* RSAR5        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR5;                            /*              */
       union {                                   /* RDAR5        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR5;                            /*              */
       union {                                   /* RDMATCR5     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR5;                         /*              */
       _UBYTE wk6[4];                            /*              */
       union {                                   /* RSAR6        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR6;                            /*              */
       union {                                   /* RDAR6        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR6;                            /*              */
       union {                                   /* RDMATCR6     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR6;                         /*              */
       _UBYTE wk7[4];                            /*              */
       union {                                   /* RSAR7        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RSAR7;                            /*              */
       union {                                   /* RDAR7        */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDAR7;                            /*              */
       union {                                   /* RDMATCR7     */
             _UDWORD LONG;                       /*  Long Access */
             struct {                            /*  Word Access */
                    _UWORD H;                    /*   High       */
                    _UWORD L;                    /*   Low        */
                    } WORD;                      /*              */
             struct {                            /*  Bit Access  */
                    _UDWORD D:32;                /*   D          */
                    } BIT;                       /*              */
             } RDMATCR7;                         /*              */
       _UBYTE wk8[132];                          /*              */
       union {                                   /* DMAOR        */
             _UWORD WORD;                        /*  Word Access */
             struct {                            /*  Byte Access */
                    _UBYTE H;                    /*   High       */
                    _UBYTE L;                    /*   Low        */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UWORD :2;                   /*              */
                    _UWORD CMS:2;                /*   CMS        */
                    _UWORD :2;                   /*              */
                    _UWORD PR:2;                 /*   PR         */
                    _UWORD :5;                   /*              */
                    _UWORD AE:1;                 /*   AE         */
                    _UWORD NMIF:1;               /*   NMIF       */
                    _UWORD DME:1;                /*   DME        */
                    } BIT;                       /*              */
             } DMAOR;                            /*              */
       _UBYTE wk9[254];                          /*              */
       union {                                   /* DMARS0       */
             _UWORD WORD;                        /*  Word Access */
             struct {                            /*  Byte Access */
                    _UWORD CH1:8;                /*   CH1        */
                    _UWORD CH0:8;                /*   CH0        */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UWORD CH1MID:6;             /*   CH1MID     */
                    _UWORD CH1RID:2;             /*   CH1RID     */
                    _UWORD CH0MID:6;             /*   CH0MID     */
                    _UWORD CH0RID:2;             /*   CH0RID     */
                    } BIT;                       /*              */
             } DMARS0;                           /*              */
       _UBYTE wk10[2];                           /*              */
       union {                                   /* DMARS1       */
             _UWORD WORD;                        /*  Word Access */
             struct {                            /*  Byte Access */
                    _UWORD CH3:8;                /*   CH3        */
                    _UWORD CH2:8;                /*   CH2        */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UWORD CH3MID:6;             /*   CH3MID     */
                    _UWORD CH3RID:2;             /*   CH3RID     */
                    _UWORD CH2MID:6;             /*   CH2MID     */
                    _UWORD CH2RID:2;             /*   CH2RID     */
                    } BIT;                       /*              */
             } DMARS1;                           /*              */
       _UBYTE wk11[2];                           /*              */
       union {                                   /* DMARS2       */
             _UWORD WORD;                        /*  Word Access */
             struct {                            /*  Byte Access */
                    _UWORD CH5:8;                /*   CH5        */
                    _UWORD CH4:8;                /*   CH4        */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UWORD CH5MID:6;             /*   CH5MID     */
                    _UWORD CH5RID:2;             /*   CH5RID     */
                    _UWORD CH4MID:6;             /*   CH4MID     */
                    _UWORD CH4RID:2;             /*   CH4RID     */
                    } BIT;                       /*              */
             } DMARS2;                           /*              */
       _UBYTE wk12[2];                           /*              */
       union {                                   /* DMARS3       */
             _UWORD WORD;                        /*  Word Access */
             struct {                            /*  Byte Access */
                    _UWORD CH7:8;                /*   CH7        */
                    _UWORD CH6:8;                /*   CH6        */
                    } BYTE;                      /*              */
             struct {                            /*  Bit Access  */
                    _UWORD CH7MID:6;             /*   CH7MID     */
                    _UWORD CH7RID:2;             /*   CH7RID     */
                    _UWORD CH6MID:6;             /*   CH6MID     */
                    _UWORD CH6RID:2;             /*   CH6RID     */
                    } BIT;                       /*              */
             } DMARS3;                           /*              */
};                                               /*              */

struct st_cpg {                             /* struct CPG   */
    union {                                 /* FRQCR        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :2;                      /*              */
            _UWORD CKOEN:2;                 /*   CKOEN      */
            _UWORD :2;                      /*              */
            _UWORD STC:2;                   /*   STC        */
            _UWORD :3;                      /*              */
            _UWORD IFC:1;                   /*   IFC        */
            _UWORD :1;                      /*              */
            _UWORD PFC:3;                   /*   PFC        */
        } BIT;
    } FRQCR;
	_UBYTE wk0[2];
	union {									/* STBCR        */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE STBY:1;					/*   STBY       */
			_UBYTE :7;						/*              */
		} BIT;
	} STBCR;
	_UBYTE wk1[3];
	union {									/* STBCR2       */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE MSTP10:1;				/*  MSTP10(H-UDI) */
			_UBYTE MSTP9:1;					/*  MSTP9(UBC)    */
			_UBYTE MSTP8:1;					/*  MSTP8(DMAC)   */
			_UBYTE MSTP7:1;					/*  MSTP7(FPU)  */
			_UBYTE :4;						/*              */
		} BIT;
	} STBCR2;
	_UBYTE wk2[1001];
	union {									/* SYSCR1       */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE :4;						/*              */
			_UBYTE RAME3:1;					/*   RAME3      */
			_UBYTE RAME2:1;					/*   RAME2      */
			_UBYTE RAME1:1;					/*   RAME1      */
			_UBYTE RAME0:1;					/*   RAME0      */
		} BIT;
	} SYSCR1;
	_UBYTE wk3[1];
	union {									/* SYSCR2       */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE :4;						/*              */
			_UBYTE RAMWE3:1;				/*   RAMWE3     */
			_UBYTE RAMWE2:1;				/*   RAMWE2     */
			_UBYTE RAMWE1:1;				/*   RAMWE1     */
			_UBYTE RAMWE0:1;				/*   RAMWE0     */
		} BIT;
	} SYSCR2;
	_UBYTE wk4[3];
	union {									/* STBCR3       */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE HIZ:1;					/*  HIZ         */
			_UBYTE MSTP36:1;				/*  MSTP35(IEB) */
			_UBYTE MSTP35:1;				/*  MSTP35(MTU2) */
			_UBYTE MSTP34:1;				/*  MSTP35(SDHI0) */
			_UBYTE MSTP33:1;				/*  MSTP33(SDHI1) */
			_UBYTE MSTP32:1;				/*  MSTP32(ADC) */
			_UBYTE MSTP31:1;				/*  MSTP31(DAC) */
			_UBYTE MSTP30:1;				/*  MSTP30(RTC) */
		} BIT;
	} STBCR3;
	_UBYTE wk5[3];
	union {									/* STBCR4       */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE :1;				        /*                 */
			_UBYTE MSTP46:1;				/*   MSTP46(SCIF1) */
			_UBYTE MSTP45:1;				/*   MSTP45(SCIF2) */
			_UBYTE MSTP44:1;				/*   MSTP44(SCIF3) */
			_UBYTE MSTP43:1;				/*   MSTP43(A-DMAC)*/
			_UBYTE MSTP42:1;				/*   MSTP42(CMT)   */
			_UBYTE MSTP41:1;				/*   MSTP41(LCDC)  */
			_UBYTE MSTP40:1;				/*   MSTP40(FLCLT) */
		} BIT;
	} STBCR4;
	_UBYTE wk6[11];
	union {									/* SYSCR3       */
		_UBYTE BYTE;						/*  Byte Access */
		struct {							/*  Bit Access  */
			_UBYTE :6;						/*              */
			_UBYTE SSI1SRST:1;				/*   SSI1SRST   */
			_UBYTE SSI0SRST:1;				/*   SSI0SRST   */
		} BIT;
	} SYSCR3;
};

struct st_wdt {                             /* struct WDT   */
    union {                                 /* WTCSR        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UBYTE IOVF:1;                  /*   IOVF       */
            _UBYTE WT_IT:1;                 /*   WT_IT      */
            _UBYTE TME:1;                   /*   TME        */
            _UBYTE :2;                      /*              */
            _UBYTE CKS:3;                   /*   CKS        */
        } BIT;
    } WTCSR;
    union {                                 /* WTCNT        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UBYTE TCNT:8;                  /*   TCNT       */
        } BIT;
    } WTCNT;
    union {                                 /* WRCSR        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UBYTE WOVF:1;                  /*   WOVF       */
            _UBYTE RSTE:1;                  /*   RSTE       */
            _UBYTE RSTS:1;                  /*   RSTS       */
            _UBYTE :5;                      /*              */
        } BIT;
    } WRCSR;
};

struct st_etherc {                          /* struct EtherC*/
    union {                                 /* ECMR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :12;                    /*              */
            _UDWORD ZPF:1;                  /*   ZPF        */
            _UDWORD PFR:1;                  /*   PFR        */
            _UDWORD RXF:1;                  /*   RXF        */
            _UDWORD TXF:1;                  /*   TXF        */
            _UDWORD :3;                     /*              */
            _UDWORD PRCEF:1;                /*   PRCEF      */
            _UDWORD :2;                     /*              */
            _UDWORD MPDE:1;                 /*   MPDE       */
            _UDWORD :2;                     /*              */
            _UDWORD RE:1;                   /*   RE         */
            _UDWORD TE:1;                   /*   TE         */
            _UDWORD :1;                     /*              */
            _UDWORD ILB:1;                  /*   ILB        */
            _UDWORD ELB:1;                  /*   ELB        */
            _UDWORD DM:1;                   /*   DM         */
            _UDWORD PRM:1;                  /*   PRM        */
        } BIT;
    } ECMR;
    union {                                 /* ECSR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :27;                    /*              */
            _UDWORD PSRTO:1;                /*   PSRTO      */
            _UDWORD :1;                     /*              */
            _UDWORD LCHNG:1;                /*   LCHNG      */
            _UDWORD MPD:1;                  /*   MPD        */
            _UDWORD ICD:1;                  /*   ICD        */
        } BIT;
    } ECSR;
    union {                                 /* ECSIPR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :27;                    /*              */
            _UDWORD PSRTOIP:1;              /*   PSRTOIP    */
            _UDWORD :1;                     /*              */
            _UDWORD LCHNGIP:1;              /*   LCHNGIP    */
            _UDWORD MPDIP:1;                /*   MPDIP      */
            _UDWORD ICDIP:1;                /*   ICDIP      */
        } BIT;
    } ECSIPR;
    union {                                 /* PIR          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :28;                    /*              */
            _UDWORD MDI:1;                  /*   MDI        */
            _UDWORD MDO:1;                  /*   MDO        */
            _UDWORD MMD:1;                  /*   MMD        */
            _UDWORD MDC:1;                  /*   MDC        */
        } BIT;
    } PIR;
    union {                                 /* MAHR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD MA:32;                  /*   MA         */
        } BIT;
    } MAHR;
    union {                                 /* MALR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD MA:16;                  /*   MA         */
        } BIT;
    } MALR;
    union {                                 /* RFLR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :20;                    /*              */
            _UDWORD RFL:12;                 /*   RFL        */
        } BIT;
    } RFLR;
    union {                                 /* PSR          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD LMON:1;                 /*   LMON       */
        } BIT;
    } PSR;
    union {                                 /* TROCR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD TROC:32;                /*   TROC       */
        } BIT;
    } TROCR;
    union {                                 /* CDCR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD COSDC:32;               /*   COSDC      */
        } BIT;
    } CDCR;
    union {                                 /* LCCR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD LCC:32;                 /*   LCC        */
        } BIT;
    } LCCR;
    union {                                 /* CNDCR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD CNDC:32;                /*   CNDC       */
        } BIT;
    } CNDCR;
    _UBYTE wk0[4];
    union {                                 /* CEFCR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD CEFC:32;                /*   CEFC       */
        } BIT;
    } CEFCR;
    union {                                 /* FRECR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD FREC:32;                /*   FREC       */
        } BIT;
    } FRECR;
    union {                                 /* TSFRCR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD TSFC:32;                /*   TSFC       */
        } BIT;
    } TSFRCR;
    union {                                 /* TLFRCR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD TLFC:32;                /*   TLFC       */
        } BIT;
    } TLFRCR;
    union {                                 /* RFCR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD RFC:32;                 /*   RFC        */
        } BIT;
    } RFCR;
    union {                                 /* MAFCR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD MAFC:32;                /*   MAFC       */
        } BIT;
    } MAFCR;
    _UBYTE wk1[8];
    union {                                 /* IPGR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :27;                    /*              */
            _UDWORD IPG:5;                  /*   IPG        */
        } BIT;
    } IPGR;
    union {                                 /* APR          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD AP:16;                  /*   AP         */
        } BIT;
    } APR;
    union {                                 /* MPR          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD MP:16;                  /*   MP         */
        } BIT;
    } MPR;
    _UBYTE wk2[4];
    union {                                 /* TPAUSER      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD TPAUSE:16;              /*   TPAUSE     */
        } BIT;
    } TPAUSER;
};

struct st_edmac {                           /* struct E-DMAC*/
    union {                                 /* EDMR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :25;                    /*              */
            _UDWORD DE:1;                   /*   DE         */
            _UDWORD DL:2;                   /*   DL         */
            _UDWORD :3;                     /*              */
            _UDWORD SWR:1;                  /*   SWR        */
        } BIT;
    } EDMR;
    union {                                 /* EDTRR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD TR:1;                   /*   TR         */
        } BIT;
    } EDTRR;
    union {                                 /* EDRRR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD RR:1;                   /*   RR         */
        } BIT;
    } EDRRR;
    union {                                 /* TDLAR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD TDLA:32;                /*   TDLA       */
        } BIT;
    } TDLAR;
    union {                                 /* RDLAR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD RDLA:32;                /*   RDLA       */
        } BIT;
    } RDLAR;
    union {                                 /* EESR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :1;                     /*              */
            _UDWORD TWB:1;                  /*   TWB        */
            _UDWORD :3;                     /*              */
            _UDWORD TABT:1;                 /*   TABT       */
            _UDWORD RABT:1;                 /*   RABT       */
            _UDWORD RFCOF:1;                /*   RFCOF      */
            _UDWORD ADE:1;                  /*   ADE        */
            _UDWORD ECI:1;                  /*   ECI        */
            _UDWORD TC:1;                   /*   TC         */
            _UDWORD TDE:1;                  /*   TDE        */
            _UDWORD TFUF:1;                 /*   TFUF       */
            _UDWORD FR:1;                   /*   FR         */
            _UDWORD RDE:1;                  /*   RDE        */
            _UDWORD RFOF:1;                 /*   RFOF       */
            _UDWORD :4;                     /*              */
            _UDWORD CND:1;                  /*   CND        */
            _UDWORD DLC:1;                  /*   DLC        */
            _UDWORD CD:1;                   /*   CD         */
            _UDWORD TRO:1;                  /*   TRO        */
            _UDWORD RMAF:1;                 /*   RMAF       */
            _UDWORD :2;                     /*              */
            _UDWORD RRF:1;                  /*   RRF        */
            _UDWORD RTLF:1;                 /*   RTLF       */
            _UDWORD RTSF:1;                 /*   RTSF       */
            _UDWORD PRE:1;                  /*   PRE        */
            _UDWORD CERF:1;                 /*   CERF       */
        } BIT;
    } EESR;
    union {                                 /* EESIPR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :1;                     /*              */
            _UDWORD TWBIP:1;                /*   TWBIP      */
            _UDWORD :3;                     /*              */
            _UDWORD TABTIP:1;               /*   TABTIP     */
            _UDWORD RABTIP:1;               /*   RABTIP     */
            _UDWORD RFCOFIP:1;              /*   RFCOFIP    */
            _UDWORD ADEIP:1;                /*   ADEIP      */
            _UDWORD ECIIP:1;                /*   ECIIP      */
            _UDWORD TCIP:1;                 /*   TCIP       */
            _UDWORD TDEIP:1;                /*   TDEIP      */
            _UDWORD TFUFIP:1;               /*   TFUFIP     */
            _UDWORD FRIP:1;                 /*   FRIP       */
            _UDWORD RDEIP:1;                /*   RDEIP      */
            _UDWORD RFOFIP:1;               /*   RFOFIP     */
            _UDWORD :4;                     /*              */
            _UDWORD CNDIP:1;                /*   CNDIP      */
            _UDWORD DLCIP:1;                /*   DLCIP      */
            _UDWORD CDIP:1;                 /*   CDIP       */
            _UDWORD TROIP:1;                /*   TROIP      */
            _UDWORD RMAFIP:1;               /*   RMAFIP     */
            _UDWORD :2;                     /*              */
            _UDWORD RRFIP:1;                /*   RRFIP      */
            _UDWORD RTLFIP:1;               /*   RTLFIP     */
            _UDWORD RTSFIP:1;               /*   RTSFIP     */
            _UDWORD PREIP:1;                /*   PREIP      */
            _UDWORD CERFIP:1;               /*   CERFIP     */
        } BIT;
    } EESIPR;
    union {                                 /* TRSCER       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :20;                    /*              */
            _UDWORD CNDCE:1;                /*   CNDCE      */
            _UDWORD DLCCE:1;                /*   DLCCE      */
            _UDWORD CDCE:1;                 /*   CDCE       */
            _UDWORD TROCE:1;                /*   TROCE      */
            _UDWORD RMAFCE:1;               /*   RMAFCE     */
            _UDWORD :2;                     /*              */
            _UDWORD RRFCE:1;                /*   RRFCE      */
            _UDWORD RTLFCE:1;               /*   RTLFCE     */
            _UDWORD RTSFCE:1;               /*   RTSFCE     */
            _UDWORD PRECE:1;                /*   PRECE      */
            _UDWORD CERFCE:1;               /*   CERFCE     */
        } BIT;
    } TRSCER;
    union {                                 /* RMFCR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD MFC:16;                 /*   MFC        */
        } BIT;
    } RMFCR;
    union {                                 /* TFTR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :21;                    /*              */
            _UDWORD TFT:11;                 /*   TFT        */
        } BIT;
    } TFTR;
    union {                                 /* FDR          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :21;                    /*              */
            _UDWORD TFD:3;                  /*   TFD        */
            _UDWORD :5;                     /*              */
            _UDWORD RFD:3;                  /*   RFD        */
        } BIT;
    } FDR;
    union {                                 /* RMCR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD RNC:1;                  /*   RNC        */
        } BIT;
    } RMCR;
    union {                                 /* EDOCR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :28;                    /*              */
            _UDWORD FEC:1;                  /*   FEC        */
            _UDWORD AEC:1;                  /*   AEC        */
            _UDWORD EDH:1;                  /*   EDH        */
            _UDWORD :1;                     /*              */
        } BIT;
    } EDOCR;
    union {                                 /* FCFTR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :13;                    /*              */
            _UDWORD RFF:3;                  /*   RFF        */
            _UDWORD :13;                    /*              */
            _UDWORD RFD:3;                  /*   RFD        */
        } BIT;
    } FCFTR;
    union {                                 /* RPADIR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :14;                    /*              */
            _UDWORD PADS:2;                 /*   PADS       */
            _UDWORD :10;                    /*              */
            _UDWORD PADR:6;                 /*   PADR       */
        } BIT;
    } RPADIR;
    union {                                 /* TRIMD        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD TIS:1;                  /*   TIS        */
        } BIT;
    } TRIMD;
    union {                                 /* RBWAR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD RBWA:32;                /*   RBWA       */
        } BIT;
    } RBWAR;
    union {                                 /* RDFAR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD RDFA:32;                /*   RDFA       */
        } BIT;
    } RDFAR;
    _UBYTE wk0[4];
    union {                                 /* TBRAR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD TBRA:32;                /*   TBRA       */
        } BIT;
    } TBRAR;
    union {                                 /* TDFAR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD TDFA:32;                /*   TDFA       */
        } BIT;
    } TDFAR;
    _UBYTE wk1[144];
    union {                                 /* CSMR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD CSEBL:1;                /*   CSEBL      */
            _UDWORD CSMD:1;                 /*   CSMD       */
            _UDWORD :24;                    /*              */
            _UDWORD SB:6;                   /*   SB         */
        } BIT;
    } CSMR;
    union {                                 /* CSSBM        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :26;                    /*              */
            _UDWORD SBM:6;                  /*   SBM        */
        } BIT;
    } CSSBM;
    union {                                 /* CSSMR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD CS:16;                  /*   CS         */
        } BIT;
    } CSSMR;
};

struct st_admac {                           /* struct A-DMAC*/
    union {                                 /* C0C          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :15;                    /*              */
            _UDWORD C0C_R:1;                /*   C0C_R      */
            _UDWORD :3;                     /*              */
            _UDWORD C0C_DWF:1;              /*   C0C_DWF    */
            _UDWORD :3;                     /*              */
            _UDWORD C0C_VLD:1;              /*   C0C_VLD    */
            _UDWORD :3;                     /*              */
            _UDWORD C0C_EIE:1;              /*   C0C_EIE    */
            _UDWORD :3;                     /*              */
            _UDWORD C0C_E:1;                /*   C0C_E      */
        } BIT;
    } C0C;
    union {                                 /* C0M          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :27;                    /*              */
            _UDWORD C0M_LIE:1;              /*   C0M_LIE    */
            _UDWORD :4;                     /*              */
        } BIT;
    } C0M;
    union {                                 /* C0I          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :19;                    /*              */
            _UDWORD C0I_DI:1;               /*   C0I_DI     */
            _UDWORD :3;                     /*              */
            _UDWORD C0I_LI:1;               /*   C0I_LI     */
            _UDWORD :7;                     /*              */
            _UDWORD C0I_EI:1;               /*   C0I_EI     */
        } BIT;
    } C0I;
    _UBYTE wk0[48];
    _UDWORD C0DSA;                          /* C0DSA        */
    _UDWORD C0DCA;                          /* C0DCA        */
    union {                                 /* C0D0         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD C0CRDO:4;               /*   C0CRDO     */
            _UDWORD C0CHDO:4;               /*   C0CHDO     */
            _UDWORD C0SO:4;                 /*   C0SO       */
            _UDWORD C0DA:1;                 /*   C0DA       */
            _UDWORD C0SA:1;                 /*   C0SA       */
            _UDWORD C0CSM:2;                /*   C0CSM      */
            _UDWORD :13;                    /*              */
            _UDWORD C0F2:1;                  /*   C0F2      */
            _UDWORD C0F1:1;                  /*   C0F1      */
            _UDWORD C0F0:1;                  /*   C0F0      */
        } BIT;
    } C0D0;
    _UDWORD C0D1;                           /* C0D1         */
    _UDWORD C0D2;                           /* C0D2         */
    union {                                 /* C0D3         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :2;                     /*              */
            _UDWORD C0DWE:1;                /*              */
            _UDWORD C0DIE:1;                /*              */
            _UDWORD :12;                    /*              */
            _UDWORD C0D3:16;                /*              */
        } BIT;
    } C0D3;
    union {                                 /* C0D4         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD C0D4:31;                /*   C0D4       */
            _UDWORD :1;                     /*              */
        } BIT;
    } C0D4;
    _UBYTE wk1[24];
    union {                                 /* C1C          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :15;                    /*              */
            _UDWORD C1C_R:1;                /*   C1C_R      */
            _UDWORD :3;                     /*              */
            _UDWORD C1C_DWF:1;              /*   C1C_DWF    */
            _UDWORD :3;                     /*              */
            _UDWORD C1C_VLD:1;              /*   C1C_VLD    */
            _UDWORD :3;                     /*              */
            _UDWORD C1C_EIE:1;              /*   C1C_EIE    */
            _UDWORD :3;                     /*              */
            _UDWORD C1C_E:1;                /*   C1C_E      */
        } BIT;
    } C1C;
    union {                                 /* C1M          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :27;                    /*              */
            _UDWORD C1M_LIE:1;              /*   C1M_LIE    */
            _UDWORD :4;                     /*              */
        } BIT;
    } C1M;
    union {                                 /* C1I          */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :19;                    /*              */
            _UDWORD C1I_DI:1;               /*   C1I_DI     */
            _UDWORD :3;                     /*              */
            _UDWORD C1I_LI:1;               /*   C1I_LI     */
            _UDWORD :7;                     /*              */
            _UDWORD C1I_EI:1;               /*   C1I_EI     */
        } BIT;
    } C1I;
    _UBYTE wk2[48];
    _UDWORD C1DSA;                          /* C1DSA        */
    _UDWORD C1DCA;                          /* C1DCA        */
    union {                                 /* C1D0         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD C1CRDO:4;               /*   C1CRDO     */
            _UDWORD C1CHDO:4;               /*   C1CHDO     */
            _UDWORD C1SO:4;                 /*   C1SO       */
            _UDWORD C1DA:1;                 /*   C1DA       */
            _UDWORD C1SA:1;                 /*   C1SA       */
            _UDWORD C1CSM:2;                /*   C1CSM      */
            _UDWORD :13;                    /*              */
            _UDWORD C0F2:1;                  /*   C0F2      */
            _UDWORD C0F1:1;                  /*   C0F1      */
            _UDWORD C0F0:1;                  /*   C0F0      */
        } BIT;
    } C1D0;
    _UDWORD C1D1;                           /* C1D1         */
    _UDWORD C1D2;                           /* C1D2         */
    union {                                 /* C1D3         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :2;                     /*              */
            _UDWORD C1DWE:1;                /*              */
            _UDWORD C1DIE:1;                /*              */
            _UDWORD :12;                    /*              */
            _UDWORD C1D3:16;                /*              */
        } BIT;
    } C1D3;
    _UDWORD C1D4;                           /* C1D4         */
    _UBYTE wk3[136];
    union {                                 /* FECC         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_R:1;               /*   FECC_R     */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_DWF:1;             /*   FECC_DWF   */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_DWE:1;             /*   FECC_DWE   */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_DIE:1;             /*   FECC_DIE   */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_LIE:1;             /*   FECC_LIE   */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_NIE:1;             /*   FECC_NIE   */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_EIE:1;             /*   FECC_EIE   */
            _UDWORD :3;                     /*              */
            _UDWORD FECC_E:1;               /*   FECC_E     */
        } BIT;
    } FECC;
    union {                                 /* FECI         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :19;                    /*              */
            _UDWORD FECI_DI:1;              /*   FECI_DI    */
            _UDWORD :3;                     /*              */
            _UDWORD FECI_LI:1;              /*   FECI_LI    */
            _UDWORD :3;                     /*              */
            _UDWORD FECI_NI:1;              /*   FECI_NI    */
            _UDWORD :3;                     /*              */
            _UDWORD FECI_EI:1;              /*   FECI_EI    */
        } BIT;
    } FECI;
    _UDWORD FECDSA;                         /* FECDSA       */
    _UDWORD FECDCA;                         /* FECDCA       */
    union {                                 /* FECD00       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD FECD00_SZ:16;           /*   FECD00_SZ  */
            _UDWORD FECD00_DO:4;            /*   FECD00_DO  */
            _UDWORD FECD00_SO:4;            /*   FECD00_SO  */
            _UDWORD FECD00_SN:4;            /*   FECD00_SN  */
            _UDWORD FECD00_DRE:1;           /*   FECD00_DRE */
            _UDWORD FECD00_F2:1;            /*   FECD00_F2  */
            _UDWORD FECD00_F1:1;            /*   FECD00_F1  */
            _UDWORD FECD00_F0:1;            /*   FECD00_F0  */
        } BIT;
    } FECD00;
    _UDWORD FECD01D0A;                      /* FECD01D0A       */
    _UDWORD FECD02S0A;                      /* FECD02S0A       */
    _UDWORD FECD03S1A;                      /* FECD03S1A       */
};

struct st_stif   {                          /* struct STIF  */
    union {                                 /* STMDR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :17;                    /*              */
            _UDWORD LSBSEL:1;               /*   LSBSEL     */
            _UDWORD EDGSEL:1;               /*   EDGSEL     */
            _UDWORD CLKSEL:1;               /*   CLKSEL     */
            _UDWORD CKFRSEL3:1;             /*   CKFRSEL3   */
            _UDWORD CKFRSEL2:1;             /*   CKFRSEL2   */
            _UDWORD CKFRSEL1:1;             /*   CKFRSEL1   */
            _UDWORD CKFRSEL0:1;             /*   CKFRSEL0   */
            _UDWORD REQACSEL:1;             /*   REQACSEL   */
            _UDWORD VLDACTSEL:1;            /*   VLDACTSEL  */
            _UDWORD SYCACTSEL:1;            /*   SYCACTSEL  */
            _UDWORD IOSEL:1;                /*   IOSEL      */
            _UDWORD IFMDSEL3:1;             /*   IFMDSEL3   */
            _UDWORD IFMDSEL2:1;             /*   IFMDSEL2   */
            _UDWORD IFMDSEL1:1;             /*   IFMDSEL1   */
            _UDWORD IFMDSEL0:1;             /*   IFMDSEL0   */
        } BIT;
    } STMDR;
    union {                                 /* STCTLR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :20;                    /*              */
            _UDWORD RCVTM2:1;               /*   RCVTM2     */
            _UDWORD RCVTM1:1;               /*   RCVTM1     */
            _UDWORD RCVTM0:1;               /*   RCVTM0     */
            _UDWORD RCV:1;                  /*   RCV        */
            _UDWORD TRICK:1;                /*   TRICK      */
            _UDWORD :4;                     /*              */
            _UDWORD REQEN:1;                /*   REQEN      */
            _UDWORD EN:1;                   /*   EN         */
            _UDWORD SRST:1;                 /*   SRST       */
        } BIT;
    } STCTLR;
    union {                                 /* STCNTCR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :28;                    /*              */
            _UDWORD CRD:1;                  /*   CRD        */
            _UDWORD CSTP:1;                 /*   CSTP       */
            _UDWORD CSET:1;                 /*   CSET       */
            _UDWORD CRST:1;                 /*   CRST       */
        } BIT;
    } STCNTCR;
    union {                                 /* STCNTVR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD VLU31:1;                /*   VLU31      */
            _UDWORD VLU30:1;                /*   VLU30      */
            _UDWORD VLU29:1;                /*   VLU29      */
            _UDWORD VLU28:1;                /*   VLU28      */
            _UDWORD VLU27:1;                /*   VLU27      */
            _UDWORD VLU26:1;                /*   VLU26      */
            _UDWORD VLU25:1;                /*   VLU25      */
            _UDWORD VLU24:1;                /*   VLU24      */
            _UDWORD VLU23:1;                /*   VLU23      */
            _UDWORD VLU22:1;                /*   VLU22      */
            _UDWORD VLU21:1;                /*   VLU21      */
            _UDWORD VLU20:1;                /*   VLU20      */
            _UDWORD VLU19:1;                /*   VLU19      */
            _UDWORD VLU18:1;                /*   VLU18      */
            _UDWORD VLU17:1;                /*   VLU17      */
            _UDWORD VLU16:1;                /*   VLU16      */
            _UDWORD VLU15:1;                /*   VLU15      */
            _UDWORD VLU14:1;                /*   VLU14      */
            _UDWORD VLU13:1;                /*   VLU13      */
            _UDWORD VLU12:1;                /*   VLU12      */
            _UDWORD VLU11:1;                /*   VLU11      */
            _UDWORD VLU10:1;                /*   VLU10      */
            _UDWORD VLU9:1;                 /*   VLU9       */
            _UDWORD VLU8:1;                 /*   VLU8       */
            _UDWORD VLU7:1;                 /*   VLU7       */
            _UDWORD VLU6:1;                 /*   VLU6       */
            _UDWORD VLU5:1;                 /*   VLU5       */
            _UDWORD VLU4:1;                 /*   VLU4       */
            _UDWORD VLU3:1;                 /*   VLU3       */
            _UDWORD VLU2:1;                 /*   VLU2       */
            _UDWORD VLU1:1;                 /*   VLU1       */
            _UDWORD VLU0:1;                 /*   VLU0       */
        } BIT;
    } STCNTVR;
    union {                                 /* STSTR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :19;                    /*              */
            _UDWORD LKZF:1;                 /*   LKZF       */
            _UDWORD LKF:1;                  /*   LKF        */
            _UDWORD DISF:1;                 /*   DISF       */
            _UDWORD UNZF:1;                 /*   UNZF       */
            _UDWORD PCRF:1;                 /*   PCRF       */
            _UDWORD TENDF:1;                /*   TENDF      */
            _UDWORD RENDF:1;                /*   RENDF      */
            _UDWORD RCVF3:1;                /*   RCVF3      */
            _UDWORD RCVF2:1;                /*   RCVF2      */
            _UDWORD RCVF1:1;                /*   RCVF1      */
            _UDWORD UPF:1;                  /*   UPF        */
            _UDWORD OPF:1;                  /*   OPF        */
            _UDWORD OWF:1;                  /*   OWF        */
        } BIT;
    } STSTR;
    union {                                 /* STIER        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :19;                    /*              */
            _UDWORD LKZE:1;                 /*   LKZE       */
            _UDWORD LKE:1;                  /*   LKE        */
            _UDWORD DISE:1;                 /*   DISE       */
            _UDWORD UNZE:1;                 /*   UNZE       */
            _UDWORD PCRE:1;                 /*   PCRE       */
            _UDWORD TENDE:1;                /*   TENDE      */
            _UDWORD RENDE:1;                /*   RENDE      */
            _UDWORD RCVE3:1;                /*   RCVE3      */
            _UDWORD RCVE2:1;                /*   RCVE2      */
            _UDWORD RCVE1:1;                /*   RCVE1      */
            _UDWORD UPE:1;                  /*   UPE        */
            _UDWORD OPE:1;                  /*   OPE        */
            _UDWORD OWE:1;                  /*   OWE        */
        } BIT;
    } STIER;
    _UDWORD STSIZER;                        /*   STSIZER    */
    _UBYTE wk0[4];
    union {                                 /* STPWMMR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :3;                     /*              */
            _UDWORD PID12:1;                /*   PID12      */
            _UDWORD PID11:1;                /*   PID11      */
            _UDWORD PID10:1;                /*   PID10      */
            _UDWORD PID9:1;                 /*   PID9       */
            _UDWORD PID8:1;                 /*   PID8       */
            _UDWORD PID7:1;                 /*   PID7       */
            _UDWORD PID6:1;                 /*   PID6       */
            _UDWORD PID5:1;                 /*   PID5       */
            _UDWORD PID4:1;                 /*   PID4       */
            _UDWORD PID3:1;                 /*   PID3       */
            _UDWORD PID2:1;                 /*   PID2       */
            _UDWORD PID1:1;                 /*   PID1       */
            _UDWORD PID0:1;                 /*   PID0       */
            _UDWORD PIDEN:1;                /*   PIDEN      */
            _UDWORD PWMUEN:1;               /*   PWMUEN     */
            _UDWORD PWMSEL:1;               /*   PWMSEL     */
            _UDWORD PWMSEL2:1;              /*   PWMSEL2    */
            _UDWORD PWMCYC:4;               /*   PWMCYC     */
            _UDWORD PWMSFT:4;               /*   PWMSFT     */
            _UDWORD PWMDIV:4;               /*   PWMDIV     */
        } BIT;
    } STPWMMR;
    union {                                 /* STPWMCR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :23;                    /*              */
            _UDWORD STCXP:1;                /*   STCXP      */
            _UDWORD PWMBRS:1;               /*   PWMBRS     */
            _UDWORD PWMBWP:1;               /*   PWMBWP     */
            _UDWORD PWMRS:1;                /*   PWMRS      */
            _UDWORD PWMWP:1;                /*   PWMWP      */
            _UDWORD STCRS:1;                /*   STCRS      */
            _UDWORD STCWP:1;                /*   STCWP      */
            _UDWORD PCRRS:1;                /*   PCRRS      */
            _UDWORD PCRWP:1;                /*   PCRWP      */
        } BIT;
    } STPWMCR;
    union {                                 /* STPWMR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD PWMB15:1;               /*   PWMB15     */
            _UDWORD PWMB14:1;               /*   PWMB14     */
            _UDWORD PWMB13:1;               /*   PWMB13     */
            _UDWORD PWMB12:1;               /*   PWMB12     */
            _UDWORD PWMB11:1;               /*   PWMB11     */
            _UDWORD PWMB10:1;               /*   PWMB10     */
            _UDWORD PWMB9:1;                /*   PWMB9      */
            _UDWORD PWMB8:1;                /*   PWMB8      */
            _UDWORD PWMB7:1;                /*   PWMB7      */
            _UDWORD PWMB6:1;                /*   PWMB6      */
            _UDWORD PWMB5:1;                /*   PWMB5      */
            _UDWORD PWMB4:1;                /*   PWMB4      */
            _UDWORD PWMB3:1;                /*   PWMB3      */
            _UDWORD PWMB2:1;                /*   PWMB2      */
            _UDWORD PWMB1:1;                /*   PWMB1      */
            _UDWORD PWMB0:1;                /*   PWMB0      */
            _UDWORD PWM15:1;                /*   PWM15      */
            _UDWORD PWM14:1;                /*   PWM14      */
            _UDWORD PWM13:1;                /*   PWM13      */
            _UDWORD PWM12:1;                /*   PWM12      */
            _UDWORD PWM11:1;                /*   PWM11      */
            _UDWORD PWM10:1;                /*   PWM10      */
            _UDWORD PWM9:1;                 /*   PWM9       */
            _UDWORD PWM8:1;                 /*   PWM8       */
            _UDWORD PWM7:1;                 /*   PWM7       */
            _UDWORD PWM6:1;                 /*   PWM6       */
            _UDWORD PWM5:1;                 /*   PWM5       */
            _UDWORD PWM4:1;                 /*   PWM4       */
            _UDWORD PWM3:1;                 /*   PWM3       */
            _UDWORD PWM2:1;                 /*   PWM2       */
            _UDWORD PWM1:1;                 /*   PWM1       */
            _UDWORD PWM0:1;                 /*   PWM0       */
        } BIT;
    } STPWMR;
    union {                                 /* STPCR0R      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :22;                    /*              */
            _UDWORD PCRB32:1;               /*   PCRB32     */
            _UDWORD PCRB31:1;               /*   PCRB31     */
            _UDWORD PCRB30:1;               /*   PCRB30     */
            _UDWORD PCRB28:1;               /*   PCRB28     */
            _UDWORD PCRB27:1;               /*   PCRB27     */
            _UDWORD PCRB26:1;               /*   PCRB26     */
            _UDWORD PCRB25:1;               /*   PCRB25     */
            _UDWORD PCRB24:1;               /*   PCRB24     */
            _UDWORD PCRB23:1;               /*   PCRB23     */
        } BIT;
    } STPCR0R;
    union {                                 /* STPCR1R      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD PCRB22:1;               /*   PCRB22     */
            _UDWORD PCRB21:1;               /*   PCRB21     */
            _UDWORD PCRB20:1;               /*   PCRB20     */
            _UDWORD PCRB19:1;               /*   PCRB19     */
            _UDWORD PCRB18:1;               /*   PCRB18     */
            _UDWORD PCRB17:1;               /*   PCRB17     */
            _UDWORD PCRB16:1;               /*   PCRB16     */
            _UDWORD PCRB15:1;               /*   PCRB15     */
            _UDWORD PCRB14:1;               /*   PCRB14     */
            _UDWORD PCRB13:1;               /*   PCRB13     */
            _UDWORD PCRB12:1;               /*   PCRB12     */
            _UDWORD PCRB11:1;               /*   PCRB11     */
            _UDWORD PCRB10:1;               /*   PCRB10     */
            _UDWORD PCRB9:1;                /*   PCRB9      */
            _UDWORD PCRB8:1;                /*   PCRB8      */
            _UDWORD PCRB7:1;                /*   PCRB7      */
            _UDWORD PCRB6:1;                /*   PCRB6      */
            _UDWORD PCRB5:1;                /*   PCRB5      */
            _UDWORD PCRB4:1;                /*   PCRB4      */
            _UDWORD PCRB3:1;                /*   PCRB3      */
            _UDWORD PCRB2:1;                /*   PCRB2      */
            _UDWORD PCRB1:1;                /*   PCRB1      */
            _UDWORD PCRB0:1;                /*   PCRB0      */
            _UDWORD PCRX8:1;                /*   PCRX8      */
            _UDWORD PCRX7:1;                /*   PCRX7      */
            _UDWORD PCRX6:1;                /*   PCRX6      */
            _UDWORD PCRX5:1;                /*   PCRX5      */
            _UDWORD PCRX4:1;                /*   PCRX4      */
            _UDWORD PCRX3:1;                /*   PCRX3      */
            _UDWORD PCRX2:1;                /*   PCRX2      */
            _UDWORD PCRX1:1;                /*   PCRX1      */
            _UDWORD PCRX0:1;                /*   PCRX0      */
        } BIT;
    } STPCR1R;
    union {                                 /* STSTC0R      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :22;                    /*              */
            _UDWORD STCB32:1;               /*   STCB32     */
            _UDWORD STCB31:1;               /*   STCB31     */
            _UDWORD STCB30:1;               /*   STCB30     */
            _UDWORD STCB28:1;               /*   STCB28     */
            _UDWORD STCB27:1;               /*   STCB27     */
            _UDWORD STCB26:1;               /*   STCB26     */
            _UDWORD STCB25:1;               /*   STCB25     */
            _UDWORD STCB24:1;               /*   STCB24     */
            _UDWORD STCB23:1;               /*   STCB23     */
        } BIT;
    } STSTC0R;
    union {                                 /* STSTC1R      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD STCB22:1;               /*   STCB22     */
            _UDWORD STCB21:1;               /*   STCB21     */
            _UDWORD STCB20:1;               /*   STCB20     */
            _UDWORD STCB19:1;               /*   STCB19     */
            _UDWORD STCB18:1;               /*   STCB18     */
            _UDWORD STCB17:1;               /*   STCB17     */
            _UDWORD STCB16:1;               /*   STCB16     */
            _UDWORD STCB15:1;               /*   STCB15     */
            _UDWORD STCB14:1;               /*   STCB14     */
            _UDWORD STCB13:1;               /*   STCB13     */
            _UDWORD STCB12:1;               /*   STCB12     */
            _UDWORD STCB11:1;               /*   STCB11     */
            _UDWORD STCB10:1;               /*   STCB10     */
            _UDWORD STCB9:1;                /*   STCB9      */
            _UDWORD STCB8:1;                /*   STCB8      */
            _UDWORD STCB7:1;                /*   STCB7      */
            _UDWORD STCB6:1;                /*   STCB6      */
            _UDWORD STCB5:1;                /*   STCB5      */
            _UDWORD STCB4:1;                /*   STCB4      */
            _UDWORD STCB3:1;                /*   STCB3      */
            _UDWORD STCB2:1;                /*   STCB2      */
            _UDWORD STCB1:1;                /*   STCB1      */
            _UDWORD STCB0:1;                /*   STCB0      */
            _UDWORD STCX8:1;                /*   STCX8      */
            _UDWORD STCX7:1;                /*   STCX7      */
            _UDWORD STCX6:1;                /*   STCX6      */
            _UDWORD STCX5:1;                /*   STCX5      */
            _UDWORD STCX4:1;                /*   STCX4      */
            _UDWORD STCX3:1;                /*   STCX3      */
            _UDWORD STCX2:1;                /*   STCX2      */
            _UDWORD STCX1:1;                /*   STCX1      */
            _UDWORD STCX0:1;                /*   STCX0      */
        } BIT;
    } STSTC1R;
    union {                                 /* STLKCR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :6;                     /*              */
            _UDWORD LKWP:1;                 /*   LKWP       */
            _UDWORD ULWP:1;                 /*   ULWP       */
            _UDWORD ULCNT3:1;               /*   ULCNT3     */
            _UDWORD ULCNT2:1;               /*   ULCNT2     */
            _UDWORD ULCNT1:1;               /*   ULCNT1     */
            _UDWORD ULCNT0:1;               /*   ULCNT0     */
            _UDWORD LKCNT3:1;               /*   LKCNT3     */
            _UDWORD LKCNT2:1;               /*   LKCNT2     */
            _UDWORD LKCNT1:1;               /*   LKCNT1     */
            _UDWORD LKCNT0:1;               /*   LKCNT0     */
            _UDWORD GAIN3:1;                /*   GAIN3      */
            _UDWORD GAIN2:1;                /*   GAIN2      */
            _UDWORD GAIN1:1;                /*   GAIN1      */
            _UDWORD GAIN0:1;                /*   GAIN0      */
            _UDWORD LKCYC3:1;               /*   LKCYC3     */
            _UDWORD LKCYC2:1;               /*   LKCYC2     */
            _UDWORD LKCYC1:1;               /*   LKCYC1     */
            _UDWORD LKCYC0:1;               /*   LKCYC0     */
            _UDWORD ULREF3:1;               /*   ULREF3     */
            _UDWORD ULREF2:1;               /*   ULREF2     */
            _UDWORD ULREF1:1;               /*   ULREF1     */
            _UDWORD ULREF0:1;               /*   ULREF0     */
            _UDWORD LKREF3:1;               /*   LKREF3     */
            _UDWORD LKREF2:1;               /*   LKREF2     */
            _UDWORD LKREF1:1;               /*   LKREF1     */
            _UDWORD LKREF0:1;               /*   LKREF0     */
        } BIT;
    } STLKCR;
};

struct st_ssi    {                          /* struct SSI   */
    union {                                 /* SCSR         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :13;                     /*              */
            _UWORD SSI0CKS2:1;              /*   SSI0CKS2   */
            _UWORD SSI0CKS1:1;              /*   SSI0CKS1   */
            _UWORD SSI0CKS0:1;              /*   SSI0CKS0   */
          } BIT;
    } SCSR;
    _UBYTE wk0[49150];
    union {                                 /* SSICR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :3;                     /*              */
            _UDWORD DMEN:1;                 /*   DMEN       */
            _UDWORD UIEN:1;                 /*   UIEN       */
            _UDWORD OIEN:1;                 /*   OIEN       */
            _UDWORD IIEN:1;                 /*   IIEN       */
            _UDWORD DIEN:1;                 /*   DIEN       */
            _UDWORD CHNL1:1;                /*   CHNL1      */
            _UDWORD CHNL0:1;                /*   CHNL0      */
            _UDWORD DWL2:1;                 /*   DWL2       */
            _UDWORD DWL1:1;                 /*   DWL1       */
            _UDWORD DWL0:1;                 /*   DWL0       */
            _UDWORD SWL2:1;                 /*   SWL2       */
            _UDWORD SWL1:1;                 /*   SWL1       */
            _UDWORD SWL0:1;                 /*   SWL0       */
            _UDWORD SCKD:1;                 /*   SCKD       */
            _UDWORD SWSD:1;                 /*   SWSD       */
            _UDWORD SCKP:1;                 /*   SCKP       */
            _UDWORD SWSP:1;                 /*   SWSP       */
            _UDWORD SPDP:1;                 /*   SPDP       */
            _UDWORD SDTA:1;                 /*   SDTA       */
            _UDWORD PDTA:1;                 /*   PDTA       */
            _UDWORD DEL:1;                  /*   DEL        */
            _UDWORD :1;                     /*              */
            _UDWORD CKDV2:1;                /*   CKDV2      */
            _UDWORD CKDV1:1;                /*   CKDV1      */
            _UDWORD CKDV0:1;                /*   CKDV0      */
            _UDWORD MUEN:1;                 /*   MUEN       */
            _UDWORD :1;                     /*              */
            _UDWORD TRMD:1;                 /*   TRMD       */
            _UDWORD EN:1;                   /*   EN         */
        } BIT;
    } SSICR;
    union {                                 /* SSISR        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :3;                     /*              */
            _UDWORD DMRQ:1;                 /*   DMRQ       */
            _UDWORD UIRQ:1;                 /*   UIRQ       */
            _UDWORD OIRQ:1;                 /*   OIRQ       */
            _UDWORD IIRQ:1;                 /*   IIRQ       */
            _UDWORD DIRQ:1;                 /*   DIRQ       */
            _UDWORD :20;                    /*              */
            _UDWORD CHNO1:1;                /*   CHNO1      */
            _UDWORD CHNO0:1;                /*   CHNO0      */
            _UDWORD SWNO:1;                 /*   SWNO       */
            _UDWORD IDST:1;                 /*   IDST       */
        } BIT;
    } SSISR;
    _UDWORD SSITDR;                         /*   SSITDR     */
    _UDWORD SSIRDR;                         /*   SSIRDR     */
};

struct st_usb    {                          /* struct USB   */
    union {                                 /* D0FWAIT      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :12;                     /*              */
            _UWORD FWAIT:4;                 /*   FWAIT      */
        } BIT;
    } D0FWAIT;
    union {                                 /* D1FWAIT      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :12;                     /*              */
            _UWORD FWAIT:4;                 /*   FWAIT      */
        } BIT;
    } D1FWAIT;
    _UBYTE wk0[4];
    union {                                 /* D0FIFO       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD FIFOPORT:32;            /*   FIFOPORT   */
        } BIT;
    } D0FIFO;
    union {                                 /* D1FIFO       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD FIFOPORT:32;            /*   FIFOPORT   */
        } BIT;
   } D1FIFO;
    _UBYTE wk1[252900];
    union {                                 /* SYSCFG       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :5;                      /*              */
            _UWORD SCKE:1;                  /*   SCKE       */
            _UWORD :2;                      /*              */
            _UWORD HSE:1;                   /*   HSE        */
            _UWORD DCFM:1;                  /*   DCFM       */
            _UWORD DRPD:1;                  /*   DRPD       */
            _UWORD DPRPU:1;                 /*   DPRPU      */
            _UWORD :3;                      /*              */
            _UWORD USBE:1;                  /*   USBE       */
        } BIT;
    } SYSCFG;
    union {                                 /* BUSWAIT      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :12;                     /*              */
            _UWORD BWAIT:4;                 /*   BWAIT      */
        } BIT;
    } BUSWAIT;
    union {                                 /* SYSSTS       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :14;                     /*              */
            _UWORD LNST:2;                  /*   LNST       */
        } BIT;
    } SYSSTS;
    _UBYTE wk2[2];
    union {                                 /* DVSTCTR      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :7;                      /*              */
            _UWORD WKUP:1;                  /*   WKUP       */
            _UWORD RWUPE:1;                 /*   RWUPE      */
            _UWORD USBRST:1;                /*   USBRST     */
            _UWORD RESUME:1;                /*   RESUME     */
            _UWORD UACT:1;                  /*   UACT       */
            _UWORD :1;                      /*              */
            _UWORD RHST:3;                  /*   RHST       */           
        } BIT;
    } DVSTCTR;
    _UBYTE wk3[2];
    union {                                 /* TESTMODE     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :12;                     /*              */
            _UWORD UTST:4;                  /*   UTST       */                    
        } BIT;
    } TESTMODE;
    _UBYTE wk4[2];
    union {                                 /* D0FBCFG      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :2;                      /*              */
            _UWORD DFACC:2;                 /*   DFACC      */
            _UWORD :12;                     /*              */
        } BIT;
    } D0FBCFG;
    union {                                 /* D1FBCFG      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :2;                      /*              */
            _UWORD DFACC:2;                 /*   DFACC      */
            _UWORD :12;                     /*              */
        } BIT;
    } D1FBCFG;
    union {                                 /* CFIFO        */
		_UDWORD LONG;                       /*  Long Access */
		struct {                            /*  Word Access */
			_UWORD H;						/*   High       */
			_UWORD L;						/*   Low        */
		} WORD;								/*              */
		struct {                            /*  Byte Access */
			_UBYTE HH;						/*   High, High */
			_UBYTE HL;						/*   High, Low  */
			_UBYTE LH;						/*   Low, High  */
			_UBYTE LL;						/*   Low, Low   */
		} BYTE;								/*              */
        struct {                            /*  Bit Access  */
            _UDWORD FIFOPORT:32;            /*              */
        } BIT;
    } CFIFO;
    _UBYTE wk5[8];
    union {                                 /* CFIFOSEL     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD RCNT:1;                  /*   RCNT       */
            _UWORD REW:1;                   /*   REW        */
            _UWORD :2;                      /*              */
            _UWORD MBW1:1;                  /*   MBW1       */
            _UWORD MBW0:1;                  /*   MBW0       */
            _UWORD :1;                      /*              */
            _UWORD BIGEND:1;                /*   BIGEND     */
            _UWORD :2;                      /*              */
            _UWORD ISEL:1;                  /*   ISEL       */
            _UWORD :1;                      /*              */
            _UWORD CURPIPE:4;               /*   CURPIPE    */
        } BIT;
    } CFIFOSEL;
    union {                                 /* CFIFOCTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BVAL:1;                  /*   BVAL       */
            _UWORD BCLR:1;                  /*   BCLR       */
            _UWORD FRDY:1;                  /*   FRDY       */
            _UWORD :1;                      /*              */
            _UWORD DTLN:12;                 /*   DTLN       */
            } BIT;
    } CFIFOCTR;
    _UBYTE wk6[4];
    union {                                 /* D0FIFOSEL    */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD RCNT:1;                  /*   RCNT       */
            _UWORD REW:1;                   /*   REW        */
            _UWORD DCLRM:1;                 /*   DCLRM      */
            _UWORD DREQE:1;                 /*   DREQE      */
            _UWORD MBW1:1;                  /*   MBW1       */
            _UWORD MBW0:1;                  /*   MBW0       */
            _UWORD :1;                      /*              */
            _UWORD BIGEND:1;                /*   BIGEND     */
            _UWORD :4;                      /*              */
            _UWORD CURPIPE:4;               /*   CURPIPE    */
        } BIT;
    } D0FIFOSEL;
    union {                                 /* D0FIFOCTR    */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BVAL:1;                  /*   BVAL       */
            _UWORD BCLR:1;                  /*   BCLR       */
            _UWORD FRDY:1;                  /*   FRDY       */
            _UWORD :1;                      /*              */
            _UWORD DTLN:12;                 /*   DTLN       */
        } BIT;
    } D0FIFOCTR;
    union {                                 /* D1FIFOSEL    */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD RCNT:1;                  /*   RCNT       */
            _UWORD REW:1;                   /*   REW        */
            _UWORD DCLRM:1;                 /*   DCLRM      */
            _UWORD DREQE:1;                 /*   DREQE      */
            _UWORD MBW1:1;                  /*   MBW1       */
            _UWORD MBW0:1;                  /*   MBW0       */
            _UWORD :1;                      /*              */
            _UWORD BIGEND:1;                /*   BIGEND     */
            _UWORD :4;                      /*              */
            _UWORD CURPIPE:4;               /*   CURPIPE    */
        } BIT;
    } D1FIFOSEL;
    union {                                 /* D1FIFOCTR    */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BVAL:1;                  /*   BVAL       */
            _UWORD BCLR:1;                  /*   BCLR       */
            _UWORD FRDY:1;                  /*   FRDY       */
            _UWORD :1;                      /*              */
            _UWORD DTLN:12;                 /*   DTLN       */
        } BIT;
    } D1FIFOCTR;
    union {                                 /* INTENB0      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD VBSE:1;                  /*   VBSE       */
            _UWORD RSME:1;                  /*   RSME       */
            _UWORD SOFE:1;                  /*   SOFE       */
            _UWORD DVSE:1;                  /*   DVSE       */
            _UWORD CTRE:1;                  /*   CTRE       */
            _UWORD BEMPE:1;                 /*   BEMPE      */
            _UWORD NRDYE:1;                 /*   NRDYE      */
            _UWORD BRDYE:1;                 /*   BRDYE      */
            _UWORD :8;                      /*              */
        } BIT;
    } INTENB0;
    union {                                 /* INTENB1      */
        _UWORD WORD;                        /*  Word Access */
        struct {        					 /*  Bit Access  */
			_UWORD :1;                   
            _UWORD BCHGE:1;                 /*   BCHGE      */
            _UWORD :1;                      /*              */
            _UWORD DTCHE:1;                 /*   DTCHE      */
            _UWORD ATTCHE:1;                /*   ATTCHE     */
            _UWORD :4;                      /*              */
			_UWORD EOFERRE:1;               /*   EOFERRE    */
            _UWORD SIGNE:1;                 /*   SIGNE      */
            _UWORD SACKE:1;                 /*   SACKE      */
            _UWORD :4;                      /*              */
        } BIT;
    } INTENB1;
    _UBYTE wk7[2];
    union {                                 /* BRDYENB      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PIPE9BRDYE:1;            /*   PIPE9BRDYE */
            _UWORD PIPE8BRDYE:1;            /*   PIPE8BRDYE */
            _UWORD PIPE7BRDYE:1;            /*   PIPE7BRDYE */
            _UWORD PIPE6BRDYE:1;            /*   PIPE6BRDYE */
            _UWORD PIPE5BRDYE:1;            /*   PIPE5BRDYE */
            _UWORD PIPE4BRDYE:1;            /*   PIPE4BRDYE */
            _UWORD PIPE3BRDYE:1;            /*   PIPE3BRDYE */
            _UWORD PIPE2BRDYE:1;            /*   PIPE2BRDYE */
            _UWORD PIPE1BRDYE:1;            /*   PIPE1BRDYE */
            _UWORD PIPE0BRDYE:1;            /*   PIPE0BRDYE */
        } BIT;
    } BRDYENB;
    union {                                 /* NRDYENB      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PIPE9NRDYE:1;            /*   PIPE9NRDYE */
            _UWORD PIPE8NRDYE:1;            /*   PIPE8NRDYE */
            _UWORD PIPE7NRDYE:1;            /*   PIPE7NRDYE */
            _UWORD PIPE6NRDYE:1;            /*   PIPE6NRDYE */
            _UWORD PIPE5NRDYE:1;            /*   PIPE5NRDYE */
            _UWORD PIPE4NRDYE:1;            /*   PIPE4NRDYE */
            _UWORD PIPE3NRDYE:1;            /*   PIPE3NRDYE */
            _UWORD PIPE2NRDYE:1;            /*   PIPE2NRDYE */
            _UWORD PIPE1NRDYE:1;            /*   PIPE1NRDYE */
            _UWORD PIPE0NRDYE:1;            /*   PIPE0NRDYE */
        } BIT;
    } NRDYENB;
    union {                                 /* BEMPENB      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PIPE9BEMPE:1;            /*   PIPE9BEMPE */
            _UWORD PIPE8BEMPE:1;            /*   PIPE8BEMPE */
            _UWORD PIPE7BEMPE:1;            /*   PIPE7BEMPE */
            _UWORD PIPE6BEMPE:1;            /*   PIPE6BEMPE */
            _UWORD PIPE5BEMPE:1;            /*   PIPE5BEMPE */
            _UWORD PIPE4BEMPE:1;            /*   PIPE4BEMPE */
            _UWORD PIPE3BEMPE:1;            /*   PIPE3BEMPE */
            _UWORD PIPE2BEMPE:1;            /*   PIPE2BEMPE */
            _UWORD PIPE1BEMPE:1;            /*   PIPE1BEMPE */
            _UWORD PIPE0BEMPE:1;            /*   PIPE0BEMPE */
        } BIT;
    } BEMPENB;
    union {                                 /* SOFCFG       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :7;                      /*              */
            _UWORD TRNENSEL:1;              /*   TRNENSEL   */
            _UWORD :1;                      /*              */
            _UWORD BRDYM:1;                 /*   BRDYM      */
            _UWORD :6;                      /*              */
        } BIT;
    } SOFCFG;
    _UBYTE wk8[2];
    union {                                 /* INTSTS0      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD VBINT:1;                 /*   VBINT      */
            _UWORD RESM:1;                  /*   RESM       */
            _UWORD SOFR:1;                  /*   SOFR       */
            _UWORD DVST:1;                  /*   DVST       */
            _UWORD CTRT:1;                  /*   CTRT       */
            _UWORD BEMP:1;                  /*   BEMP       */
            _UWORD NRDY:1;                  /*   NRDY       */
            _UWORD BRDY:1;                  /*   BRDY       */
            _UWORD VBSTS:1;                 /*   VBSTS      */
            _UWORD DVSQ:3;                  /*   DVSQ       */
            _UWORD VALID:1;                 /*   VALID      */
            _UWORD CTSQ:3;                  /*   CTSQ       */
        } BIT;
    } INTSTS0;
    union {                                 /* INTSTS1      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD BCHG:1;                  /*   BCHG       */
            _UWORD :1;                      /*              */
            _UWORD DTCH:1;                  /*   DTCH       */
            _UWORD ATTCH:1;                 /*   ATTCH      */
            _UWORD :4;                      /*              */
            _UWORD EOFERR:1;                /*   EOFERR     */
            _UWORD SIGN:1;                  /*   SIGN       */
            _UWORD SACK:1;                  /*   SACK       */
            _UWORD :4;                      /*              */
        } BIT;
    } INTSTS1;
    _UBYTE wk9[2];
    union {                                 /* BRDYSTS      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PIPE9BRDY:1;             /*   PIPE9BRDY  */
            _UWORD PIPE8BRDY:1;             /*   PIPE8BRDY  */
            _UWORD PIPE7BRDY:1;             /*   PIPE7BRDY  */
            _UWORD PIPE6BRDY:1;             /*   PIPE6BRDY  */
            _UWORD PIPE5BRDY:1;             /*   PIPE5BRDY  */
            _UWORD PIPE4BRDY:1;             /*   PIPE4BRDY  */
            _UWORD PIPE3BRDY:1;             /*   PIPE3BRDY  */
            _UWORD PIPE2BRDY:1;             /*   PIPE2BRDY  */
            _UWORD PIPE1BRDY:1;             /*   PIPE1BRDY  */
            _UWORD PIPE0BRDY:1;             /*   PIPE0BRDY  */
        } BIT;
    } BRDYSTS;
    union {                                 /* NRDYSTS      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PIPE9NRDY:1;             /*   PIPE9NRDY  */
            _UWORD PIPE8NRDY:1;             /*   PIPE8NRDY  */
            _UWORD PIPE7NRDY:1;             /*   PIPE7NRDY  */
            _UWORD PIPE6NRDY:1;             /*   PIPE6NRDY  */
            _UWORD PIPE5NRDY:1;             /*   PIPE5NRDY  */
            _UWORD PIPE4NRDY:1;             /*   PIPE4NRDY  */
            _UWORD PIPE3NRDY:1;             /*   PIPE3NRDY  */
            _UWORD PIPE2NRDY:1;             /*   PIPE2NRDY  */
            _UWORD PIPE1NRDY:1;             /*   PIPE1NRDY  */
            _UWORD PIPE0NRDY:1;             /*   PIPE0NRDY  */
        } BIT;
    } NRDYSTS;
    union {                                 /* BEMPSTS      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PIPE9BEMP:1;             /*   PIPE9BEMP  */
            _UWORD PIPE8BEMP:1;             /*   PIPE8BEMP  */
            _UWORD PIPE7BEMP:1;             /*   PIPE7BEMP  */
            _UWORD PIPE6BEMP:1;             /*   PIPE6BEMP  */
            _UWORD PIPE5BEMP:1;             /*   PIPE5BEMP  */
            _UWORD PIPE4BEMP:1;             /*   PIPE4BEMP  */
            _UWORD PIPE3BEMP:1;             /*   PIPE3BEMP  */
            _UWORD PIPE2BEMP:1;             /*   PIPE2BEMP  */
            _UWORD PIPE1BEMP:1;             /*   PIPE1BEMP  */
            _UWORD PIPE0BEMP:1;             /*   PIPE0BEMP  */
        } BIT;
    } BEMPSTS;
    union {                                 /* FRMNUM       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD OVRN:1;                  /*   OVRN       */
            _UWORD CRCE:1;                  /*   CRCE       */
            _UWORD :3;                      /*              */
            _UWORD FRNM:11;                 /*   FRNM       */
        } BIT;
    } FRMNUM;
    union {                                 /* UFRMNUM      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :13;                     /*              */
            _UWORD UFRNM:3;                 /*   UFRNM      */
        } BIT;
    } UFRMNUM;
    union {                                 /* USBADDR      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :9;                      /*              */
            _UWORD USBADDR:7;               /*   USBADDR    */
        } BIT;
    } USBADDR;
    _UBYTE wk10[2];
    union {                                 /* USBREQ       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BREQUEST:8;              /*   BREQUEST   */
            _UWORD BMREQUESTTYPE:8;         /*   BMREQUESTTYPE*/
        } BIT;
    } USBREQ;
    union {                                 /* USBVAL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD WVALUE:16;               /*   WVALUE     */
        } BIT;
    } USBVAL;
    union {                                 /* USBINDX      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD WINDEX:16;               /*   WINDEX     */
        } BIT;
    } USBINDX;
    union {                                 /* USBLENG      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD WLENGTH:16;              /*   WLENGTH    */
        } BIT;
    } USBLENG;
    union {                                 /* DCPCFG       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :11;                     /*              */
            _UWORD DIR:1;                   /*   DIR        */
            _UWORD :4;                      /*              */
        } BIT;
    } DCPCFG;
    union {                                 /* DCPMAXP      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD DEVSEL:4;                /*   DEVSEL     */
            _UWORD :5;                      /*              */
            _UWORD MXPS:7;                  /*   MXPS       */
        } BIT;
    } DCPMAXP;
    union {                                 /* DCPCTR       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD SUREQ:1;                 /*   SUREQ      */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD SUREQCLR:1;              /*   SUREQCLR   */
            _UWORD :2;                      /*              */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD PINGE:1;                 /*   PINGE      */
            _UWORD :1;                      /*              */
            _UWORD CCPL:1;                  /*   CCPL       */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } DCPCTR;
    _UBYTE wk11[2];
    union {                                 /* PIPESEL      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :12;                     /*              */
            _UWORD PIPESEL:4;               /*   PIPESEL    */
        } BIT;
    } PIPESEL;
    _UBYTE wk12[2];
    union {                                 /* PIPECFG      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD TYPE:2;                  /*   TYPE       */
            _UWORD :3;                      /*              */
            _UWORD BFRE:1;                  /*   BFRE       */
            _UWORD DBLB:1;                  /*   DBLB       */
            _UWORD CNTMD:1;                 /*   CNTMD      */
            _UWORD SHTNAK:1;                /*   SHTNAK     */
            _UWORD :2;                      /*              */
            _UWORD DIR:1;                   /*   DIR        */
            _UWORD EPNUM:4;                 /*   EPNUM      */
        } BIT;
    } PIPECFG;
    union {                                 /* PIPEBUF      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD BUFSIZE:5;               /*   BUFSIZE    */
            _UWORD :2;                      /*              */
            _UWORD BUFNMB:8;                /*   BUFNMB     */
        } BIT;
    } PIPEBUF;
    union {                                 /* PIPEMAXP     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD DEVSEL:4;                /*  DEVSEL      */
            _UWORD :1;                      /*              */
            _UWORD MXPS:11;                 /*  MXPS        */
        } BIT;
    } PIPEMAXP;
    union {                                 /* PIPEPERI     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :3;                      /*              */
            _UWORD IFIS:1;                  /*   IFIS       */
            _UWORD :9;                      /*              */
            _UWORD IITV:3;                  /*   IITV       */
        } BIT;
    } PIPEPERI;
    union {                                 /* PIPE1CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD INBUFM:1;                /*   INBUFM     */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :1;                      /*              */
            _UWORD ATREPM:1;                /*   ATREPM     */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE1CTR;
    union {                                 /* PIPE2CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD INBUFM:1;                /*   INBUFM     */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :1;                      /*              */
            _UWORD ATREPM:1;                /*   ATREPM     */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE2CTR;
    union {                                 /* PIPE3CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD INBUFM:1;                /*   INBUFM     */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :1;                      /*              */
            _UWORD ATREPM:1;                /*   ATREPM     */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE3CTR;
    union {                                 /* PIPE4CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD INBUFM:1;                /*   INBUFM     */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :1;                      /*              */
            _UWORD ATREPM:1;                /*   ATREPM     */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE4CTR;
    union {                                 /* PIPE5CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD INBUFM:1;                /*   INBUFM     */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :1;                      /*              */
            _UWORD ATREPM:1;                /*   ATREPM     */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE5CTR;
    union {                                 /* PIPE6CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD :1;                      /*              */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :2;                      /*              */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE6CTR;
    union {                                 /* PIPE7CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD :1;                      /*              */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :2;                      /*              */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE7CTR;
    union {                                 /* PIPE8CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD :1;                      /*              */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :2;                      /*              */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE8CTR;
    union {                                 /* PIPE9CTR     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD BSTS:1;                  /*   BSTS       */
            _UWORD :1;                      /*              */
            _UWORD CSCLR:1;                 /*   CSCLR      */
            _UWORD CSSTS:1;                 /*   CSSTS      */
            _UWORD :2;                      /*              */
            _UWORD ACLRM:1;                 /*   ACLRM      */
            _UWORD SQCLR:1;                 /*   SQCLR      */
            _UWORD SQSET:1;                 /*   SQSET      */
            _UWORD SQMON:1;                 /*   SQMON      */
            _UWORD PBUSY:1;                 /*   PBUSY      */
            _UWORD :3;                      /*              */
            _UWORD PID:2;                   /*   PID        */
        } BIT;
    } PIPE9CTR;
    _UBYTE wk13[14];
    union {                                 /* PIPE1TRE     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD TRENB:1;                 /*   TRENB      */
            _UWORD TRCLR:1;                 /*   TRCLR      */
            _UWORD :8;                      /*              */
        } BIT;
    } PIPE1TRE;
    union {                                 /* PIPE1TRN     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD TRNCNT:16;               /*              */
        } BIT;
    } PIPE1TRN;
    union {                                 /* PIPE2TRE     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD TRENB:1;                 /*   TRENB      */
            _UWORD TRCLR:1;                 /*   TRCLR      */
            _UWORD :8;                      /*              */
        } BIT;
    } PIPE2TRE;
    union {                                 /* PIPE2TRN     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD TRNCNT:16;               /*              */
        } BIT;
    } PIPE2TRN;
    union {                                 /* PIPE2TRE     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD TRENB:1;                 /*   TRENB      */
            _UWORD TRCLR:1;                 /*   TRCLR      */
            _UWORD :8;                      /*              */
        } BIT;
    } PIPE3TRE;
    union {                                 /* PIPE3TRN     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD TRNCNT:16;               /*              */
        } BIT;
    } PIPE3TRN;
    union {                                 /* PIPE4TRE     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD TRENB:1;                 /*   TRENB      */
            _UWORD TRCLR:1;                 /*   TRCLR      */
            _UWORD :8;                      /*              */
        } BIT;
    } PIPE4TRE;
    union {                                 /* PIPE4TRN     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD TRNCNT:16;               /*              */
        } BIT;
    } PIPE4TRN;
    union {                                 /* PIPE5TRE     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD TRENB:1;                 /*   TRENB      */
            _UWORD TRCLR:1;                 /*   TRCLR      */
            _UWORD :8;                      /*              */
        } BIT;
    } PIPE5TRE;
    union {                                 /* PIPE5TRN     */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD TRNCNT:16;               /*              */
        } BIT;
    } PIPE5TRN;
    _UBYTE wk14[44];
    union {                                 /* DEVADD0      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD0;
    union {                                 /* DEVADD1      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD1;
    union {                                 /* DEVADD2      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD2;
    union {                                 /* DEVADD3      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD3;
    union {                                 /* DEVADD4      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD4;
    union {                                 /* DEVADD5      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD5;
    union {                                 /* DEVADD6      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD6;
    union {                                 /* DEVADD7      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD7;
    union {                                 /* DEVADD8      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD8;
    union {                                 /* DEVADD9      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADD9;
    union {                                 /* DEVADDA      */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD UPPHUB:4;                /*   UPPHUB     */
            _UWORD HUBPORT:3;               /*   HUBPORT    */
            _UWORD USBSPD:2;                /*   USBSPD     */
            _UWORD :6;                      /*              */
        } BIT;
    } DEVADDA;
};

struct st_iic3 {                                /* struct IIC3 */
       union {                                  /* ICCR1        */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE ICE:1;               /*   ICE        */
                    _UBYTE RCVD:1;              /*   RCVD       */
                    _UBYTE MST:1;               /*   MST        */
                    _UBYTE TRS:1;               /*   TRS        */
                    _UBYTE CKS:4;               /*   CKS        */
                    } BIT;
             } ICCR1;
       union {                                  /* ICCR2        */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE BBSY:1;              /*   BBSY       */
                    _UBYTE SCP:1;               /*   SCP        */
                    _UBYTE SDAO:1;              /*   SDAO       */
                    _UBYTE SDAOP:1;             /*   SDAOP      */
                    _UBYTE SCLO:1;              /*   SCLO       */
                    _UBYTE :1;                  /*              */
                    _UBYTE IICRST:1;            /*   IICRST     */
                    _UBYTE :1;                  /*              */
                    } BIT;
             } ICCR2;
       union {                                  /* ICMR         */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE MLS:1;               /*   MLS        */
                    _UBYTE :3;                  /*              */
                    _UBYTE BCWP:1;              /*   BCWP       */
                    _UBYTE BC:3;                /*   BC         */
                    } BIT;
             } ICMR;
       union {                                  /* ICIER        */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE TIE:1;               /*   TIE        */
                    _UBYTE TEIE:1;              /*   TEIE       */
                    _UBYTE RIE:1;               /*   RIE        */
                    _UBYTE NAKIE:1;             /*   NAKIE      */
                    _UBYTE STIE:1;              /*   STIE       */
                    _UBYTE ACKE:1;              /*   ACKE       */
                    _UBYTE ACKBR:1;             /*   ACKBR      */
                    _UBYTE ACKBT:1;             /*   ACKBT      */
                    } BIT;
             } ICIER;
       union {                                  /* ICSR         */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE TDRE:1;              /*   TDRE       */
                    _UBYTE TEND:1;              /*   TEND       */
                    _UBYTE RDRF:1;              /*   RDRF       */
                    _UBYTE NACKF:1;             /*   NACKF      */
                    _UBYTE STOP:1;              /*   STOP       */
                    _UBYTE ALOVE:1;             /*   AL/OVE     */
                    _UBYTE AAS:1;               /*   AAS        */
                    _UBYTE ADZ:1;               /*   ADZ        */
                    } BIT;
             } ICSR;
       union {                                  /* SAR          */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE SVA:7;               /*   SVA        */
                    _UBYTE FS:1;                /*   FS         */
                    } BIT;
             } SAR;
       _UBYTE ICDRT;                            /* ICDRT        */
       _UBYTE ICDRR;                            /* ICDRR        */
       union {                                  /* NF2CYC       */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE :6;                  /*              */
                    _UBYTE PRS:1;               /*   PRS        */
                    _UBYTE NF2CYC:1;            /*   NF2CYC     */
                    } BIT;                      /*              */
             } NF2CYC;
};

struct st_hif {                             /* struct HIF   */
    union {                                 /* HIFIDX       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :24;                    /*              */
            _UDWORD REG:6;                  /*   REG        */
            _UDWORD BYTE:2;                 /*   BYTE       */
        } BIT;
    } HIFIDX;

    union {                                 /* HIFGSR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD STATUS:16;              /*   STATUS     */
        } BIT;
    } HIFGSR;

    union {                                 /* HIFSCR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :20;                    /*              */
            _UDWORD DMD:1;                  /*   DMD        */
            _UDWORD DPOL:1;                 /*   DPOL       */
            _UDWORD BMD:1;                  /*   BMD        */
            _UDWORD BSEL:1;                 /*   BSEL       */
            _UDWORD :2;                     /*              */
            _UDWORD MD1:1;                  /*   MD1        */
            _UDWORD :2;                     /*              */
            _UDWORD WBSWP:1;                /*   WBSWP      */
            _UDWORD EDN:1;                  /*   EDN        */
            _UDWORD BO:1;                   /*   BO         */
        } BIT;
    } HIFSCR;

    union {                                 /* HIFMCR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :24;                    /*              */
            _UDWORD LOCK:1;                 /*   LOCK       */
            _UDWORD :1;                     /*              */
            _UDWORD WT:1;                   /*   WT         */
            _UDWORD :1;                     /*              */
            _UDWORD RD:1;                   /*   RD         */
            _UDWORD :2;                     /*              */
            _UDWORD AIAD:1;                 /*   AIAD       */
        } BIT;
    } HIFMCR;

    union {                                 /* HIFIICR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :24;                    /*              */
            _UDWORD IIC:7;                  /*   IIC        */
            _UDWORD IIR:1;                  /*   IIR        */
        } BIT;
    } HIFIICR;

    union {                                 /* HIFEICR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :24;                    /*              */
            _UDWORD EIC:7;                  /*   EIC        */
            _UDWORD EIR:1;                  /*   EIR        */
        } BIT;
    } HIFEICR;

    _UDWORD HIFADR;                         /* HIFADR       */

    _UDWORD HIFDATA;                        /* HIFDATA      */

    union {                                 /* HIFDTR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD DTRG:1;                 /*   DTRG       */
        } BIT;
    } HIFDTR;

    union {                                 /* HIFBICR      */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :30;                    /*              */
            _UDWORD BIE:1;                  /*   BIE        */
            _UDWORD BIF:1;                  /*   BIF        */
        } BIT;
    } HIFBICR;

    _UBYTE wk0[24];

    union {                                 /* HIFBCR       */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :31;                    /*              */
            _UDWORD AC:1;                   /*   AC         */
        } BIT;
    } HIFBCR;
};

struct st_cmt {                                 /* struct CMT   */
       union {                                  /* CMSTR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :14;                 /*              */
                    _UWORD STR1:1;              /*   STR1       */
                    _UWORD STR0:1;              /*   STR0       */
                    } BIT;                      /*              */
             } CMSTR;                           /*              */
       union {                                  /* CMCSR0       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :8;                  /*              */
                    _UWORD CMF:1;               /*   CMF        */
                    _UWORD CMIE:1;              /*   CMIE       */
                    _UWORD :4;                  /*              */
                    _UWORD CKS:2;               /*   CKS        */
                    } BIT;                      /*              */
             } CMCSR0;                          /*              */
       union {                                  /* CMCNT0       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD D:16;                /*   D          */
                    } BIT;                      /*              */
             } CMCNT0;                          /*              */
       union {                                  /* CMCOR0       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD D:16;                /*   D          */
                    } BIT;                      /*              */
             } CMCOR0;                          /*              */
       union {                                  /* CMCSR1       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :8;                  /*              */
                    _UWORD CMF:1;               /*   CMF        */
                    _UWORD CMIE:1;              /*   CMIE       */
                    _UWORD :4;                  /*              */
                    _UWORD CKS:2;               /*   CKS        */
                    } BIT;                      /*              */
             } CMCSR1;                          /*              */
       union {                                  /* CMCNT1       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD D:16;                /*   D          */
                    } BIT;                      /*              */
             } CMCNT1;                          /*              */
       union {                                  /* CMCOR1       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD D:16;                /*   D          */
                    } BIT;                      /*              */
             } CMCOR1;                          /*              */
};                                              /*              */

struct st_scif {                                /* struct SCIF0 */
       union {                                  /* SCSMR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :8;                  /*              */
                    _UWORD CA:1;                /*   CA         */
                    _UWORD CHR:1;               /*   CHR        */
                    _UWORD PE:1;                /*   PE         */
                    _UWORD OE:1;                /*   OE         */
                    _UWORD STOP:1;              /*   STOP       */
                    _UWORD :1;                  /*              */
                    _UWORD CKS:2;               /*   CKS        */
                    } BIT;                      /*              */
             } SCSMR;                           /*              */
       _UBYTE wk0[2];                           /*              */
       union {                                  /* SCBRR        */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE D:8;                 /*   D          */
                    } BIT;                      /*              */
             } SCBRR;                           /*              */
       _UBYTE wk1[3];                           /*              */
       union {                                  /* SCSCR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :8;                  /*              */
                    _UWORD TIE:1;               /*   TIE        */
                    _UWORD RIE:1;               /*   RIE        */
                    _UWORD TE:1;                /*   TE         */
                    _UWORD RE:1;                /*   RE         */
                    _UWORD REIE:1;              /*   REIE       */
                    _UWORD :1;                  /*              */
                    _UWORD CKE:2;               /*   CKE        */
                    } BIT;                      /*              */
             } SCSCR;                           /*              */
       _UBYTE wk2[2];                           /*              */
       union {                                  /* SCFTDR       */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE D:8;                 /*   D          */
                    } BIT;                      /*              */
             } SCFTDR;                          /*              */
       _UBYTE wk3[3];                           /*              */
       union {                                  /* SCFSR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD PERN:4;              /*   PERN       */
                    _UWORD FERN:4;              /*   FERN       */
                    _UWORD ER:1;                /*   ER         */
                    _UWORD TEND:1;              /*   TEND       */
                    _UWORD TDFE:1;              /*   TDFE       */
                    _UWORD BRK:1;               /*   BRK        */
                    _UWORD FER:1;               /*   FER        */
                    _UWORD PER:1;               /*   PER        */
                    _UWORD RDF:1;               /*   RDF        */
                    _UWORD DR:1;                /*   DR         */
                    } BIT;                      /*              */
             } SCFSR;                           /*              */
       _UBYTE wk4[2];                           /*              */
       union {                                  /* SCFRDR       */
             _UBYTE BYTE;                       /*  Byte Access */
             struct {                           /*  Bit Access  */
                    _UBYTE D:8;                 /*   D          */
                    } BIT;                      /*              */
             } SCFRDR;                          /*              */
       _UBYTE wk5[3];                           /*              */
       union {                                  /* SCFCR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :5;                  /*              */
                    _UWORD RSTRG:3;             /*   RSTRG      */
                    _UWORD RTRG:2;              /*   RTRG       */
                    _UWORD TTRG:2;              /*   TTRG       */
                    _UWORD MCE:1;               /*   MCE        */
                    _UWORD TFRST:1;             /*   TFRST      */
                    _UWORD RFRST:1;             /*   RFRST      */
                    _UWORD LOOP:1;              /*   LOOP       */
                    } BIT;                      /*              */
             } SCFCR;                           /*              */
       _UBYTE wk6[2];                           /*              */
       union {                                  /* SCFDR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :3;                  /*              */
                    _UWORD T:5;                 /*   T          */
                    _UWORD :3;                  /*              */
                    _UWORD R:5;                 /*   R          */
                    } BIT;                      /*              */
             } SCFDR;                           /*              */
       _UBYTE wk7[2];                           /*              */
       union {                                  /* SCSPTR       */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :8;                  /*              */
                    _UWORD RTSIO:1;             /*   RTSIO      */
                    _UWORD RTSDT:1;             /*   RTSDT      */
                    _UWORD CTSIO:1;             /*   CTSIO      */
                    _UWORD CTSDT:1;             /*   CTSDT      */
                    _UWORD SCKIO:1;             /*   SCKIO      */
                    _UWORD SCKDT:1;             /*   SCKDT      */
                    _UWORD SPB2IO:1;            /*   SPB2IO     */
                    _UWORD SPB2DT:1;            /*   SPB2DT     */
                    } BIT;                      /*              */
             } SCSPTR;                          /*              */
       _UBYTE wk8[2];                           /*              */
       union {                                  /* SCLSR        */
             _UWORD WORD;                       /*  Word Access */
             struct {                           /*  Bit Access  */
                    _UWORD :15;                 /*              */
                    _UWORD ORER:1;              /*   ORER       */
                    } BIT;                      /*              */
             } SCLSR;                           /*              */
       _UBYTE wk9[2];                           /*              */
};

struct st_port {                            /* struct PORT  */
    /* ---- Port A ---- */
    union {                                 /* PADRH        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PA25DR:1;                /*   PA25DR     */
            _UWORD PA24DR:1;                /*   PA24DR     */
            _UWORD PA23DR:1;                /*   PA23DR     */
            _UWORD PA22DR:1;                /*   PA22DR     */
            _UWORD PA21DR:1;                /*   PA21DR     */
            _UWORD PA20DR:1;                /*   PA20DR     */
            _UWORD PA19DR:1;                /*   PA19DR     */
            _UWORD PA18DR:1;                /*   PA18DR     */
            _UWORD PA17DR:1;                /*   PA17DR     */
            _UWORD :1;                      /*              */
        } BIT;
    } PADRH;

    _UBYTE wk0[2];

    union {                                 /* PAIORH       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :6;                      /*              */
            _UWORD PA25IOR:1;               /*   PA25IOR    */
            _UWORD PA24IOR:1;               /*   PA24IOR    */
            _UWORD PA23IOR:1;               /*   PA23IOR    */
            _UWORD PA22IOR:1;               /*   PA22IOR    */
            _UWORD PA21IOR:1;               /*   PA21IOR    */
            _UWORD PA20IOR:1;               /*   PA20IOR    */
            _UWORD PA19IOR:1;               /*   PA19IOR    */
            _UWORD PA18IOR:1;               /*   PA18IOR    */
            _UWORD PA17IOR:1;               /*   PA17IOR    */
            _UWORD :1;                      /*              */
        } BIT;
    } PAIORH;

    _UBYTE wk1[2];

    union {                                 /* PACRH2       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :13;                     /*              */
            _UWORD PA25MD0:1;               /*   PA25MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA24MD0:1;               /*   PA24MD0    */
        } BIT;
    } PACRH2;

    union {                                 /* PACRH1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PA23MD0:1;               /*   PA23MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA22MD0:1;               /*   PA22MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA21MD0:1;               /*   PA21MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA20MD0:1;               /*   PA20MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA19MD0:1;               /*   PA19MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA18MD0:1;               /*   PA18MD0    */
            _UWORD :1;                      /*              */
            _UWORD PA17MD0:1;               /*   PA17MD0    */
            _UWORD :2;                      /*              */
        } BIT;
    } PACRH1;

    _UBYTE wk2[116];

    /* ---- Port B ---- */

    _UBYTE wk3[2];

    union {                                 /* PBDRL        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD PB7DR:1;                 /*   PB7DR      */
            _UWORD PB6DR:1;                 /*   PB6DR      */
            _UWORD PB5DR:1;                 /*   PB5DR      */
            _UWORD PB4DR:1;                 /*   PB4DR      */
            _UWORD PB3DR:1;                 /*   PB3DR      */
            _UWORD PB2DR:1;                 /*   PB2DR      */
            _UWORD PB1DR:1;                 /*   PB1DR      */
            _UWORD PB0DR:1;                 /*   PB0DR      */
        } BIT;
    } PBDRL;

    _UBYTE wk4[2];

    union {                                 /* PBIORL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD PB7IOR:1;                /*   PB7IOR     */
            _UWORD PB6IOR:1;                /*   PB6IOR     */
            _UWORD PB5IOR:1;                /*   PB5IOR     */
            _UWORD PB4IOR:1;                /*   PB4IOR     */
            _UWORD PB3IOR:1;                /*   PB3IOR     */
            _UWORD PB2IOR:1;                /*   PB2IOR     */
            _UWORD PB1IOR:1;                /*   PB1IOR     */
            _UWORD PB0IOR:1;                /*   PB0IOR     */
        } BIT;
    } PBIORL;

    _UBYTE wk5[6];

    union {                                 /* PBCRL1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PB7MD0:1;                /*   PB7MD0     */
            _UWORD :1;                      /*              */
            _UWORD PB6MD0:1;                /*   PB6MD0     */
            _UWORD PB5MD1:1;                /*   PB5MD1     */
            _UWORD PB5MD0:1;                /*   PB5MD0     */
            _UWORD PB4MD1:1;                /*   PB4MD1     */
            _UWORD PB4MD0:1;                /*   PB4MD0     */
            _UWORD PB3MD1:1;                /*   PB3MD1     */
            _UWORD PB3MD0:1;                /*   PB3MD0     */
            _UWORD PB2MD1:1;                /*   PB2MD1     */
            _UWORD PB2MD0:1;                /*   PB2MD0     */
            _UWORD PB1MD1:1;                /*   PB1MD1     */
            _UWORD PB1MD0:1;                /*   PB1MD0     */
            _UWORD PB0MD1:1;                /*   PB0MD1     */
            _UWORD PB0MD0:1;                /*   PB0MD0     */
        } BIT;
    } PBCRL1;

    _UBYTE wk6[112];

    /* ---- Port C ---- */

    union {                                 /* PCDRH        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :11;                     /*              */
            _UWORD PC20DR:1;                /*   PC20DR     */
            _UWORD PC19DR:1;                /*   PC19DR     */
            _UWORD PC18DR:1;                /*   PC18DR     */
            _UWORD PC17DR:1;                /*   PC17DR     */
            _UWORD PC16DR:1;                /*   PC16DR     */
        } BIT;
    } PCDRH;

    union {                                 /* PCDRL        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PC15DR:1;                /*   PC15DR     */
            _UWORD PC14DR:1;                /*   PC14DR     */
            _UWORD PC13DR:1;                /*   PC13DR     */
            _UWORD PC12DR:1;                /*   PC12DR     */
            _UWORD PC11DR:1;                /*   PC11DR     */
            _UWORD PC10DR:1;                /*   PC10DR     */
            _UWORD PC9DR:1;                 /*   PC9DR      */
            _UWORD PC8DR:1;                 /*   PC8DR      */
            _UWORD PC7DR:1;                 /*   PC7DR      */
            _UWORD PC6DR:1;                 /*   PC6DR      */
            _UWORD PC5DR:1;                 /*   PC5DR      */
            _UWORD PC4DR:1;                 /*   PC4DR      */
            _UWORD PC3DR:1;                 /*   PC3DR      */
            _UWORD PC2DR:1;                 /*   PC2DR      */
            _UWORD PC1DR:1;                 /*   PC1DR      */
            _UWORD PC0DR:1;                 /*   PC0DR      */
        } BIT;
    } PCDRL;

    union {                                 /* PCIORH       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :11;                     /*              */
            _UWORD PC20IOR:1;               /*   PC20IOR    */
            _UWORD PC19IOR:1;               /*   PC19IOR    */
            _UWORD PC18IOR:1;               /*   PC18IOR    */
            _UWORD PC17IOR:1;               /*   PC17IOR    */
            _UWORD PC16IOR:1;               /*   PC16IOR    */
        } BIT;
    } PCIORH;

    union {                                 /* PCIORL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PC15IOR:1;               /*   PC15IOR    */
            _UWORD PC14IOR:1;               /*   PC14IOR    */
            _UWORD PC13IOR:1;               /*   PC13IOR    */
            _UWORD PC12IOR:1;               /*   PC12IOR    */
            _UWORD PC11IOR:1;               /*   PC11IOR    */
            _UWORD PC10IOR:1;               /*   PC10IOR    */
            _UWORD PC9IOR:1;                /*   PC9IOR     */
            _UWORD PC8IOR:1;                /*   PC8IOR     */
            _UWORD PC7IOR:1;                /*   PC7IOR     */
            _UWORD PC6IOR:1;                /*   PC6IOR     */
            _UWORD PC5IOR:1;                /*   PC5IOR     */
            _UWORD PC4IOR:1;                /*   PC4IOR     */
            _UWORD PC3IOR:1;                /*   PC3IOR     */
            _UWORD PC2IOR:1;                /*   PC2IOR     */
            _UWORD PC1IOR:1;                /*   PC1IOR     */
            _UWORD PC0IOR:1;                /*   PC0IOR     */
        } BIT;
    } PCIORL;

    _UBYTE wk7[2];

    union {                                 /* PCCRH1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :7;                      /*              */
            _UWORD PC20MD0:1;               /*   PC20MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC19MD0:1;               /*   PC19MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC18MD0:1;               /*   PC18MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC17MD0:1;               /*   PC17MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC16MD0:1;               /*   PC16MD0    */
        } BIT;
    } PCCRH1;

    union {                                 /* PCCRL2       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PC15MD0:1;               /*   PC15MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC14MD0:1;               /*   PC14MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC13MD0:1;               /*   PC13MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC12MD0:1;               /*   PC12MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC11MD0:1;               /*   PC11MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC10MD0:1;               /*   PC10MD0    */
            _UWORD :1;                      /*              */
            _UWORD PC9MD0:1;                /*   PC9MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC8MD0:1;                /*   PC8MD0     */
        } BIT;
    } PCCRL2;

    union {                                 /* PCCRL1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PC7MD0:1;                /*   PC7MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC6MD0:1;                /*   PC6MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC5MD0:1;                /*   PC5MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC4MD0:1;                /*   PC4MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC3MD0:1;                /*   PC3MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC2MD0:1;                /*   PC2MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC1MD0:1;                /*   PC1MD0     */
            _UWORD :1;                      /*              */
            _UWORD PC0MD0:1;                /*   PC0MD0     */
        } BIT;
    } PCCRL1;

    _UBYTE wk8[112];

    /* ---- Port D ---- */

    _UBYTE wk9[2];

    union {                                 /* PDDRL        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD PD7DR:1;                 /*   PD7DR      */
            _UWORD PD6DR:1;                 /*   PD6DR      */
            _UWORD PD5DR:1;                 /*   PD5DR      */
            _UWORD PD4DR:1;                 /*   PD4DR      */
            _UWORD PD3DR:1;                 /*   PD3DR      */
            _UWORD PD2DR:1;                 /*   PD2DR      */
            _UWORD PD1DR:1;                 /*   PD1DR      */
            _UWORD PD0DR:1;                 /*   PD0DR      */
        } BIT;
    } PDDRL;

    _UBYTE wk10[2];

    union {                                 /* PDIORL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD PD7IOR:1;                /*   PD7IOR     */
            _UWORD PD6IOR:1;                /*   PD6IOR     */
            _UWORD PD5IOR:1;                /*   PD5IOR     */
            _UWORD PD4IOR:1;                /*   PD4IOR     */
            _UWORD PD3IOR:1;                /*   PD3IOR     */
            _UWORD PD2IOR:1;                /*   PD2IOR     */
            _UWORD PD1IOR:1;                /*   PD1IOR     */
            _UWORD PD0IOR:1;                /*   PD0IOR     */
        } BIT;
    } PDIORL;

    _UBYTE wk11[6];

    union {                                 /* PDCRL1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PD7MD1:1;                /*   PD7MD1     */
            _UWORD PD7MD0:1;                /*   PD7MD0     */
            _UWORD PD6MD1:1;                /*   PD6MD1     */
            _UWORD PD6MD0:1;                /*   PD6MD0     */
            _UWORD PD5MD1:1;                /*   PD5MD1     */
            _UWORD PD5MD0:1;                /*   PD5MD0     */
            _UWORD PD4MD1:1;                /*   PD4MD1     */
            _UWORD PD4MD0:1;                /*   PD4MD0     */
            _UWORD PD3MD1:1;                /*   PD3MD1     */
            _UWORD PD3MD0:1;                /*   PD3MD0     */
            _UWORD PD2MD1:1;                /*   PD2MD1     */
            _UWORD PD2MD0:1;                /*   PD2MD0     */
            _UWORD PD1MD1:1;                /*   PD1MD1     */
            _UWORD PD1MD0:1;                /*   PD1MD0     */
            _UWORD PD0MD1:1;                /*   PD0MD1     */
            _UWORD PD0MD0:1;                /*   PD0MD0     */
        } BIT;
    } PDCRL1;

    _UBYTE wk12[112];

    /* ---- Port E ---- */

    _UBYTE wk13[2];

    union {                                 /* PEDRL        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD PE11DR:1;                /*   PE11DR     */
            _UWORD PE10DR:1;                /*   PE10DR     */
            _UWORD PE9DR:1;                 /*   PE9DR      */
            _UWORD PE8DR:1;                 /*   PE8DR      */
            _UWORD PE7DR:1;                 /*   PE7DR      */
            _UWORD PE6DR:1;                 /*   PE6DR      */
            _UWORD PE5DR:1;                 /*   PE5DR      */
            _UWORD PE4DR:1;                 /*   PE4DR      */
            _UWORD PE3DR:1;                 /*   PE3DR      */
            _UWORD PE2DR:1;                 /*   PE2DR      */
            _UWORD PE1DR:1;                 /*   PE1DR      */
            _UWORD PE0DR:1;                 /*   PE0DR      */
        } BIT;
    } PEDRL;

    _UBYTE wk14[2];

    union {                                 /* PEIORL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD PE11IOR:1;               /*   PE11IOR    */
            _UWORD PE10IOR:1;               /*   PE10IOR    */
            _UWORD PE9IOR:1;                /*   PE9IOR     */
            _UWORD PE8IOR:1;                /*   PE8IOR     */
            _UWORD PE7IOR:1;                /*   PE7IOR     */
            _UWORD PE6IOR:1;                /*   PE6IOR     */
            _UWORD PE5IOR:1;                /*   PE5IOR     */
            _UWORD PE4IOR:1;                /*   PE4IOR     */
            _UWORD PE3IOR:1;                /*   PE3IOR     */
            _UWORD PE2IOR:1;                /*   PE2IOR     */
            _UWORD PE1IOR:1;                /*   PE1IOR     */
            _UWORD PE0IOR:1;                /*   PE0IOR     */
        } BIT;
    } PEIORL;

    _UBYTE wk15[4];

    union {                                 /* PECRL2       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD PE13MD1:1;               /*   PE13MD1    */
            _UWORD PE13MD0:1;               /*   PE13MD0    */
            _UWORD PE12MD1:1;               /*   PE12MD1    */
            _UWORD PE12MD0:1;               /*   PE12MD0    */
            _UWORD PE11MD1:1;               /*   PE11MD1    */
            _UWORD PE11MD0:1;               /*   PE11MD0    */
            _UWORD PE10MD1:1;               /*   PE10MD1    */
            _UWORD PE10MD0:1;               /*   PE10MD0    */
            _UWORD PE9MD1:1;                /*   PE9MD1     */
            _UWORD PE9MD0:1;                /*   PE9MD0     */
            _UWORD PE8MD1:1;                /*   PE8MD1     */
            _UWORD PE8MD0:1;                /*   PE8MD0     */
        } BIT;
    } PECRL2;

    union {                                 /* PECRL1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PE7MD1:1;                /*   PE7MD1     */
            _UWORD PE7MD0:1;                /*   PE7MD0     */
            _UWORD PE6MD1:1;                /*   PE6MD1     */
            _UWORD PE6MD0:1;                /*   PE6MD0     */
            _UWORD PE5MD1:1;                /*   PE5MD1     */
            _UWORD PE5MD0:1;                /*   PE5MD0     */
            _UWORD PE4MD1:1;                /*   PE4MD1     */
            _UWORD PE4MD0:1;                /*   PE4MD0     */
            _UWORD PE3MD1:1;                /*   PE3MD1     */
            _UWORD PE3MD0:1;                /*   PE3MD0     */
            _UWORD PE2MD1:1;                /*   PE2MD1     */
            _UWORD PE2MD0:1;                /*   PE2MD0     */
            _UWORD PE1MD1:1;                /*   PE1MD1     */
            _UWORD PE1MD0:1;                /*   PE1MD0     */
            _UWORD PE0MD1:1;                /*   PE0MD1     */
            _UWORD PE0MD0:1;                /*   PE0MD0     */
        } BIT;
    } PECRL1;

    _UBYTE wk16[112];

    /* ---- Port F ---- */

    _UBYTE wk17[2];

    union {                                 /* PFDRL        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD PF11DR:1;                /*   PF11DR     */
            _UWORD PF10DR:1;                /*   PF10DR     */
            _UWORD PF9DR:1;                 /*   PF9DR      */
            _UWORD PF8DR:1;                 /*   PF8DR      */
            _UWORD PF7DR:1;                 /*   PF7DR      */
            _UWORD PF6DR:1;                 /*   PF6DR      */
            _UWORD PF5DR:1;                 /*   PF5DR      */
            _UWORD PF4DR:1;                 /*   PF4DR      */
            _UWORD PF3DR:1;                 /*   PF3DR      */
            _UWORD PF2DR:1;                 /*   PF2DR      */
            _UWORD PF1DR:1;                 /*   PF1DR      */
            _UWORD PF0DR:1;                 /*   PF0DR      */
        } BIT;
    } PFDRL;

    _UBYTE wk18[2];

    union {                                 /* PFIORL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD PF11IOR:1;               /*   PF11IOR    */
            _UWORD PF10IOR:1;               /*   PF10IOR    */
            _UWORD PF9IOR:1;                /*   PF9IOR     */
            _UWORD PF8IOR:1;                /*   PF8IOR     */
            _UWORD PF7IOR:1;                /*   PF7IOR     */
            _UWORD PF6IOR:1;                /*   PF6IOR     */
            _UWORD PF5IOR:1;                /*   PF5IOR     */
            _UWORD PF4IOR:1;                /*   PF4IOR     */
            _UWORD PF3IOR:1;                /*   PF3IOR     */
            _UWORD PF2IOR:1;                /*   PF2IOR     */
            _UWORD PF1IOR:1;                /*   PF1IOR     */
            _UWORD PF0IOR:1;                /*   PF0IOR     */
        } BIT;
    } PFIORL;

    _UBYTE wk19[4];

    union {                                 /* PFCRL2       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :4;                      /*              */
            _UWORD PF13MD1:1;               /*   PF13MD1    */
            _UWORD PF13MD0:1;               /*   PF13MD0    */
            _UWORD :2;                      /*              */
            _UWORD PF11MD1:1;               /*   PF11MD1    */
            _UWORD PF11MD0:1;               /*   PF11MD0    */
            _UWORD PF10MD1:1;               /*   PF10MD1    */
            _UWORD PF10MD0:1;               /*   PF10MD0    */
            _UWORD PF9MD1:1;                /*   PF9MD1     */
            _UWORD PF9MD0:1;                /*   PF9MD0     */
            _UWORD :1;                      /*              */
            _UWORD PF8MD0:1;                /*   PF8MD0     */
        } BIT;
    } PFCRL2;

    union {                                 /* PFCRL1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PF7MD1:1;                /*   PF7MD1     */
            _UWORD PF7MD0:1;                /*   PF7MD0     */
            _UWORD PF6MD1:1;                /*   PF6MD1     */
            _UWORD PF6MD0:1;                /*   PF6MD0     */
            _UWORD PF5MD1:1;                /*   PF5MD1     */
            _UWORD PF5MD0:1;                /*   PF5MD0     */
            _UWORD PF4MD1:1;                /*   PF4MD1     */
            _UWORD PF4MD0:1;                /*   PF4MD0     */
            _UWORD PF3MD1:1;                /*   PF3MD1     */
            _UWORD PF3MD0:1;                /*   PF3MD0     */
            _UWORD PF2MD1:1;                /*   PF2MD1     */
            _UWORD PF2MD0:1;                /*   PF2MD0     */
            _UWORD PF1MD1:1;                /*   PF1MD1     */
            _UWORD PF1MD0:1;                /*   PF1MD0     */
            _UWORD :1;                      /*              */
            _UWORD PF0MD0:1;                /*   PF0MD0     */
        } BIT;
    } PFCRL1;

    _UBYTE wk20[112];

    /* ---- Port G ---- */

    union {                                 /* PGDRH        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD PG23DR:1;                /*   PG23DR     */
            _UWORD PG22DR:1;                /*   PG22DR     */
            _UWORD PG21DR:1;                /*   PG21DR     */
            _UWORD PG20DR:1;                /*   PG20DR     */
            _UWORD PG19DR:1;                /*   PG19DR     */
            _UWORD PG18DR:1;                /*   PG18DR     */
            _UWORD PG17DR:1;                /*   PG17DR     */
            _UWORD PG16DR:1;                /*   PG16DR     */
        } BIT;
    } PGDRH;

    union {                                 /* PGDRL        */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PG15DR:1;                /*   PG15DR     */
            _UWORD PG14DR:1;                /*   PG14DR     */
            _UWORD PG13DR:1;                /*   PG13DR     */
            _UWORD PG12DR:1;                /*   PG12DR     */
            _UWORD PG11DR:1;                /*   PG11DR     */
            _UWORD PG10DR:1;                /*   PG10DR     */
            _UWORD PG9DR:1;                 /*   PG9DR      */
            _UWORD PG8DR:1;                 /*   PG8DR      */
            _UWORD PG7DR:1;                 /*   PG7DR      */
            _UWORD PG6DR:1;                 /*   PG6DR      */
            _UWORD PG5DR:1;                 /*   PG5DR      */
            _UWORD PG4DR:1;                 /*   PG4DR      */
            _UWORD PG3DR:1;                 /*   PG3DR      */
            _UWORD PG2DR:1;                 /*   PG2DR      */
            _UWORD PG1DR:1;                 /*   PG1DR      */
            _UWORD PG0DR:1;                 /*   PG0DR      */
        } BIT;
    } PGDRL;

    union {                                 /* PGIORH       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :8;                      /*              */
            _UWORD PG23IOR:1;               /*   PG23IOR    */
            _UWORD PG22IOR:1;               /*   PG22IOR    */
            _UWORD PG21IOR:1;               /*   PG21IOR    */
            _UWORD PG20IOR:1;               /*   PG20IOR    */
            _UWORD PG19IOR:1;               /*   PG19IOR    */
            _UWORD PG18IOR:1;               /*   PG18IOR    */
            _UWORD PG17IOR:1;               /*   PG17IOR    */
            _UWORD PG16IOR:1;               /*   PG16IOR    */
        } BIT;
    } PGIORH;

    union {                                 /* PGIORL       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD PG15IOR:1;               /*   PG15IOR    */
            _UWORD PG14IOR:1;               /*   PG14IOR    */
            _UWORD PG13IOR:1;               /*   PG13IOR    */
            _UWORD PG12IOR:1;               /*   PG12IOR    */
            _UWORD PG11IOR:1;               /*   PG11IOR    */
            _UWORD PG10IOR:1;               /*   PG10IOR    */
            _UWORD PG9IOR:1;                /*   PG9IOR     */
            _UWORD PG8IOR:1;                /*   PG8IOR     */
            _UWORD PG7IOR:1;                /*   PG7IOR     */
            _UWORD PG6IOR:1;                /*   PG6IOR     */
            _UWORD PG5IOR:1;                /*   PG5IOR     */
            _UWORD PG4IOR:1;                /*   PG4IOR     */
            _UWORD PG3IOR:1;                /*   PG3IOR     */
            _UWORD PG2IOR:1;                /*   PG2IOR     */
            _UWORD PG1IOR:1;                /*   PG1IOR     */
            _UWORD PG0IOR:1;                /*   PG0IOR     */
        } BIT;
    } PGIORL;

	_UBYTE wk21[2];

    union {                                 /* PGCRH2       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PG23MD0:1;               /*   PG23MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG22MD0:1;               /*   PG22MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG21MD0:1;               /*   PG21MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG20MD0:1;               /*   PG20MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG19MD0:1;               /*   PG19MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG18MD0:1;               /*   PG18MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG17MD0:1;               /*   PG17MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG16MD0:1;               /*   PG16MD0    */
        } BIT;
    } PGCRH2;

    union {                                 /* PGCRL2       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PG15MD0:1;               /*   PG15MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG14MD0:1;               /*   PG14MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG13MD0:1;               /*   PG13MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG12MD0:1;               /*   PG12MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG11MD0:1;               /*   PG11MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG10MD0:1;               /*   PG10MD0    */
            _UWORD :1;                      /*              */
            _UWORD PG9MD0:1;                /*   PG9MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG8MD0:1;                /*   PG8MD0     */
        } BIT;
    } PGCRL2;

    union {                                 /* PGCRL1       */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Byte Access */
               _UBYTE H;                    /*   High       */
               _UBYTE L;                    /*   Low        */
               } BYTE;                      /*              */
        struct {                            /*  Bit Access  */
            _UWORD :1;                      /*              */
            _UWORD PG7MD0:1;                /*   PG7MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG6MD0:1;                /*   PG6MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG5MD0:1;                /*   PG5MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG4MD0:1;                /*   PG4MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG3MD0:1;                /*   PG3MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG2MD0:1;                /*   PG2MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG1MD0:1;                /*   PG1MD0     */
            _UWORD :1;                      /*              */
            _UWORD PG0MD0:1;                /*   PG0MD0     */
        } BIT;
    } PGCRL1;
};

struct st_ubc {                             /* struct UBC   */
    union {                                 /* BAR0         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BA0_:32;                /*   BA0_       */
        } BIT;                              /*              */
    } BAR0;                                 /*              */
    union {                                 /* BAMR0        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BAM0_:32;               /*   BAM0_      */
        } BIT;
    } BAMR0;
    union {                                 /* BDR0         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BD0_:32;                /*   BD0_       */
        } BIT;
    } BDR0;
    union {                                 /* BDMR0        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BDM0_:32;               /*   BDM0_      */
        } BIT;
    } BDMR0;
    union {                                 /* BAR1         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BA1_:32;                /*   BA1_       */
        } BIT;
    } BAR1; 
    union {                                 /* BAMR1        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BAM1_:32;               /*   BAM1_      */
        } BIT;
    } BAMR1;
    union {                                 /* BDR1         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BD1_:32;                /*   BD1_       */
        } BIT;
    } BDR1;
    union {                                 /* BDMR1        */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD BDM1_:32;               /*   BDM1_      */
        } BIT;
    } BDMR1;
    _UBYTE wk0[128];
    union {                                 /* BBR0         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :2;
            _UWORD UBID0:1;                 /*   UBID0      */
            _UWORD DBE0:1;                  /*   DBE0       */
            _UWORD CP0_:4;                  /*   CP0_       */
            _UWORD CD0_:2;                  /*   CD0_       */
            _UWORD ID0_:2;                  /*   ID0_       */
            _UWORD RW0_:2;                  /*   RW0_       */
            _UWORD SZ0_:2;                  /*   SZ0_       */
        } BIT;
    } BBR0;
    _UBYTE wk1[14];
    union {                                 /* BBR1         */
        _UWORD WORD;                        /*  Word Access */
        struct {                            /*  Bit Access  */
            _UWORD :2;                      /*              */
            _UWORD UBID1:1;                 /*   UBID1      */
            _UWORD DBE1:1;                  /*   DBE1       */
            _UWORD CP1_:4;                  /*   CP1_       */
            _UWORD CD1_:2;                  /*   CD1_       */
            _UWORD ID1_:2;                  /*   ID1_       */
            _UWORD RW1_:2;                  /*   RW1_       */
            _UWORD SZ1_:2;                  /*   SZ1_       */
        } BIT;
    } BBR1;
    _UBYTE wk2[14];
    union {                                 /* BRCR         */
        _UDWORD LONG;                       /*  Long Access */
        struct {                            /*  Bit Access  */
            _UDWORD :16;                    /*              */
            _UDWORD SCMFC0:1;               /*   SCMFC0     */
            _UDWORD SCMFC1:1;               /*   SCMFC1     */
            _UDWORD SCMFD0:1;               /*   SCMFD0     */
            _UDWORD SCMFD1:1;               /*   SCMFD1     */
            _UDWORD :5;                     /*              */
            _UDWORD PCB:2;                  /*   PCB        */
            _UDWORD :5;                     /*              */
        } BIT;
    } BRCR;
};

struct st_hudi{                             /* struct HUDI  */
    union {
        _UWORD WORD;
        struct{
            _UWORD TI:8;
            _UWORD :8;
        }BIT;
    }SDIR;
};


#define CCNT    (*(volatile struct st_ccnt *)0xfffc1000)    /* CCNT   address */
#define INTC    (*(volatile struct st_intc *)0xfffe0800)    /* INTC   address */
#define BSC     (*(volatile struct st_bsc *)0xfffc0000)     /* BSC    address */
#define AC      (*(volatile struct st_ac *)0xfffc180c)      /* AC     address */
#define DMAC    (*(volatile struct st_dmac*)0xfffe1000)     /* DMAC   address */
#define CPG     (*(volatile struct st_cpg *)0xfffe0010)     /* CPG    address */
#define WDT     (*(volatile struct st_wdt *)0xfffe0000)     /* WDT    address */
#define ETHERC  (*(volatile struct st_etherc*)0xfffc2160)   /* EtherC address */
#define EDMAC   (*(volatile struct st_edmac*)0xfffc2000)    /* E-DMAC address */
#define ADMAC   (*(volatile struct st_admac*)0xfffc2440)    /* A-DAMC address */
#define STIF0   (*(volatile struct st_stif*)0xffffd000)     /* STIF0  address */
#define STIF1   (*(volatile struct st_stif*)0xffffd800)     /* STIF1  address */
#define SSI0    (*(volatile struct st_ssi*)0xffff0000)      /* SSI0   address */
#define SSI1    (*(volatile struct st_ssi*)0xffff0800)      /* SSI0   address */
#define USB     (*(volatile struct st_usb*)0xfffc1c0c)      /* USB    address */
#define IIC30   (*(volatile struct st_iic3 *)0xfffee000)    /* IIC30  address */
#define HIF     (*(volatile struct st_hif   *)0xffffe000)   /* HIF    address */
#define CMT     (*(volatile struct st_cmt *)0xfffec000)     /* CMT    address */
#define SCIF0   (*(volatile struct st_scif *)0xfffe8000)    /* SCIF0  address */
#define SCIF1   (*(volatile struct st_scif *)0xfffe8800)    /* SCIF1  address */
#define SCIF2   (*(volatile struct st_scif *)0xfffe9000)    /* SCIF2  address */
#define PORT    (*(volatile struct st_port *)0xfffe3800)    /* PORT(I/O+PFC) address */
#define UBC     (*(volatile struct st_ubc *)0xfffc0400)     /* UBC    address */
#define HUDI    (*(volatile struct st_hudi *)0xfffe2000)    /* HUDI   address */

/* End of IODEFINE_H */
#endif
